.*: Assembler messages:
.*:5: Error: Improper bit index \(51\)
.*:7: Error: Improper bit index \(71\)
.*:10: Error: Improper bit index \(49\)
.*:12: Error: Improper bit index \(74\)
.*:15: Error: Improper size \(37\)
.*:17: Error: Improper position \(39\)
.*:18: Error: Improper size \(25\)
.*:20: Error: Improper position \(64\)
.*:21: Error: Improper size \(14\)
.*:23: Error: opcode not supported on this processor.*
.*:24: Error: opcode not supported on this processor.*
.*:25: Error: opcode not supported on this processor.*
.*:26: Error: opcode not supported on this processor.*
.*:27: Error: opcode not supported on this processor.*
.*:28: Error: opcode not supported on this processor.*
.*:29: Error: opcode not supported on this processor.*
.*:30: Error: opcode not supported on this processor.*
.*:31: Error: opcode not supported on this processor.*
.*:32: Error: opcode not supported on this processor.*
.*:33: Error: opcode not supported on this processor.*
.*:34: Error: opcode not supported on this processor.*
.*:35: Error: opcode not supported on this processor.*
.*:36: Error: opcode not supported on this processor.*
.*:37: Error: opcode not supported on this processor.*
.*:39: Error: opcode not supported on this processor.*
.*:40: Error: opcode not supported on this processor.*
.*:41: Error: opcode not supported on this processor.*
.*:42: Error: opcode not supported on this processor.*
.*:43: Error: opcode not supported on this processor.*
.*:45: Error: illegal operands `dmfc2 \$2,0x10000'
.*:46: Error: illegal operands `dmtc2 \$2,0x12345'
.*:47: Error: illegal operands `dmfc2 \$9,\$12'
.*:48: Error: illegal operands `dmfc2 \$4,\$15,4'
.*:49: Error: illegal operands `dmtc2 \$16,\$8'
.*:50: Error: illegal operands `dmtc2 \$22,\$7,\$4'
.*:52: Error: Improper size \(32\)
.*:54: Error: Improper position \(32\)
.*:55: Error: Improper size \(29\)
.*:57: Error: Improper position \(70\)
.*:58: Error: Improper size \(25\)
.*:60: Error: Improper immediate \(512\)
.*:61: Error: Improper immediate \(-771\)
.*:62: Error: Improper immediate \(615\)
.*:63: Error: Improper immediate \(-513\)
