.*: Assembler messages:
.*:3: Error: No !tlsgd!1 was found
.*:6: Error: No !tlsldm!2 was found
.*:18: Error: No !tlsldm!5 was found
.*:22: Error: No !tlsgd!6 was found
.*:8: Error: too many !literal!3 for !tlsgd
.*:12: Error: too many !literal!4 for !tlsldm
