[^:]*: Assembler messages:
[^:]*:21: Error: immediate offset out of range
[^:]*:22: Error: immediate offset out of range
[^:]*:24: Error: immediate offset out of range
[^:]*:25: Error: immediate offset out of range
[^:]*:27: Error: immediate offset out of range
[^:]*:28: Error: immediate offset out of range
[^:]*:31: Error: immediate offset out of range
[^:]*:32: Error: immediate offset out of range
[^:]*:35: Error: immediate offset out of range
[^:]*:36: Error: immediate offset out of range
[^:]*:38: Error: immediate offset out of range
[^:]*:39: Error: immediate offset out of range
[^:]*:41: Error: immediate offset out of range
[^:]*:42: Error: immediate offset out of range
[^:]*:44: Error: immediate offset out of range
[^:]*:45: Error: immediate offset out of range
[^:]*:46: Error: immediate offset not 2-byte-aligned
[^:]*:48: Error: immediate offset out of range
[^:]*:49: Error: immediate offset out of range
[^:]*:50: Error: immediate offset not 2-byte-aligned
[^:]*:52: Error: immediate offset out of range
[^:]*:53: Error: immediate offset out of range
[^:]*:54: Error: immediate offset not 4-byte-aligned
[^:]*:56: Error: immediate offset out of range
[^:]*:57: Error: immediate offset out of range
[^:]*:59: Error: immediate offset out of range
[^:]*:60: Error: immediate offset out of range
[^:]*:61: Error: immediate offset not 2-byte-aligned
[^:]*:63: Error: immediate offset out of range
[^:]*:64: Error: immediate offset out of range
[^:]*:65: Error: immediate offset not 4-byte-aligned
[^:]*:9: Error: value too large for 2-byte field
[^:]*:11: Error: value too large for 2-byte field
[^:]*:13: Error: value too large for 1-byte field
[^:]*:15: Error: value too large for 1-byte field
