.*: Assembler messages:
.*:3: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:4: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:5: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:6: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:7: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:8: Error: Number \(0x0*100000000\) larger than 32 bits
.*:10: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:11: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:12: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:13: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:14: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:15: Error: Number \(0x0*100000000\) larger than 32 bits
.*:17: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:18: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:19: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:20: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:21: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:22: Error: Number \(0x0*100000000\) larger than 32 bits
.*:24: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:25: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:26: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:27: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:28: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:29: Error: Number \(0x0*100000000\) larger than 32 bits
.*:31: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:32: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:32: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:33: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:33: Error: Number \(0xabcdef0123450000\) larger than 32 bits
.*:34: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:34: Error: Number \(0x0*123456789ac0000\) larger than 32 bits
.*:35: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:35: Error: Number \(0x0*200000000\) larger than 32 bits
.*:36: Error: Number \(0x0*100000000\) larger than 32 bits
.*:36: Error: Number \(0x0*100000000\) larger than 32 bits
.*:38: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:39: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:39: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:40: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:40: Error: Number \(0xabcdef0123450000\) larger than 32 bits
.*:41: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:41: Error: Number \(0x0*123456789ac0000\) larger than 32 bits
.*:42: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:42: Error: Number \(0x0*200000000\) larger than 32 bits
.*:43: Error: Number \(0x0*100000000\) larger than 32 bits
.*:43: Error: Number \(0x0*100000000\) larger than 32 bits
.*:45: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:46: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:46: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:47: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:47: Error: Number \(0xabcdef0123450000\) larger than 32 bits
.*:48: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:48: Error: Number \(0x0*123456789ac0000\) larger than 32 bits
.*:49: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:49: Error: Number \(0x0*200000000\) larger than 32 bits
.*:50: Error: Number \(0x0*100000000\) larger than 32 bits
.*:50: Error: Number \(0x0*100000000\) larger than 32 bits
.*:52: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:53: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:53: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:54: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:54: Error: Number \(0xabcdef0123450000\) larger than 32 bits
.*:55: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:55: Error: Number \(0x0*123456789ac0000\) larger than 32 bits
.*:56: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:56: Error: Number \(0x0*200000000\) larger than 32 bits
.*:57: Error: Number \(0x0*100000000\) larger than 32 bits
.*:57: Error: Number \(0x0*100000000\) larger than 32 bits
.*:59: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:60: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:61: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:62: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:63: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:64: Error: Number \(0x0*100000000\) larger than 32 bits
.*:66: Error: Number \(0xfffffffeffffffff\) larger than 32 bits
.*:67: Error: Number \(0xfffffffe00000000\) larger than 32 bits
.*:68: Error: Number \(0xabcdef0123456789\) larger than 32 bits
.*:69: Error: Number \(0x0*123456789abcdef\) larger than 32 bits
.*:70: Error: Number \(0x0*1ffffffff\) larger than 32 bits
.*:71: Error: Number \(0x0*100000000\) larger than 32 bits
