
#define FUNC(X_)  extern void X_ (void); void X_ (void) { };

FUNC(A)
FUNC(B)
FUNC(C)
FUNC(D)
FUNC(E)
FUNC(GC_abort)
FUNC(GC_add_ext_descriptor)
FUNC(GC_add_leaked)
FUNC(GC_add_map_entry)
FUNC(GC_used_heap_size_after_full)
FUNC(GC_version)
FUNC(GC_with_callee_saves_pushed)
FUNC(GC_words_allocd_at_reset)
FUNC(GC_world_stopped)
FUNC(GC_write)
FUNC(JIS0208_to_Unicode)
FUNC(JIS0212_to_Unicode)
FUNC(JvConvertArgv)
FUNC(JvRunMain)
FUNC(JvRunMainName)
FUNC(Unicode_to_JIS)
FUNC(_Jv_AllocBytes)
FUNC(_Jv_AllocObject)
FUNC(_Jv_AllocObjectNoFinalizer)
FUNC(_ZTVN5javax8security4sasl23AuthenticationExceptionE)
FUNC(_ZTVN5javax8security4sasl4SaslE)
FUNC(__gcj_personality_v0)
FUNC(__ieee754_acos)
FUNC(__ieee754_asin)
FUNC(__ieee754_atan2)
FUNC(__kernel_cos)
FUNC(__kernel_rem_pio2)
FUNC(__kernel_sin)
FUNC(__kernel_tan)
FUNC(_dist_code)
FUNC(_length_code)
FUNC(_mprec_log10)
FUNC(_tr_align)
FUNC(_tr_flush_block)
FUNC(_tr_init)
FUNC(_tr_stored_block)
FUNC(_tr_tally)
FUNC(adler32)
FUNC(adler32_combine)
FUNC(crc32)
FUNC(crc32_combine)
FUNC(deflate)
FUNC(deflateBound)
FUNC(deflateCopy)
FUNC(ffi_call_STDCALL)
FUNC(ffi_call_SYSV)
FUNC(ffi_closure_SYSV)
FUNC(ffi_closure_SYSV_inner)
FUNC(ffi_closure_alloc)
FUNC(ffi_closure_free)
FUNC(free_list_index_of)
FUNC(get_crc_table)
FUNC(gzclearerr)
FUNC(gzclose)
FUNC(gzungetc)
FUNC(gzwrite)
FUNC(h0)
FUNC(h1)
FUNC(h2)
FUNC(h3)
FUNC(h4)
FUNC(inflate)
FUNC(inflateBack)
FUNC(inflateBackEnd)
FUNC(inflate_fast)
FUNC(inflate_table)
FUNC(lt_dladderror)
FUNC(lt_dladdsearchdir)
FUNC(lt_dlsetsearchpath)
FUNC(lt_dlsym)
FUNC(lt_preloaded_symbols)
FUNC(print)
FUNC(thread_table)
FUNC(uncompress)
FUNC(zError)
FUNC(z_errmsg)
FUNC(zcalloc)
FUNC(zcfree)
FUNC(zlibCompileFlags)
FUNC(zlibVersion)
FUNC(_Jv_JNIFunctions)
FUNC(_Jv_JNI_InvokeFunctions)
FUNC(_Jv_JNI_PopSystemFrame)
FUNC(_Jv_JVMPI_Notify_OBJECT_ALLOC)
FUNC(_Jv_JVMPI_Notify_THREAD_END)
FUNC(_Jv_JVMPI_Notify_THREAD_START)
FUNC(_Jv_JVMTI_Interface)
FUNC(_Jv_LookupInterfaceMethod)
FUNC(_Jv_LookupInterfaceMethodIdx)
FUNC(_Jv_LookupJNIMethod)
FUNC(_Jv_Malloc)
FUNC(_Jv_Throw)
FUNC(_Jv_ThrowAbstractMethodError)
FUNC(_Jv_UnwrapJNIweakReference)
FUNC(_Jv__mcmp)
FUNC(_Jv__mdiff)
FUNC(_Jv__mprec_bigtens)
FUNC(_Jv__mprec_tinytens)
FUNC(_Jv_argc)
FUNC(_Jv_argv)
FUNC(_Jv_b2d)
FUNC(_Jv_booleanClass)
FUNC(_Jv_byteClass)
FUNC(_Jv_charClass)
FUNC(_Jv_d2b)
FUNC(_Jv_ulp)
FUNC(_Jv_voidClass)
FUNC(_Z10_Jv_InitGCv)
FUNC(_Z10_Jv_equalnP13_Jv_Utf8ConstPN4java4lang6StringEi)
FUNC(_Z11_Jv_SetArgsiPPKc)
FUNC(_Z11_Jv_ZMallocPvjj)
FUNC(_Z11trie_lookupPtt)
FUNC(_Z12_Jv_CondWaitP23_Jv_ConditionVariable_tP11_Jv_Mutex_txi)
FUNC(_Z12_Jv_init_cifP13_Jv_Utf8ConstibP7ffi_cifPP9_ffi_typeS5_)
FUNC(_Z12_Jv_is_proxyPv)
FUNC(_Z12shsTransformP8SHS_INFO)
FUNC(_Z13_Jv_DisableGCv)
FUNC(_Z15_Jv_create_coreP14_Jv_core_chainPN4java4lang6StringE)
FUNC(_Z16_Jv_BlockSigchldv)
FUNC(_Z16_Jv_BuildGCDescrPN4java4lang5ClassE)
FUNC(_Z16_Jv_GCFreeMemoryv)
FUNC(_Z16_Jv_SetStackSizePKc)
FUNC(_Z16_Jv_VerifyMethodP16_Jv_InterpMethod)
FUNC(_Z17JvNewStringLatin1PKc)
FUNC(_ZTVN5javax8security4auth4x50021X500PrivateCredentialE)
FUNC(_ZTVN5javax8security4auth5login12LoginContextE)
FUNC(_ZTVN5javax8security4auth5login13ConfigurationE)
FUNC(_ZTVN5javax8security4auth5login14LoginExceptionE)
FUNC(_ZTVN5javax8security4sasl19RealmChoiceCallbackE)
FUNC(_Z24_Jv_isPrimitiveOrDerivedPK13_Jv_Utf8Const)
FUNC(_Z26_Jv_FindSymbolInExecutablePKc)
FUNC(_Z26_Jv_GCInitializeFinalizersPFvvE)
FUNC(_Z37_Jv_FindClassFromSignatureNoExceptionPcPN4java4lang11ClassLoaderEPS_)
FUNC(_Z39_Jv_ThrowNoClassDefFoundErrorTrampolineP7ffi_cifPvPS1_S1_)
FUNC(_Z7in_hashPN4java4lang6ObjectE)
FUNC(_Z7shsInitP8SHS_INFO)
FUNC(_Z8shsFinalP8SHS_INFO)
FUNC(_Z9_Jv_AbortPKcS0_iS0_)
FUNC(_Z9_Jv_RunGCv)
FUNC(_Z9_Jv_ZFreePvS_)
FUNC(_Z9_Jv_equalP13_Jv_Utf8ConstPN4java4lang6StringEi)
FUNC(_Z9shsUpdateP8SHS_INFOPhi)
FUNC(_ZGr30_java_Sutil_Sweeks__properties)
FUNC(_ZGr32_java_Sutil_Siso4217__properties)
FUNC(_ZGr48_gnu_Sjavax_Sprint_SPrinterDialog_de__properties)
FUNC(_ZGr49_gnu_Sjava_Slocale_SLocaleInformation__properties)
FUNC(_ZGr51_gnu_Sjava_Sutil_Sregex_SMessagesBundle__properties)

