#ld: -T arm.ld
#objdump: -s

.*:     file format.*

#...
Contents of section .ARM.exidx:
 8004 (fcffff7f b0b0a880 f8ffff7f 01000000|7ffffffc 80a8b0b0 7ffffff8 00000001)  .*
Contents of section .far:
#...
