[^:]*: Assembler messages:
[^:]*:27: Error: branch must be last instruction in IT block -- `ldreq r15,\[r0\]'
[^:]*:28: Error: branch must be last instruction in IT block -- `ldreq r15,\[r0,#0\]'
[^:]*:29: Error: branch must be last instruction in IT block -- `ldreq r15,\[sp\]'
[^:]*:30: Error: branch must be last instruction in IT block -- `ldreq r15,\[sp,#0\]'
[^:]*:31: Error: branch must be last instruction in IT block -- `ldreq.w r15,\[r0\]'
[^:]*:32: Error: branch must be last instruction in IT block -- `ldreq.w r15,\[r0,#0\]'
[^:]*:33: Error: branch must be last instruction in IT block -- `ldreq r15,\[r0,#-4\]'
[^:]*:34: Error: branch must be last instruction in IT block -- `ldreq r15,\[r0\],#4'
[^:]*:35: Error: branch must be last instruction in IT block -- `ldreq r15,\[r0,#0\]!'
[^:]*:38: Error: branch must be last instruction in IT block -- `ldreq r15,label'
[^:]*:39: Error: branch must be last instruction in IT block -- `ldreq.w r15,label'
[^:]*:40: Error: branch must be last instruction in IT block -- `ldreq.w r15,\[pc,#-0\]'
[^:]*:43: Error: branch must be last instruction in IT block -- `ldreq r15,\[r0,r1\]'
[^:]*:44: Error: branch must be last instruction in IT block -- `ldreq.w r15,\[r0,r1\]'
[^:]*:45: Error: branch must be last instruction in IT block -- `ldreq.w r15,\[r0,r1,LSL#2\]'
[^:]*:48: Error: r15 not allowed here -- `ldrb pc,\[r0,#4\]'
[^:]*:50: Error: r13 not allowed here -- `ldrb.w sp,\[r0,#4\]'
[^:]*:51: Error: r15 not allowed here -- `ldrb.w pc,\[r0,#4\]'
[^:]*:52: Error: r15 not allowed here -- `ldrb pc,\[r0,#-4\]'
[^:]*:54: Error: r15 not allowed here -- `ldrb pc,\[r0\],#4'
[^:]*:55: Error: r13 not allowed here -- `ldrb sp,\[r0\],#4'
[^:]*:56: Error: r15 not allowed here -- `ldrb pc,\[r0,#4\]!'
[^:]*:57: Error: r13 not allowed here -- `ldrb sp,\[r0,#4\]!'
[^:]*:60: Error: r15 not allowed here -- `ldrb pc,label'
[^:]*:61: Error: r15 not allowed here -- `ldrb pc,\[PC,#-0\]'
[^:]*:62: Error: r13 not allowed here -- `ldrb sp,label'
[^:]*:63: Error: r13 not allowed here -- `ldrb sp,\[PC,#-0\]'
[^:]*:66: Error: r15 not allowed here -- `ldrb pc,\[r0,r1\]'
[^:]*:67: Error: cannot use register index with PC-relative addressing -- `ldrb r0,\[pc,r1\]'
[^:]*:68: Error: r15 not allowed here -- `ldrb r0,\[r1,pc\]'
[^:]*:69: Error: r15 not allowed here -- `ldrb.w pc,\[r0,r1,LSL#1\]'
[^:]*:70: Error: r13 not allowed here -- `ldrb.w sp,\[r0,r1\]'
[^:]*:71: Error: r15 not allowed here -- `ldrb.w r2,\[r0,pc,LSL#2\]'
[^:]*:72: Error: r13 not allowed here -- `ldrb.w r2,\[r0,sp,LSL#2\]'
[^:]*:75: Error: r15 not allowed here -- `ldrbt pc,\[r0,#4\]'
[^:]*:76: Error: r13 not allowed here -- `ldrbt sp,\[r0,#4\]'
[^:]*:79: Error: r15 not allowed here -- `ldrd pc,r0,\[r1\]'
[^:]*:80: Error: r13 not allowed here -- `ldrd sp,r0,\[r1\]'
[^:]*:81: Error: r15 not allowed here -- `ldrd r0,pc,\[r1\]'
[^:]*:82: Error: r13 not allowed here -- `ldrd r0,sp,\[r1\]'
[^:]*:83: Error: r15 not allowed here -- `ldrd pc,r0,\[r1\],#4'
[^:]*:84: Error: r13 not allowed here -- `ldrd sp,r0,\[r1\],#4'
[^:]*:85: Error: r15 not allowed here -- `ldrd r0,pc,\[r1\],#4'
[^:]*:86: Error: r13 not allowed here -- `ldrd r0,sp,\[r1\],#4'
[^:]*:87: Error: r15 not allowed here -- `ldrd pc,r0,\[r1,#4\]!'
[^:]*:88: Error: r13 not allowed here -- `ldrd sp,r0,\[r1,#4\]!'
[^:]*:89: Error: r15 not allowed here -- `ldrd r0,pc,\[r1,#4\]!'
[^:]*:90: Error: r13 not allowed here -- `ldrd r0,sp,\[r1,#4\]!'
[^:]*:93: Error: r15 not allowed here -- `ldrd pc,r0,label'
[^:]*:94: Error: r13 not allowed here -- `ldrd sp,r0,label'
[^:]*:95: Error: r15 not allowed here -- `ldrd r0,pc,label'
[^:]*:96: Error: r13 not allowed here -- `ldrd r0,sp,label'
[^:]*:97: Error: r15 not allowed here -- `ldrd pc,r0,\[pc,#-0\]'
[^:]*:98: Error: r13 not allowed here -- `ldrd sp,r0,\[pc,#-0\]'
[^:]*:99: Error: r15 not allowed here -- `ldrd r0,pc,\[pc,#-0\]'
[^:]*:100: Error: r13 not allowed here -- `ldrd r0,sp,\[pc,#-0\]'
[^:]*:105: Error: r15 not allowed here -- `ldrex pc,\[r0\]'
[^:]*:106: Error: r13 not allowed here -- `ldrex sp,\[r0\]'
[^:]*:107: Error: r15 not allowed here -- `ldrex r0,\[pc\]'
[^:]*:108: Error: r15 not allowed here -- `ldrexb pc,\[r0\]'
[^:]*:109: Error: r13 not allowed here -- `ldrexb sp,\[r0\]'
[^:]*:110: Error: r15 not allowed here -- `ldrexb r0,\[pc\]'
[^:]*:111: Error: r15 not allowed here -- `ldrexd pc,r0,\[r1\]'
[^:]*:112: Error: r13 not allowed here -- `ldrexd sp,r0,\[r1\]'
[^:]*:113: Error: r15 not allowed here -- `ldrexd r0,pc,\[r1\]'
[^:]*:114: Error: r13 not allowed here -- `ldrexd r0,sp,\[r1\]'
[^:]*:115: Error: r15 not allowed here -- `ldrexd r0,r1,\[pc\]'
[^:]*:116: Error: r15 not allowed here -- `ldrexh pc,\[r0\]'
[^:]*:117: Error: r13 not allowed here -- `ldrexh sp,\[r0\]'
[^:]*:118: Error: r15 not allowed here -- `ldrexh r0,\[pc\]'
[^:]*:121: Error: r15 not allowed here -- `ldrh pc,\[r0\]'
[^:]*:122: Error: r15 not allowed here -- `ldrh pc,\[r0,#4\]'
[^:]*:125: Error: r15 not allowed here -- `ldrh.w pc,\[r0\]'
[^:]*:126: Error: r15 not allowed here -- `ldrh.w pc,\[r0,#4\]'
[^:]*:127: Error: r13 not allowed here -- `ldrh.w sp,\[r0\]'
[^:]*:128: Error: r13 not allowed here -- `ldrh.w sp,\[r0,#4\]'
[^:]*:129: Error: r15 not allowed here -- `ldrh pc,\[r0,#-3\]'
[^:]*:131: Error: r15 not allowed here -- `ldrh pc,\[r0\],#4'
[^:]*:132: Error: r13 not allowed here -- `ldrh sp,\[r0\],#4'
[^:]*:133: Error: r15 not allowed here -- `ldrh pc,\[r0,#4\]!'
[^:]*:134: Error: r13 not allowed here -- `ldrh sp,\[r0,#4\]!'
[^:]*:137: Error: r15 not allowed here -- `ldrh pc,label'
[^:]*:138: Error: r15 not allowed here -- `ldrh pc,\[pc,#-0\]'
[^:]*:139: Error: r13 not allowed here -- `ldrh sp,label'
[^:]*:140: Error: r13 not allowed here -- `ldrh sp,\[pc,#-0\]'
[^:]*:143: Error: r15 not allowed here -- `ldrh pc,\[r0,r1\]'
[^:]*:144: Error: cannot use register index with PC-relative addressing -- `ldrh r0,\[pc,r1\]'
[^:]*:145: Error: r15 not allowed here -- `ldrh r0,\[r1,pc\]'
[^:]*:146: Error: r15 not allowed here -- `ldrh.w pc,\[r0,r1,LSL#1\]'
[^:]*:147: Error: r13 not allowed here -- `ldrh.w sp,\[r0,r1,LSL#1\]'
[^:]*:148: Error: r15 not allowed here -- `ldrh.w r2,\[r0,pc,LSL#1\]'
[^:]*:149: Error: r13 not allowed here -- `ldrh.w r2,\[r0,sp,LSL#1\]'
[^:]*:152: Error: r15 not allowed here -- `ldrht pc,\[r0,#4\]'
[^:]*:153: Error: r13 not allowed here -- `ldrht sp,\[r0,#4\]'
[^:]*:156: Error: r15 not allowed here -- `ldrsb pc,\[r0,#4\]'
[^:]*:158: Error: r13 not allowed here -- `ldrsb sp,\[r0,#4\]'
[^:]*:159: Error: r15 not allowed here -- `ldrsb pc,\[r0,#-4\]'
[^:]*:160: Error: r13 not allowed here -- `ldrsb sp,\[r0,#-4\]'
[^:]*:161: Error: r15 not allowed here -- `ldrsb pc,\[r0\],#4'
[^:]*:162: Error: r13 not allowed here -- `ldrsb sp,\[r0\],#4'
[^:]*:163: Error: r15 not allowed here -- `ldrsb pc,\[r0,#4\]!'
[^:]*:164: Error: r13 not allowed here -- `ldrsb sp,\[r0,#4\]!'
[^:]*:167: Error: r15 not allowed here -- `ldrsb pc,label'
[^:]*:168: Error: r15 not allowed here -- `ldrsb pc,\[pc,#-0\]'
[^:]*:169: Error: r13 not allowed here -- `ldrsb sp,label'
[^:]*:170: Error: r13 not allowed here -- `ldrsb sp,\[pc,#-0\]'
[^:]*:173: Error: r15 not allowed here -- `ldrsb pc,\[r0,r1\]'
[^:]*:174: Error: cannot use register index with PC-relative addressing -- `ldrsb r0,\[pc,r1\]'
[^:]*:175: Error: r15 not allowed here -- `ldrsb r0,\[r1,pc\]'
[^:]*:176: Error: r15 not allowed here -- `ldrsb.w pc,\[r0,r1,LSL#2\]'
[^:]*:178: Error: r13 not allowed here -- `ldrsb.w sp,\[r0,r1,LSL#2\]'
[^:]*:179: Error: r15 not allowed here -- `ldrsb.w r2,\[r0,pc,LSL#2\]'
[^:]*:180: Error: r13 not allowed here -- `ldrsb.w r2,\[r0,sp,LSL#2\]'
[^:]*:184: Error: r15 not allowed here -- `ldrsbt pc,\[r0,#4\]'
[^:]*:185: Error: r13 not allowed here -- `ldrsbt sp,\[r0,#4\]'
[^:]*:189: Error: r15 not allowed here -- `ldrsh pc,\[r0,#4\]'
[^:]*:190: Error: r13 not allowed here -- `ldrsh sp,\[r0,#4\]'
[^:]*:191: Error: r15 not allowed here -- `ldrsh pc,\[r0,#-4\]'
[^:]*:192: Error: r15 not allowed here -- `ldrsh pc,\[r0\],#4'
[^:]*:193: Error: r15 not allowed here -- `ldrsh pc,\[r0,#4\]!'
[^:]*:194: Error: r13 not allowed here -- `ldrsh sp,\[r0,#-4\]'
[^:]*:195: Error: r13 not allowed here -- `ldrsh sp,\[r0\],#4'
[^:]*:196: Error: r13 not allowed here -- `ldrsh sp,\[r0,#4\]!'
[^:]*:199: Error: r15 not allowed here -- `ldrsh pc,label'
[^:]*:200: Error: r13 not allowed here -- `ldrsh sp,label'
[^:]*:201: Error: r13 not allowed here -- `ldrsh sp,\[pc,#-0\]'
[^:]*:204: Error: r15 not allowed here -- `ldrsh pc,\[r0,r1\]'
[^:]*:205: Error: cannot use register index with PC-relative addressing -- `ldrsh r0,\[pc,r1\]'
[^:]*:206: Error: r15 not allowed here -- `ldrsh r0,\[r1,pc\]'
[^:]*:208: Error: r15 not allowed here -- `ldrsh.w pc,\[r0,r1,LSL#3\]'
[^:]*:209: Error: r13 not allowed here -- `ldrsh.w sp,\[r0,r1,LSL#3\]'
[^:]*:210: Error: r13 not allowed here -- `ldrsh.w r0,\[r1,sp,LSL#3\]'
[^:]*:211: Error: r15 not allowed here -- `ldrsh.w r0,\[r1,pc,LSL#3\]'
[^:]*:215: Error: r15 not allowed here -- `ldrsht pc,\[r0,#4\]'
[^:]*:216: Error: r13 not allowed here -- `ldrsht sp,\[r0,#4\]'
[^:]*:220: Error: r15 not allowed here -- `ldrt pc,\[r0,#4\]'
[^:]*:221: Error: r13 not allowed here -- `ldrt sp,\[r0,#4\]'
[^:]*:226: Error: r15 not allowed here -- `str pc,\[r0,#4\]'
[^:]*:227: Error: cannot use register index with PC-relative addressing -- `str.w r0,\[pc,#4\]'
[^:]*:228: Error: cannot use register index with PC-relative addressing -- `str r0,\[pc,#-4\]'
[^:]*:229: Error: cannot use post-indexing with PC-relative addressing -- `str r0,\[pc\],#4'
[^:]*:230: Error: cannot use writeback with PC-relative addressing -- `str r0,\[pc,#4\]!'
[^:]*:233: Error: cannot use register index with PC-relative addressing -- `str.w r0,\[pc,r1\]'
[^:]*:234: Error: cannot use register index with PC-relative addressing -- `str.w r0,\[pc,r1,LSL#2\]'
[^:]*:240: Error: cannot use register index with PC-relative addressing -- `strb.w r0,\[pc,#4\]'
[^:]*:241: Error: r15 not allowed here -- `strb.w pc,\[r0,#4\]'
[^:]*:242: Error: r13 not allowed here -- `strb.w sp,\[r0,#4\]'
[^:]*:243: Error: cannot use register index with PC-relative addressing -- `strb r0,\[pc,#-4\]'
[^:]*:244: Error: cannot use post-indexing with PC-relative addressing -- `strb r0,\[pc\],#4'
[^:]*:245: Error: cannot use writeback with PC-relative addressing -- `strb r0,\[pc,#4\]!'
[^:]*:246: Error: r15 not allowed here -- `strb pc,\[r0,#-4\]'
[^:]*:247: Error: r15 not allowed here -- `strb pc,\[r0\],#4'
[^:]*:248: Error: r15 not allowed here -- `strb pc,\[r0,#4\]!'
[^:]*:249: Error: r13 not allowed here -- `strb sp,\[r0,#-4\]'
[^:]*:250: Error: r13 not allowed here -- `strb sp,\[r0\],#4'
[^:]*:251: Error: r13 not allowed here -- `strb sp,\[r0,#4\]!'
[^:]*:254: Error: cannot use register index with PC-relative addressing -- `strb.w r0,\[pc,r1\]'
[^:]*:255: Error: cannot use register index with PC-relative addressing -- `strb.w r0,\[pc,r1,LSL#2\]'
[^:]*:256: Error: r15 not allowed here -- `strb.w pc,\[r0,r1\]'
[^:]*:257: Error: r15 not allowed here -- `strb.w pc,\[r0,r1,LSL#2\]'
[^:]*:258: Error: r13 not allowed here -- `strb.w sp,\[r0,r1\]'
[^:]*:259: Error: r13 not allowed here -- `strb.w sp,\[r0,r1,LSL#2\]'
[^:]*:260: Error: r15 not allowed here -- `strb.w r0,\[r1,pc\]'
[^:]*:261: Error: r15 not allowed here -- `strb.w r0,\[r1,pc,LSL#2\]'
[^:]*:262: Error: r13 not allowed here -- `strb.w r0,\[r1,sp\]'
[^:]*:263: Error: r13 not allowed here -- `strb.w r0,\[r1,sp,LSL#2\]'
[^:]*:266: Error: cannot use register index with PC-relative addressing -- `strbt r0,\[pc,#4\]'
[^:]*:267: Error: r15 not allowed here -- `strbt pc,\[r0,#4\]'
[^:]*:268: Error: r13 not allowed here -- `strbt sp,\[r0,#4\]'
[^:]*:271: Error: cannot use register index with PC-relative addressing -- `strd r0,r1,\[pc,#4\]'
[^:]*:272: Error: cannot use post-indexing with PC-relative addressing -- `strd r0,r1,\[pc\],#4'
[^:]*:273: Error: cannot use writeback with PC-relative addressing -- `strd r0,r1,\[pc,#4\]!'
[^:]*:274: Error: r15 not allowed here -- `strd pc,r0,\[r1,#4\]'
[^:]*:275: Error: r15 not allowed here -- `strd pc,r0,\[r1\],#4'
[^:]*:276: Error: r15 not allowed here -- `strd pc,r0,\[r1,#4\]!'
[^:]*:277: Error: r13 not allowed here -- `strd sp,r0,\[r1,#4\]'
[^:]*:278: Error: r13 not allowed here -- `strd sp,r0,\[r1\],#4'
[^:]*:279: Error: r13 not allowed here -- `strd sp,r0,\[r1,#4\]!'
[^:]*:280: Error: r15 not allowed here -- `strd r0,pc,\[r1,#4\]'
[^:]*:281: Error: r15 not allowed here -- `strd r0,pc,\[r1\],#4'
[^:]*:282: Error: r15 not allowed here -- `strd r0,pc,\[r1,#4\]!'
[^:]*:283: Error: r13 not allowed here -- `strd r0,sp,\[r1,#4\]'
[^:]*:284: Error: r13 not allowed here -- `strd r0,sp,\[r1\],#4'
[^:]*:285: Error: r13 not allowed here -- `strd r0,sp,\[r1,#4\]!'
[^:]*:291: Error: r15 not allowed here -- `strex pc,r0,\[r1\]'
[^:]*:292: Error: r15 not allowed here -- `strex pc,r0,\[r1,#4\]'
[^:]*:293: Error: r13 not allowed here -- `strex sp,r0,\[r1\]'
[^:]*:294: Error: r13 not allowed here -- `strex sp,r0,\[r1,#4\]'
[^:]*:295: Error: r15 not allowed here -- `strex r0,pc,\[r1\]'
[^:]*:296: Error: r15 not allowed here -- `strex r0,pc,\[r1,#4\]'
[^:]*:297: Error: r13 not allowed here -- `strex r0,sp,\[r1\]'
[^:]*:298: Error: r13 not allowed here -- `strex r0,sp,\[r1,#4\]'
[^:]*:299: Error: r15 not allowed here -- `strex r0,r1,\[pc\]'
[^:]*:300: Error: r15 not allowed here -- `strex r0,r1,\[pc,#4\]'
[^:]*:303: Error: r15 not allowed here -- `strexb pc,r0,\[r1\]'
[^:]*:304: Error: r13 not allowed here -- `strexb sp,r0,\[r1\]'
[^:]*:305: Error: r15 not allowed here -- `strexb r0,pc,\[r1\]'
[^:]*:306: Error: r13 not allowed here -- `strexb r0,sp,\[r1\]'
[^:]*:307: Error: r15 not allowed here -- `strexb r0,r1,\[pc\]'
[^:]*:310: Error: r15 not allowed here -- `strexd pc,r0,r1,\[r2\]'
[^:]*:311: Error: r13 not allowed here -- `strexd sp,r0,r1,\[r2\]'
[^:]*:312: Error: r15 not allowed here -- `strexd r0,pc,r1,\[r2\]'
[^:]*:313: Error: r13 not allowed here -- `strexd r0,sp,r1,\[r2\]'
[^:]*:314: Error: r15 not allowed here -- `strexd r0,r1,pc,\[r2\]'
[^:]*:315: Error: r13 not allowed here -- `strexd r0,r1,sp,\[r2\]'
[^:]*:316: Error: r15 not allowed here -- `strexd r0,r1,r2,\[pc\]'
[^:]*:319: Error: r15 not allowed here -- `strexh pc,r0,\[r1\]'
[^:]*:320: Error: r13 not allowed here -- `strexh sp,r0,\[r1\]'
[^:]*:321: Error: r15 not allowed here -- `strexh r0,pc,\[r1\]'
[^:]*:322: Error: r13 not allowed here -- `strexh r0,sp,\[r1\]'
[^:]*:323: Error: r15 not allowed here -- `strexh r0,r1,\[pc\]'
[^:]*:326: Error: cannot use register index with PC-relative addressing -- `strh.w r0,\[pc\]'
[^:]*:327: Error: cannot use register index with PC-relative addressing -- `strh.w r0,\[pc,#4\]'
[^:]*:328: Error: cannot use register index with PC-relative addressing -- `strh r0,\[pc,#-4\]'
[^:]*:329: Error: cannot use post-indexing with PC-relative addressing -- `strh r0,\[pc\],#4'
[^:]*:330: Error: cannot use writeback with PC-relative addressing -- `strh r0,\[pc,#4\]!'
[^:]*:333: Error: cannot use register index with PC-relative addressing -- `strh.w r0,\[pc,r1\]'
[^:]*:334: Error: cannot use register index with PC-relative addressing -- `strh.w r0,\[pc,r1,LSL#2\]'
[^:]*:335: Error: r15 not allowed here -- `strh.w pc,\[r0,#4\]'
[^:]*:336: Error: r15 not allowed here -- `strh.w pc,\[r0\]'
[^:]*:337: Error: r13 not allowed here -- `strh.w sp,\[r0,#4\]'
[^:]*:338: Error: r13 not allowed here -- `strh.w sp,\[r0\]'
[^:]*:339: Error: r15 not allowed here -- `strh pc,\[r0,#-4\]'
[^:]*:340: Error: r15 not allowed here -- `strh pc,\[r0\],#4'
[^:]*:341: Error: r15 not allowed here -- `strh pc,\[r0,#4\]!'
[^:]*:342: Error: r13 not allowed here -- `strh sp,\[r0,#-4\]'
[^:]*:343: Error: r13 not allowed here -- `strh sp,\[r0\],#4'
[^:]*:344: Error: r13 not allowed here -- `strh sp,\[r0,#4\]!'
[^:]*:345: Error: r15 not allowed here -- `strh.w pc,\[r0,r1\]'
[^:]*:346: Error: r13 not allowed here -- `strh.w sp,\[r0,r1\]'
[^:]*:347: Error: r15 not allowed here -- `strh.w r0,\[r1,pc\]'
[^:]*:348: Error: r13 not allowed here -- `strh.w r0,\[r1,sp\]'
[^:]*:349: Error: r15 not allowed here -- `strh.w pc,\[r0,r1,LSL#2\]'
[^:]*:350: Error: r13 not allowed here -- `strh.w sp,\[r0,r1,LSL#2\]'
[^:]*:351: Error: r15 not allowed here -- `strh.w r0,\[r1,pc,LSL#2\]'
[^:]*:352: Error: r13 not allowed here -- `strh.w r0,\[r1,sp,LSL#2\]'
[^:]*:355: Error: cannot use register index with PC-relative addressing -- `strht r0,\[pc,#4\]'
[^:]*:356: Error: r15 not allowed here -- `strht pc,\[r0,#4\]'
[^:]*:357: Error: r13 not allowed here -- `strht sp,\[pc,#4\]'
[^:]*:360: Error: cannot use register index with PC-relative addressing -- `strt r0,\[pc,#4\]'
[^:]*:361: Error: r15 not allowed here -- `strt pc,\[r0,#4\]'
[^:]*:362: Error: r13 not allowed here -- `strt sp,\[r0,#4\]'
