.*: Assembler messages:
.*:8: Error: Directive .atmp available only with -mintel-syntax option
.*:8: Error: junk at end of line, first unrecognized character is `r'
.*:10: Error: Directive .dual available only with -mintel-syntax option
.*:13: Error: Directive .enddual available only with -mintel-syntax option
