[^:]*: Assembler messages:
[^:]*:5: Error: unknown opcode 'nonesuch'
[^:]*:6: Error: operand 1 of 'nop' not constant
[^:]*:7: Error: too many operands to 'nop'
[^:]*:8: Error: too many operands to 'nop'
[^:]*:9: Error: too many operands to 'nop'
[^:]*:10: Error: junk after operand 1 of 'nop'
[^:]*:11: Error: operand 1 of 'nop' out of range
[^:]*:12: Error: operand 1 of 'nop' out of range
[^:]*:13: Error: operand 1 of 'nop' out of range
[^:]*:14: Error: operand 1 of 'nop' out of range
[^:]*:15: Error: operand 1 of 'nop' out of range
[^:]*:16: Error: missing operand after comma
[^:]*:17: Error: bad number of operands to 'abs'
[^:]*:18: Error: 'abs' instruction not supported on this functional unit
[^:]*:19: Error: bad register or register pair for operand 1 of 'abs'
[^:]*:19: Error: bad register or register pair for operand 2 of 'abs'
[^:]*:20: Error: bad register for operand 1 of 'abs'
[^:]*:20: Error: bad register for operand 2 of 'abs'
[^:]*:21: Error: bad register or register pair for operand 2 of 'abs'
[^:]*:22: Error: bad register or register pair for operand 1 of 'abs'
[^:]*:23: Error: operand 1 of 'abs' on wrong side
[^:]*:24: Error: operand 2 of 'abs' on wrong side
[^:]*:25: Error: operand 1 of 'abs' on wrong side
[^:]*:26: Error: operand 2 of 'abs' on wrong side
[^:]*:27: Error: operand 1 of 'abs' on wrong side
[^:]*:28: Error: operand 2 of 'abs' on wrong side
[^:]*:29: Error: operand 2 of 'abs' on wrong side
[^:]*:30: Error: operand 1 of 'abs' on wrong side
[^:]*:31: Error: register pair for operand 1 of 'abs' not a valid even/odd pair
[^:]*:32: Error: register pair for operand 2 of 'abs' not a valid even/odd pair
[^:]*:33: Error: register pair for operand 1 of 'abs' not a valid even/odd pair
[^:]*:33: Error: operand 1 of 'abs' on wrong side
[^:]*:34: Error: operand 2 of 'abs' on wrong side
[^:]*:35: Error: bad register for operand 1 of 'abs'
[^:]*:35: Error: bad register for operand 2 of 'abs'
[^:]*:36: Error: bad operand combination for 'abs'
[^:]*:37: Error: bad number of operands to 'abs2'
[^:]*:38: Error: 'abs2' instruction not supported on this functional unit
[^:]*:39: Error: bad register for operand 1 of 'abs2'
[^:]*:39: Error: bad register for operand 2 of 'abs2'
[^:]*:40: Error: operand 1 of 'abs2' on wrong side
[^:]*:41: Error: 'absdp' instruction not supported on this functional unit
[^:]*:42: Error: bad number of operands to 'absdp'
[^:]*:43: Error: bad register pair for operand 1 of 'absdp'
[^:]*:43: Error: bad register pair for operand 2 of 'absdp'
[^:]*:44: Error: 'absdp' instruction not supported on this functional unit
[^:]*:45: Error: 'abssp' instruction not supported on this functional unit
[^:]*:46: Error: bad register for operand 1 of 'abssp'
[^:]*:47: Error: operand 1 of 'abssp' on wrong side
[^:]*:48: Error: operand 1 of 'abssp' on wrong side
[^:]*:49: Error: 'add' instruction not supported on this functional unit
[^:]*:50: Error: operand 2 of 'add' on wrong side
[^:]*:51: Error: operand 2 of 'add' on wrong side
[^:]*:52: Error: junk after operand 1 of 'add'
[^:]*:53: Error: operand 1 of 'add' out of range
[^:]*:54: Error: operand 1 of 'add' out of range
[^:]*:55: Error: bad operand combination for 'add'
[^:]*:56: Error: operand 1 of 'add' out of range
[^:]*:57: Error: bad number of operands to 'add'
[^:]*:58: Error: bad register for operand 3 of 'add'
[^:]*:59: Error: bad number of operands to 'add'
[^:]*:60: Error: operand 2 of 'add' on wrong side
[^:]*:61: Error: operand 1 of 'add' out of range
[^:]*:62: Error: operand 1 of 'add' out of range
[^:]*:63: Error: 'add' instruction not supported on this functional unit
[^:]*:64: Error: bad number of operands to 'add'
[^:]*:65: Error: operand 2 of 'add' out of range
[^:]*:66: Error: operand 2 of 'add' out of range
[^:]*:67: Error: bad operand combination for 'add'
[^:]*:68: Error: operand 2 of 'add' out of range
[^:]*:69: Error: operand 2 of 'add' out of range
[^:]*:70: Error: 'addab' instruction not supported on this functional unit
[^:]*:71: Error: operand 1 of 'addab' on wrong side
[^:]*:72: Error: bad number of operands to 'addab'
[^:]*:73: Error: operand 1 of 'addab' on wrong side
[^:]*:74: Error: operand 2 of 'addab' out of range
[^:]*:75: Error: operand 2 of 'addab' out of range
[^:]*:76: Error: operand 2 of 'addab' out of range
[^:]*:77: Error: operand 2 of 'addab' out of range
[^:]*:78: Error: operand 2 of 'addab' out of range
[^:]*:79: Error: 'addad' instruction not supported on this functional unit
[^:]*:80: Error: 'addad' instruction not supported on this functional unit
[^:]*:81: Error: too many operands to 'addad'
[^:]*:82: Error: operand 2 of 'addad' out of range
[^:]*:83: Error: operand 2 of 'addad' out of range
[^:]*:84: Error: operand 2 of 'addad' on wrong side
[^:]*:85: Error: operand 2 of 'addad' not constant
[^:]*:86: Error: 'addah' instruction not supported on this functional unit
[^:]*:87: Error: operand 1 of 'addah' on wrong side
[^:]*:88: Error: bad number of operands to 'addah'
[^:]*:89: Error: operand 1 of 'addah' on wrong side
[^:]*:90: Error: operand 2 of 'addah' out of range
[^:]*:91: Error: operand 2 of 'addah' out of range
[^:]*:92: Error: operand 2 of 'addah' out of range
[^:]*:93: Error: operand 2 of 'addah' out of range
[^:]*:94: Error: operand 2 of 'addah' out of range
[^:]*:95: Error: 'addaw' instruction not supported on this functional unit
[^:]*:96: Error: operand 1 of 'addaw' on wrong side
[^:]*:97: Error: bad number of operands to 'addaw'
[^:]*:98: Error: operand 1 of 'addaw' on wrong side
[^:]*:99: Error: operand 2 of 'addaw' out of range
[^:]*:100: Error: operand 2 of 'addaw' out of range
[^:]*:101: Error: operand 2 of 'addaw' out of range
[^:]*:102: Error: operand 2 of 'addaw' out of range
[^:]*:103: Error: operand 2 of 'addaw' out of range
[^:]*:104: Error: 'adddp' instruction not supported on this functional unit
[^:]*:105: Error: bad number of operands to 'adddp'
[^:]*:106: Error: bad register pair for operand 1 of 'adddp'
[^:]*:106: Error: bad register pair for operand 2 of 'adddp'
[^:]*:106: Error: bad register pair for operand 3 of 'adddp'
[^:]*:107: Error: operand 2 of 'adddp' on wrong side
[^:]*:108: Error: operand 2 of 'adddp' on wrong side
[^:]*:109: Error: 'addk' instruction not supported on this functional unit
[^:]*:110: Error: operand 1 of 'addk' out of range
[^:]*:111: Error: operand 1 of 'addk' out of range
[^:]*:112: Error: bad number of operands to 'addk'
[^:]*:113: Error: 'addk' instruction not supported on this functional unit
[^:]*:114: Error: 'mvk' instruction not supported on this functional unit
[^:]*:115: Error: operand 1 of 'mvk' out of range
[^:]*:116: Error: operand 1 of 'mvk' out of range
[^:]*:117: Error: too many operands to 'mvk'
[^:]*:118: Error: 'mvk' instruction not supported on this functional unit
[^:]*:119: Error: 'mvkh' instruction not supported on this functional unit
[^:]*:120: Error: too many operands to 'mvkh'
[^:]*:121: Error: 'mvkh' instruction not supported on this functional unit
[^:]*:122: Error: 'mvklh' instruction not supported on this functional unit
[^:]*:123: Error: too many operands to 'mvklh'
[^:]*:124: Error: 'mvklh' instruction not supported on this functional unit
[^:]*:125: Error: 'mvkl' instruction not supported on this functional unit
[^:]*:126: Error: too many operands to 'mvkl'
[^:]*:127: Error: 'mvkl' instruction not supported on this functional unit
[^:]*:128: Error: 'addkpc' instruction not supported on this functional unit
[^:]*:129: Error: 'addkpc' instruction not supported on this functional unit
[^:]*:130: Error: invalid PC-relative operand
[^:]*:131: Error: bad number of operands to 'addkpc'
[^:]*:132: Error: operand 3 of 'addkpc' out of range
[^:]*:133: Error: operand 3 of 'addkpc' out of range
[^:]*:134: Error: 'b' instruction not supported on this functional unit
[^:]*:135: Error: 'b' instruction not supported on this functional unit
[^:]*:136: Error: too many operands to 'b'
[^:]*:137: Error: invalid PC-relative operand
[^:]*:138: Error: 'call' instruction not supported on this functional unit
[^:]*:139: Error: 'call' instruction not supported on this functional unit
[^:]*:140: Error: too many operands to 'call'
[^:]*:141: Error: invalid PC-relative operand
[^:]*:142: Error: 'bdec' instruction not supported on this functional unit
[^:]*:143: Error: 'bdec' instruction not supported on this functional unit
[^:]*:144: Error: operand 2 of 'bdec' on wrong side
[^:]*:145: Error: invalid PC-relative operand
[^:]*:146: Error: too many operands to 'bdec'
[^:]*:147: Error: 'bpos' instruction not supported on this functional unit
[^:]*:148: Error: 'bpos' instruction not supported on this functional unit
[^:]*:149: Error: operand 2 of 'bpos' on wrong side
[^:]*:150: Error: invalid PC-relative operand
[^:]*:151: Error: too many operands to 'bpos'
[^:]*:152: Error: 'bnop' instruction not supported on this functional unit
[^:]*:153: Error: 'bnop' instruction not supported on this functional unit
[^:]*:154: Error: operand 2 of 'bnop' out of range
[^:]*:155: Error: invalid PC-relative operand
[^:]*:156: Error: operand 2 of 'bnop' out of range
[^:]*:157: Error: 'callnop' instruction not supported on this functional unit
[^:]*:158: Error: 'callnop' instruction not supported on this functional unit
[^:]*:159: Error: operand 2 of 'callnop' out of range
[^:]*:160: Error: invalid PC-relative operand
[^:]*:161: Error: operand 2 of 'callnop' out of range
[^:]*:162: Error: 'callp' instruction not supported on this functional unit
[^:]*:163: Error: 'callp' instruction not supported on this functional unit
[^:]*:164: Error: operand 2 of 'callp' not a valid return address register
[^:]*:165: Error: invalid PC-relative operand
[^:]*:166: Error: operand 2 of 'callp' on wrong side
[^:]*:167: Error: operand 2 of 'callp' on wrong side
[^:]*:168: Error: 'addsp' instruction not supported on this functional unit
[^:]*:169: Error: bad number of operands to 'addsp'
[^:]*:170: Error: bad register for operand 2 of 'addsp'
[^:]*:171: Error: operand 1 of 'addsp' on wrong side
[^:]*:172: Error: operand 2 of 'addsp' on wrong side
[^:]*:173: Error: 'addsub' instruction not supported on this functional unit
[^:]*:174: Error: bad number of operands to 'addsub'
[^:]*:175: Error: bad register pair for operand 3 of 'addsub'
[^:]*:176: Error: operand 1 of 'addsub' on wrong side
[^:]*:177: Error: 'addsub2' instruction not supported on this functional unit
[^:]*:178: Error: bad number of operands to 'addsub2'
[^:]*:179: Error: bad register pair for operand 3 of 'addsub2'
[^:]*:180: Error: operand 1 of 'addsub2' on wrong side
[^:]*:181: Error: 'addu' instruction not supported on this functional unit
[^:]*:182: Error: bad number of operands to 'addu'
[^:]*:183: Error: operand 1 of 'addu' on wrong side
[^:]*:184: Error: bad register pair for operand 3 of 'addu'
[^:]*:185: Error: 'add2' instruction not supported on this functional unit
[^:]*:186: Error: too many operands to 'add2'
[^:]*:187: Error: operand 1 of 'add2' on wrong side
[^:]*:188: Error: operand 2 of 'add2' on wrong side
[^:]*:189: Error: 'add4' instruction not supported on this functional unit
[^:]*:190: Error: too many operands to 'add4'
[^:]*:191: Error: operand 1 of 'add4' on wrong side
[^:]*:192: Error: operand 2 of 'add4' on wrong side
[^:]*:193: Error: 'and' instruction not supported on this functional unit
[^:]*:194: Error: operand 1 of 'and' out of range
[^:]*:195: Error: operand 1 of 'and' out of range
[^:]*:196: Error: operand 1 of 'and' out of range
[^:]*:197: Error: operand 1 of 'and' out of range
[^:]*:198: Error: operand 1 of 'and' out of range
[^:]*:199: Error: operand 1 of 'and' out of range
[^:]*:200: Error: operand 1 of 'and' on wrong side
[^:]*:201: Error: 'andn' instruction not supported on this functional unit
[^:]*:202: Error: bad number of operands to 'andn'
[^:]*:203: Error: operand 1 of 'andn' on wrong side
[^:]*:204: Error: bad register for operand 1 of 'andn'
[^:]*:205: Error: 'avg2' instruction not supported on this functional unit
[^:]*:206: Error: bad number of operands to 'avg2'
[^:]*:207: Error: operand 1 of 'avg2' on wrong side
[^:]*:208: Error: operand 1 of 'avg2' on wrong side
[^:]*:209: Error: 'avgu4' instruction not supported on this functional unit
[^:]*:210: Error: bad number of operands to 'avgu4'
[^:]*:211: Error: operand 1 of 'avgu4' on wrong side
[^:]*:212: Error: operand 1 of 'avgu4' on wrong side
[^:]*:213: Error: 'b' instruction not supported on this functional unit
[^:]*:214: Error: too many operands to 'b'
[^:]*:215: Error: 'call' instruction not supported on this functional unit
[^:]*:216: Error: too many operands to 'call'
[^:]*:217: Error: 'callret' instruction not supported on this functional unit
[^:]*:218: Error: too many operands to 'callret'
[^:]*:219: Error: 'ret' instruction not supported on this functional unit
[^:]*:220: Error: too many operands to 'ret'
[^:]*:221: Error: bad register for operand 1 of 'b'
[^:]*:222: Error: 'b' instruction not supported on this functional unit
[^:]*:223: Error: bad register for operand 1 of 'b'
[^:]*:224: Error: 'b' instruction not supported on this functional unit
[^:]*:225: Error: too many operands to 'bitc4'
[^:]*:226: Error: 'bitc4' instruction not supported on this functional unit
[^:]*:227: Error: operand 2 of 'bitc4' on wrong side
[^:]*:228: Error: operand 1 of 'bitc4' on wrong side
[^:]*:229: Error: bad number of operands to 'bitr'
[^:]*:230: Error: 'bitr' instruction not supported on this functional unit
[^:]*:231: Error: operand 2 of 'bitr' on wrong side
[^:]*:232: Error: operand 1 of 'bitr' on wrong side
[^:]*:233: Error: 'bnop' instruction not supported on this functional unit
[^:]*:234: Error: 'bnop' instruction not supported on this functional unit
[^:]*:235: Error: operand 2 of 'bnop' out of range
[^:]*:236: Error: operand 2 of 'bnop' out of range
[^:]*:237: Error: bad number of operands to 'bnop'
[^:]*:238: Error: 'callnop' instruction not supported on this functional unit
[^:]*:239: Error: 'callnop' instruction not supported on this functional unit
[^:]*:240: Error: operand 2 of 'callnop' out of range
[^:]*:241: Error: operand 2 of 'callnop' out of range
[^:]*:242: Error: bad number of operands to 'callnop'
[^:]*:243: Error: 'clr' instruction not supported on this functional unit
[^:]*:244: Error: 'clr' instruction not supported on this functional unit
[^:]*:245: Error: bad number of operands to 'clr'
[^:]*:246: Error: bad register for operand 2 of 'clr'
[^:]*:246: Error: bad register for operand 3 of 'clr'
[^:]*:246: Error: too many operands to 'clr'
[^:]*:247: Error: operand 2 of 'clr' on wrong side
[^:]*:248: Error: 'cmpeq' instruction not supported on this functional unit
[^:]*:249: Error: too many operands to 'cmpeq'
[^:]*:250: Error: junk after operand 1 of 'cmpeq'
[^:]*:251: Error: operand 1 of 'cmpeq' out of range
[^:]*:252: Error: operand 1 of 'cmpeq' out of range
[^:]*:253: Error: operand 1 of 'cmpeq' out of range
[^:]*:254: Error: operand 1 of 'cmpeq' out of range
[^:]*:255: Error: bad operand combination for 'cmpeq'
[^:]*:256: Error: 'cmpeq2' instruction not supported on this functional unit
[^:]*:257: Error: bad number of operands to 'cmpeq2'
[^:]*:258: Error: operand 2 of 'cmpeq2' on wrong side
[^:]*:259: Error: operand 2 of 'cmpeq2' on wrong side
[^:]*:260: Error: 'cmpeq4' instruction not supported on this functional unit
[^:]*:261: Error: bad number of operands to 'cmpeq4'
[^:]*:262: Error: operand 1 of 'cmpeq4' on wrong side
[^:]*:263: Error: operand 2 of 'cmpeq4' on wrong side
[^:]*:264: Error: 'cmpeqdp' instruction not supported on this functional unit
[^:]*:265: Error: bad number of operands to 'cmpeqdp'
[^:]*:266: Error: bad register pair for operand 1 of 'cmpeqdp'
[^:]*:266: Error: bad register pair for operand 2 of 'cmpeqdp'
[^:]*:267: Error: operand 1 of 'cmpeqdp' on wrong side
[^:]*:268: Error: operand 2 of 'cmpeqdp' on wrong side
[^:]*:269: Error: bad number of operands to 'cmpeqsp'
[^:]*:270: Error: 'cmpeqsp' instruction not supported on this functional unit
[^:]*:271: Error: operand 2 of 'cmpeqsp' on wrong side
[^:]*:272: Error: operand 1 of 'cmpeqsp' on wrong side
[^:]*:273: Error: 'cmpgt' instruction not supported on this functional unit
[^:]*:274: Error: too many operands to 'cmpgt'
[^:]*:275: Error: bad operand combination for 'cmpgt'
[^:]*:276: Error: operand 1 of 'cmpgt' out of range
[^:]*:277: Error: operand 1 of 'cmpgt' out of range
[^:]*:278: Error: operand 1 of 'cmpgt' out of range
[^:]*:279: Error: operand 1 of 'cmpgt' out of range
[^:]*:280: Error: bad operand combination for 'cmpgt'
[^:]*:281: Error: 'cmpgt2' instruction not supported on this functional unit
[^:]*:282: Error: bad number of operands to 'cmpgt2'
[^:]*:283: Error: operand 1 of 'cmpgt2' on wrong side
[^:]*:284: Error: operand 2 of 'cmpgt2' on wrong side
[^:]*:285: Error: 'cmpgtdp' instruction not supported on this functional unit
[^:]*:286: Error: bad number of operands to 'cmpgtdp'
[^:]*:287: Error: operand 1 of 'cmpgtdp' on wrong side
[^:]*:288: Error: operand 2 of 'cmpgtdp' on wrong side
[^:]*:289: Error: 'cmpgtsp' instruction not supported on this functional unit
[^:]*:290: Error: bad number of operands to 'cmpgtsp'
[^:]*:291: Error: operand 1 of 'cmpgtsp' on wrong side
[^:]*:292: Error: operand 2 of 'cmpgtsp' on wrong side
[^:]*:293: Error: 'cmpgtu' instruction not supported on this functional unit
[^:]*:294: Error: too many operands to 'cmpgtu'
[^:]*:295: Error: junk after operand 1 of 'cmpgtu'
[^:]*:296: Error: operand 1 of 'cmpgtu' out of range
[^:]*:297: Error: operand 1 of 'cmpgtu' out of range
[^:]*:298: Error: operand 1 of 'cmpgtu' out of range
[^:]*:299: Error: operand 1 of 'cmpgtu' out of range
[^:]*:300: Error: bad operand combination for 'cmpgtu'
[^:]*:301: Error: 'cmpgtu4' instruction not supported on this functional unit
[^:]*:302: Error: bad number of operands to 'cmpgtu4'
[^:]*:303: Error: operand 3 of 'cmpgtu4' on wrong side
[^:]*:304: Error: operand 2 of 'cmpgtu4' on wrong side
[^:]*:305: Error: 'cmplt' instruction not supported on this functional unit
[^:]*:306: Error: too many operands to 'cmplt'
[^:]*:307: Error: bad operand combination for 'cmplt'
[^:]*:308: Error: operand 1 of 'cmplt' out of range
[^:]*:309: Error: operand 1 of 'cmplt' out of range
[^:]*:310: Error: operand 1 of 'cmplt' out of range
[^:]*:311: Error: operand 1 of 'cmplt' out of range
[^:]*:312: Error: bad operand combination for 'cmplt'
[^:]*:313: Error: 'cmplt2' instruction not supported on this functional unit
[^:]*:314: Error: bad number of operands to 'cmplt2'
[^:]*:315: Error: operand 2 of 'cmplt2' on wrong side
[^:]*:316: Error: operand 1 of 'cmplt2' on wrong side
[^:]*:317: Error: 'cmpltdp' instruction not supported on this functional unit
[^:]*:318: Error: bad number of operands to 'cmpltdp'
[^:]*:319: Error: operand 1 of 'cmpltdp' on wrong side
[^:]*:320: Error: operand 2 of 'cmpltdp' on wrong side
[^:]*:321: Error: 'cmpltsp' instruction not supported on this functional unit
[^:]*:322: Error: bad number of operands to 'cmpltsp'
[^:]*:323: Error: operand 1 of 'cmpltsp' on wrong side
[^:]*:324: Error: operand 2 of 'cmpltsp' on wrong side
[^:]*:325: Error: 'cmpltu' instruction not supported on this functional unit
[^:]*:326: Error: too many operands to 'cmpltu'
[^:]*:327: Error: junk after operand 1 of 'cmpltu'
[^:]*:328: Error: operand 1 of 'cmpltu' out of range
[^:]*:329: Error: operand 1 of 'cmpltu' out of range
[^:]*:330: Error: operand 1 of 'cmpltu' out of range
[^:]*:331: Error: operand 1 of 'cmpltu' out of range
[^:]*:332: Error: bad operand combination for 'cmpltu'
[^:]*:333: Error: 'cmpltu4' instruction not supported on this functional unit
[^:]*:334: Error: bad number of operands to 'cmpltu4'
[^:]*:335: Error: operand 3 of 'cmpltu4' on wrong side
[^:]*:336: Error: operand 1 of 'cmpltu4' on wrong side
[^:]*:337: Error: 'cmpy' instruction not supported on this functional unit
[^:]*:338: Error: bad number of operands to 'cmpy'
[^:]*:339: Error: operand 1 of 'cmpy' on wrong side
[^:]*:340: Error: operand 2 of 'cmpy' on wrong side
[^:]*:341: Error: 'cmpyr' instruction not supported on this functional unit
[^:]*:342: Error: bad number of operands to 'cmpyr'
[^:]*:343: Error: operand 1 of 'cmpyr' on wrong side
[^:]*:344: Error: operand 2 of 'cmpyr' on wrong side
[^:]*:345: Error: 'cmpyr1' instruction not supported on this functional unit
[^:]*:346: Error: bad number of operands to 'cmpyr1'
[^:]*:347: Error: operand 1 of 'cmpyr1' on wrong side
[^:]*:348: Error: operand 2 of 'cmpyr1' on wrong side
[^:]*:349: Error: 'ddotp4' instruction not supported on this functional unit
[^:]*:350: Error: bad number of operands to 'ddotp4'
[^:]*:351: Error: operand 2 of 'ddotp4' on wrong side
[^:]*:352: Error: operand 1 of 'ddotp4' on wrong side
[^:]*:353: Error: 'ddotph2' instruction not supported on this functional unit
[^:]*:354: Error: bad number of operands to 'ddotph2'
[^:]*:355: Error: operand 2 of 'ddotph2' on wrong side
[^:]*:356: Error: operand 1 of 'ddotph2' on wrong side
[^:]*:357: Error: 'ddotph2r' instruction not supported on this functional unit
[^:]*:358: Error: bad number of operands to 'ddotph2r'
[^:]*:359: Error: operand 2 of 'ddotph2r' on wrong side
[^:]*:360: Error: operand 1 of 'ddotph2r' on wrong side
[^:]*:361: Error: 'ddotpl2' instruction not supported on this functional unit
[^:]*:362: Error: bad number of operands to 'ddotpl2'
[^:]*:363: Error: operand 2 of 'ddotpl2' on wrong side
[^:]*:364: Error: operand 1 of 'ddotpl2' on wrong side
[^:]*:365: Error: 'ddotpl2r' instruction not supported on this functional unit
[^:]*:366: Error: bad number of operands to 'ddotpl2r'
[^:]*:367: Error: operand 2 of 'ddotpl2r' on wrong side
[^:]*:368: Error: operand 1 of 'ddotpl2r' on wrong side
[^:]*:369: Error: 'deal' instruction not supported on this functional unit
[^:]*:370: Error: too many operands to 'deal'
[^:]*:371: Error: operand 2 of 'deal' on wrong side
[^:]*:372: Error: operand 1 of 'deal' on wrong side
[^:]*:373: Error: 'dint' instruction not supported on this functional unit
[^:]*:374: Error: too many operands to 'dint'
[^:]*:375: Error: 'dmv' instruction not supported on this functional unit
[^:]*:376: Error: bad number of operands to 'dmv'
[^:]*:377: Error: operand 1 of 'dmv' on wrong side
[^:]*:378: Error: operand 2 of 'dmv' on wrong side
[^:]*:379: Error: 'dotp2' instruction not supported on this functional unit
[^:]*:380: Error: bad number of operands to 'dotp2'
[^:]*:381: Error: operand 1 of 'dotp2' on wrong side
[^:]*:382: Error: operand 2 of 'dotp2' on wrong side
[^:]*:383: Error: operand 1 of 'dotp2' on wrong side
[^:]*:384: Error: operand 2 of 'dotp2' on wrong side
[^:]*:385: Error: 'dotpn2' instruction not supported on this functional unit
[^:]*:386: Error: bad number of operands to 'dotpn2'
[^:]*:387: Error: operand 1 of 'dotpn2' on wrong side
[^:]*:388: Error: operand 2 of 'dotpn2' on wrong side
[^:]*:389: Error: 'dotpnrsu2' instruction not supported on this functional unit
[^:]*:390: Error: bad number of operands to 'dotpnrsu2'
[^:]*:391: Error: operand 1 of 'dotpnrsu2' on wrong side
[^:]*:392: Error: operand 2 of 'dotpnrsu2' on wrong side
[^:]*:393: Error: 'dotpnrus2' instruction not supported on this functional unit
[^:]*:394: Error: bad number of operands to 'dotpnrus2'
[^:]*:395: Error: operand 2 of 'dotpnrus2' on wrong side
[^:]*:396: Error: operand 1 of 'dotpnrus2' on wrong side
[^:]*:397: Error: 'dotprsu2' instruction not supported on this functional unit
[^:]*:398: Error: bad number of operands to 'dotprsu2'
[^:]*:399: Error: operand 1 of 'dotprsu2' on wrong side
[^:]*:400: Error: operand 2 of 'dotprsu2' on wrong side
[^:]*:401: Error: 'dotprus2' instruction not supported on this functional unit
[^:]*:402: Error: bad number of operands to 'dotprus2'
[^:]*:403: Error: operand 2 of 'dotprus2' on wrong side
[^:]*:404: Error: operand 1 of 'dotprus2' on wrong side
[^:]*:405: Error: 'dotpsu4' instruction not supported on this functional unit
[^:]*:406: Error: bad number of operands to 'dotpsu4'
[^:]*:407: Error: operand 1 of 'dotpsu4' on wrong side
[^:]*:408: Error: operand 2 of 'dotpsu4' on wrong side
[^:]*:409: Error: 'dotpus4' instruction not supported on this functional unit
[^:]*:410: Error: bad number of operands to 'dotpus4'
[^:]*:411: Error: operand 2 of 'dotpus4' on wrong side
[^:]*:412: Error: operand 1 of 'dotpus4' on wrong side
[^:]*:413: Error: 'dotpu4' instruction not supported on this functional unit
[^:]*:414: Error: bad number of operands to 'dotpu4'
[^:]*:415: Error: operand 1 of 'dotpu4' on wrong side
[^:]*:416: Error: operand 2 of 'dotpu4' on wrong side
[^:]*:417: Error: 'dpack2' instruction not supported on this functional unit
[^:]*:418: Error: bad number of operands to 'dpack2'
[^:]*:419: Error: operand 3 of 'dpack2' on wrong side
[^:]*:420: Error: operand 2 of 'dpack2' on wrong side
[^:]*:421: Error: 'dpackx2' instruction not supported on this functional unit
[^:]*:422: Error: bad number of operands to 'dpackx2'
[^:]*:423: Error: operand 3 of 'dpackx2' on wrong side
[^:]*:424: Error: operand 2 of 'dpackx2' on wrong side
[^:]*:425: Error: 'dpint' instruction not supported on this functional unit
[^:]*:426: Error: 'dpint' instruction not supported on this functional unit
[^:]*:427: Error: operand 1 of 'dpint' on wrong side
[^:]*:428: Error: 'dpsp' instruction not supported on this functional unit
[^:]*:429: Error: 'dpsp' instruction not supported on this functional unit
[^:]*:430: Error: operand 1 of 'dpsp' on wrong side
[^:]*:431: Error: 'dptrunc' instruction not supported on this functional unit
[^:]*:432: Error: 'dptrunc' instruction not supported on this functional unit
[^:]*:433: Error: operand 1 of 'dptrunc' on wrong side
[^:]*:434: Error: 'ext' instruction not supported on this functional unit
[^:]*:435: Error: 'ext' instruction not supported on this functional unit
[^:]*:436: Error: bad number of operands to 'ext'
[^:]*:437: Error: bad register for operand 2 of 'ext'
[^:]*:437: Error: bad register for operand 3 of 'ext'
[^:]*:437: Error: too many operands to 'ext'
[^:]*:438: Error: operand 2 of 'ext' on wrong side
[^:]*:439: Error: operand 2 of 'clr' out of range
[^:]*:440: Error: operand 2 of 'clr' out of range
[^:]*:441: Error: operand 3 of 'clr' out of range
[^:]*:442: Error: operand 3 of 'clr' out of range
[^:]*:443: Error: operand 2 of 'ext' out of range
[^:]*:444: Error: operand 2 of 'ext' out of range
[^:]*:445: Error: operand 3 of 'ext' out of range
[^:]*:446: Error: operand 3 of 'ext' out of range
[^:]*:447: Error: 'extu' instruction not supported on this functional unit
[^:]*:448: Error: 'extu' instruction not supported on this functional unit
[^:]*:449: Error: bad number of operands to 'extu'
[^:]*:450: Error: bad register for operand 2 of 'extu'
[^:]*:450: Error: bad register for operand 3 of 'extu'
[^:]*:450: Error: too many operands to 'extu'
[^:]*:451: Error: operand 2 of 'extu' on wrong side
[^:]*:452: Error: operand 2 of 'extu' out of range
[^:]*:453: Error: operand 2 of 'extu' out of range
[^:]*:454: Error: operand 3 of 'extu' out of range
[^:]*:455: Error: operand 3 of 'extu' out of range
[^:]*:456: Error: 'gmpy' instruction not supported on this functional unit
[^:]*:457: Error: bad number of operands to 'gmpy'
[^:]*:458: Error: 'gmpy' instruction not supported on this functional unit
[^:]*:459: Error: operand 1 of 'gmpy' on wrong side
[^:]*:460: Error: 'gmpy4' instruction not supported on this functional unit
[^:]*:461: Error: too many operands to 'gmpy4'
[^:]*:462: Error: operand 1 of 'gmpy4' on wrong side
[^:]*:463: Error: operand 2 of 'gmpy4' on wrong side
[^:]*:464: Error: 'idle' instruction not supported on this functional unit
[^:]*:465: Error: too many operands to 'idle'
[^:]*:466: Error: 'intdp' instruction not supported on this functional unit
[^:]*:467: Error: bad number of operands to 'intdp'
[^:]*:468: Error: operand 2 of 'intdp' on wrong side
[^:]*:469: Error: operand 2 of 'intdp' on wrong side
[^:]*:470: Error: 'intdpu' instruction not supported on this functional unit
[^:]*:471: Error: bad number of operands to 'intdpu'
[^:]*:472: Error: operand 2 of 'intdpu' on wrong side
[^:]*:473: Error: operand 2 of 'intdpu' on wrong side
[^:]*:474: Error: 'intsp' instruction not supported on this functional unit
[^:]*:475: Error: bad number of operands to 'intsp'
[^:]*:476: Error: operand 2 of 'intsp' on wrong side
[^:]*:477: Error: operand 2 of 'intsp' on wrong side
[^:]*:478: Error: 'intspu' instruction not supported on this functional unit
[^:]*:479: Error: bad number of operands to 'intspu'
[^:]*:480: Error: operand 2 of 'intspu' on wrong side
[^:]*:481: Error: operand 2 of 'intspu' on wrong side
[^:]*:482: Error: 'cmtl' instruction not supported on this functional unit
[^:]*:483: Error: 'cmtl' instruction not supported on this functional unit
[^:]*:484: Error: 'cmtl' instruction not supported on this functional unit
[^:]*:485: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:486: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:487: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:488: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:489: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:490: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:491: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:492: Error: operand 1 of 'cmtl' not a valid memory reference
[^:]*:493: Error: operand 2 of 'cmtl' on wrong side
[^:]*:494: Error: 'll' instruction not supported on this functional unit
[^:]*:495: Error: 'll' instruction not supported on this functional unit
[^:]*:496: Error: 'll' instruction not supported on this functional unit
[^:]*:497: Error: operand 1 of 'll' not a valid memory reference
[^:]*:498: Error: operand 1 of 'll' not a valid memory reference
[^:]*:499: Error: operand 1 of 'll' not a valid memory reference
[^:]*:500: Error: operand 1 of 'll' not a valid memory reference
[^:]*:501: Error: operand 1 of 'll' not a valid memory reference
[^:]*:502: Error: operand 1 of 'll' not a valid memory reference
[^:]*:503: Error: operand 1 of 'll' not a valid memory reference
[^:]*:504: Error: operand 1 of 'll' not a valid memory reference
[^:]*:505: Error: operand 2 of 'll' on wrong side
[^:]*:506: Error: 'sl' instruction not supported on this functional unit
[^:]*:507: Error: 'sl' instruction not supported on this functional unit
[^:]*:508: Error: 'sl' instruction not supported on this functional unit
[^:]*:509: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:510: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:511: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:512: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:513: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:514: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:515: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:516: Error: operand 2 of 'sl' not a valid memory reference
[^:]*:517: Error: operand 1 of 'sl' on wrong side
[^:]*:518: Error: 'ldb' instruction not supported on this functional unit
[^:]*:519: Error: operand 2 of 'ldb' on wrong side
[^:]*:520: Error: operand 1 of 'ldb' not a valid memory reference
[^:]*:521: Error: operand 1 of 'ldb' not a valid memory reference
[^:]*:522: Error: operand 2 of 'ldb' on wrong side
[^:]*:523: Error: bad number of operands to 'ldb'
[^:]*:524: Error: operand 1 of 'ldb' not a valid memory reference
[^:]*:525: Error: bad operand 1 of 'ldb'
[^:]*:526: Error: bad operand 1 of 'ldb'
[^:]*:527: Error: offset in operand 1 of 'ldb' out of range
[^:]*:528: Error: offset in operand 1 of 'ldb' out of range
[^:]*:529: Error: offset in operand 1 of 'ldb' out of range
[^:]*:530: Error: offset in operand 1 of 'ldb' out of range
[^:]*:531: Error: operand 1 of 'ldb' not a valid memory reference
[^:]*:532: Error: operand 1 of 'ldb' not a valid memory reference
[^:]*:533: Error: 'ldbu' instruction not supported on this functional unit
[^:]*:534: Error: operand 2 of 'ldbu' on wrong side
[^:]*:535: Error: operand 1 of 'ldbu' not a valid memory reference
[^:]*:536: Error: operand 1 of 'ldbu' not a valid memory reference
[^:]*:537: Error: operand 2 of 'ldbu' on wrong side
[^:]*:538: Error: bad number of operands to 'ldbu'
[^:]*:539: Error: operand 1 of 'ldbu' not a valid memory reference
[^:]*:540: Error: bad operand 1 of 'ldbu'
[^:]*:541: Error: bad operand 1 of 'ldbu'
[^:]*:542: Error: offset in operand 1 of 'ldbu' out of range
[^:]*:543: Error: offset in operand 1 of 'ldbu' out of range
[^:]*:544: Error: offset in operand 1 of 'ldbu' out of range
[^:]*:545: Error: offset in operand 1 of 'ldbu' out of range
[^:]*:546: Error: operand 1 of 'ldbu' not a valid memory reference
[^:]*:547: Error: operand 1 of 'ldbu' not a valid memory reference
[^:]*:548: Error: 'lddw' instruction not supported on this functional unit
[^:]*:549: Error: operand 2 of 'lddw' on wrong side
[^:]*:550: Error: operand 1 of 'lddw' not a valid memory reference
[^:]*:551: Error: operand 1 of 'lddw' not a valid memory reference
[^:]*:552: Error: operand 2 of 'lddw' on wrong side
[^:]*:553: Error: bad number of operands to 'lddw'
[^:]*:554: Error: operand 1 of 'lddw' not a valid memory reference
[^:]*:555: Error: bad operand 1 of 'lddw'
[^:]*:556: Error: bad operand 1 of 'lddw'
[^:]*:557: Error: offset in operand 1 of 'lddw' out of range
[^:]*:558: Error: offset in operand 1 of 'lddw' out of range
[^:]*:559: Error: offset in operand 1 of 'lddw' out of range
[^:]*:560: Error: offset in operand 1 of 'lddw' out of range
[^:]*:561: Error: operand 1 of 'lddw' not a valid memory reference
[^:]*:562: Error: operand 1 of 'lddw' not a valid memory reference
[^:]*:563: Error: offset in operand 1 of 'lddw' not divisible by 8
[^:]*:564: Error: operand 1 of 'lddw' not a valid memory reference
[^:]*:565: Error: 'ldh' instruction not supported on this functional unit
[^:]*:566: Error: operand 2 of 'ldh' on wrong side
[^:]*:567: Error: operand 1 of 'ldh' not a valid memory reference
[^:]*:568: Error: operand 1 of 'ldh' not a valid memory reference
[^:]*:569: Error: operand 2 of 'ldh' on wrong side
[^:]*:570: Error: bad number of operands to 'ldh'
[^:]*:571: Error: operand 1 of 'ldh' not a valid memory reference
[^:]*:572: Error: bad operand 1 of 'ldh'
[^:]*:573: Error: bad operand 1 of 'ldh'
[^:]*:574: Error: offset in operand 1 of 'ldh' out of range
[^:]*:575: Error: offset in operand 1 of 'ldh' out of range
[^:]*:576: Error: offset in operand 1 of 'ldh' out of range
[^:]*:577: Error: offset in operand 1 of 'ldh' out of range
[^:]*:578: Error: operand 1 of 'ldh' not a valid memory reference
[^:]*:579: Error: operand 1 of 'ldh' not a valid memory reference
[^:]*:580: Error: offset in operand 1 of 'ldh' not divisible by 2
[^:]*:581: Error: 'ldhu' instruction not supported on this functional unit
[^:]*:582: Error: operand 2 of 'ldhu' on wrong side
[^:]*:583: Error: operand 1 of 'ldhu' not a valid memory reference
[^:]*:584: Error: operand 1 of 'ldhu' not a valid memory reference
[^:]*:585: Error: operand 2 of 'ldhu' on wrong side
[^:]*:586: Error: bad number of operands to 'ldhu'
[^:]*:587: Error: operand 1 of 'ldhu' not a valid memory reference
[^:]*:588: Error: bad operand 1 of 'ldhu'
[^:]*:589: Error: bad operand 1 of 'ldhu'
[^:]*:590: Error: offset in operand 1 of 'ldhu' out of range
[^:]*:591: Error: offset in operand 1 of 'ldhu' out of range
[^:]*:592: Error: offset in operand 1 of 'ldhu' out of range
[^:]*:593: Error: offset in operand 1 of 'ldhu' out of range
[^:]*:594: Error: operand 1 of 'ldhu' not a valid memory reference
[^:]*:595: Error: operand 1 of 'ldhu' not a valid memory reference
[^:]*:596: Error: offset in operand 1 of 'ldhu' not divisible by 2
[^:]*:597: Error: 'ldndw' instruction not supported on this functional unit
[^:]*:598: Error: operand 2 of 'ldndw' on wrong side
[^:]*:599: Error: operand 1 of 'ldndw' not a valid memory reference
[^:]*:600: Error: operand 1 of 'ldndw' not a valid memory reference
[^:]*:601: Error: operand 2 of 'ldndw' on wrong side
[^:]*:602: Error: bad number of operands to 'ldndw'
[^:]*:603: Error: operand 1 of 'ldndw' not a valid memory reference
[^:]*:604: Error: bad operand 1 of 'ldndw'
[^:]*:605: Error: bad operand 1 of 'ldndw'
[^:]*:606: Error: offset in operand 1 of 'ldndw' out of range
[^:]*:607: Error: offset in operand 1 of 'ldndw' out of range
[^:]*:608: Error: offset in operand 1 of 'ldndw' out of range
[^:]*:609: Error: offset in operand 1 of 'ldndw' out of range
[^:]*:610: Error: operand 1 of 'ldndw' not a valid memory reference
[^:]*:611: Error: 'ldnw' instruction not supported on this functional unit
[^:]*:612: Error: operand 2 of 'ldnw' on wrong side
[^:]*:613: Error: operand 1 of 'ldnw' not a valid memory reference
[^:]*:614: Error: operand 1 of 'ldnw' not a valid memory reference
[^:]*:615: Error: operand 2 of 'ldnw' on wrong side
[^:]*:616: Error: bad number of operands to 'ldnw'
[^:]*:617: Error: operand 1 of 'ldnw' not a valid memory reference
[^:]*:618: Error: bad operand 1 of 'ldnw'
[^:]*:619: Error: bad operand 1 of 'ldnw'
[^:]*:620: Error: offset in operand 1 of 'ldnw' out of range
[^:]*:621: Error: offset in operand 1 of 'ldnw' out of range
[^:]*:622: Error: offset in operand 1 of 'ldnw' out of range
[^:]*:623: Error: offset in operand 1 of 'ldnw' out of range
[^:]*:624: Error: operand 1 of 'ldnw' not a valid memory reference
[^:]*:625: Error: operand 1 of 'ldnw' not a valid memory reference
[^:]*:626: Error: offset in operand 1 of 'ldnw' not divisible by 4
[^:]*:627: Error: 'ldw' instruction not supported on this functional unit
[^:]*:628: Error: operand 2 of 'ldw' on wrong side
[^:]*:629: Error: operand 1 of 'ldw' not a valid memory reference
[^:]*:630: Error: operand 1 of 'ldw' not a valid memory reference
[^:]*:631: Error: operand 2 of 'ldw' on wrong side
[^:]*:632: Error: bad number of operands to 'ldw'
[^:]*:633: Error: operand 1 of 'ldw' not a valid memory reference
[^:]*:634: Error: bad operand 1 of 'ldw'
[^:]*:635: Error: bad operand 1 of 'ldw'
[^:]*:636: Error: offset in operand 1 of 'ldw' out of range
[^:]*:637: Error: offset in operand 1 of 'ldw' out of range
[^:]*:638: Error: offset in operand 1 of 'ldw' out of range
[^:]*:639: Error: offset in operand 1 of 'ldw' out of range
[^:]*:640: Error: operand 1 of 'ldw' not a valid memory reference
[^:]*:641: Error: operand 1 of 'ldw' not a valid memory reference
[^:]*:642: Error: offset in operand 1 of 'ldw' not divisible by 4
[^:]*:643: Error: operand 1 of 'ldb' out of range
[^:]*:644: Error: operand 1 of 'ldb' out of range
[^:]*:645: Error: operand 1 of 'ldbu' out of range
[^:]*:646: Error: operand 1 of 'ldbu' out of range
[^:]*:647: Error: operand 1 of 'ldh' out of range
[^:]*:648: Error: operand 1 of 'ldh' out of range
[^:]*:649: Error: operand 1 of 'ldhu' out of range
[^:]*:650: Error: operand 1 of 'ldhu' out of range
[^:]*:651: Error: operand 1 of 'ldw' out of range
[^:]*:652: Error: operand 1 of 'ldw' out of range
[^:]*:653: Error: 'lmbd' instruction not supported on this functional unit
[^:]*:654: Error: bad number of operands to 'lmbd'
[^:]*:655: Error: operand 1 of 'lmbd' on wrong side
[^:]*:656: Error: operand 2 of 'lmbd' on wrong side
[^:]*:657: Error: operand 1 of 'lmbd' out of range
[^:]*:658: Error: operand 1 of 'lmbd' out of range
[^:]*:659: Error: 'max2' instruction not supported on this functional unit
[^:]*:660: Error: bad number of operands to 'max2'
[^:]*:661: Error: operand 1 of 'max2' on wrong side
[^:]*:662: Error: operand 2 of 'max2' on wrong side
[^:]*:663: Error: operand 2 of 'max2' on wrong side
[^:]*:664: Error: operand 1 of 'max2' on wrong side
[^:]*:665: Error: 'maxu4' instruction not supported on this functional unit
[^:]*:666: Error: bad number of operands to 'maxu4'
[^:]*:667: Error: operand 1 of 'maxu4' on wrong side
[^:]*:668: Error: operand 2 of 'maxu4' on wrong side
[^:]*:669: Error: 'min2' instruction not supported on this functional unit
[^:]*:670: Error: bad number of operands to 'min2'
[^:]*:671: Error: operand 1 of 'min2' on wrong side
[^:]*:672: Error: operand 2 of 'min2' on wrong side
[^:]*:673: Error: operand 2 of 'min2' on wrong side
[^:]*:674: Error: operand 1 of 'min2' on wrong side
[^:]*:675: Error: 'minu4' instruction not supported on this functional unit
[^:]*:676: Error: bad number of operands to 'minu4'
[^:]*:677: Error: operand 1 of 'minu4' on wrong side
[^:]*:678: Error: operand 2 of 'minu4' on wrong side
[^:]*:679: Error: 'mpy' instruction not supported on this functional unit
[^:]*:680: Error: bad number of operands to 'mpy'
[^:]*:681: Error: operand 1 of 'mpy' on wrong side
[^:]*:682: Error: operand 2 of 'mpy' on wrong side
[^:]*:683: Error: operand 1 of 'mpy' out of range
[^:]*:684: Error: operand 1 of 'mpy' out of range
[^:]*:685: Error: operand 2 of 'mpy' on wrong side
[^:]*:686: Error: 'mpydp' instruction not supported on this functional unit
[^:]*:687: Error: bad number of operands to 'mpydp'
[^:]*:688: Error: operand 1 of 'mpydp' on wrong side
[^:]*:689: Error: 'mpydp' instruction not supported on this functional unit
[^:]*:690: Error: 'mpyh' instruction not supported on this functional unit
[^:]*:691: Error: bad number of operands to 'mpyh'
[^:]*:692: Error: operand 1 of 'mpyh' on wrong side
[^:]*:693: Error: operand 2 of 'mpyh' on wrong side
[^:]*:694: Error: 'mpyhi' instruction not supported on this functional unit
[^:]*:695: Error: bad number of operands to 'mpyhi'
[^:]*:696: Error: operand 1 of 'mpyhi' on wrong side
[^:]*:697: Error: operand 2 of 'mpyhi' on wrong side
[^:]*:698: Error: 'mpyhir' instruction not supported on this functional unit
[^:]*:699: Error: bad number of operands to 'mpyhir'
[^:]*:700: Error: operand 1 of 'mpyhir' on wrong side
[^:]*:701: Error: operand 2 of 'mpyhir' on wrong side
[^:]*:702: Error: 'mpyhl' instruction not supported on this functional unit
[^:]*:703: Error: bad number of operands to 'mpyhl'
[^:]*:704: Error: operand 1 of 'mpyhl' on wrong side
[^:]*:705: Error: operand 2 of 'mpyhl' on wrong side
[^:]*:706: Error: 'mpyhlu' instruction not supported on this functional unit
[^:]*:707: Error: bad number of operands to 'mpyhlu'
[^:]*:708: Error: operand 1 of 'mpyhlu' on wrong side
[^:]*:709: Error: operand 2 of 'mpyhlu' on wrong side
[^:]*:710: Error: 'mpyhslu' instruction not supported on this functional unit
[^:]*:711: Error: bad number of operands to 'mpyhslu'
[^:]*:712: Error: operand 1 of 'mpyhslu' on wrong side
[^:]*:713: Error: operand 2 of 'mpyhslu' on wrong side
[^:]*:714: Error: 'mpyhsu' instruction not supported on this functional unit
[^:]*:715: Error: bad number of operands to 'mpyhsu'
[^:]*:716: Error: operand 1 of 'mpyhsu' on wrong side
[^:]*:717: Error: operand 2 of 'mpyhsu' on wrong side
[^:]*:718: Error: 'mpyhu' instruction not supported on this functional unit
[^:]*:719: Error: bad number of operands to 'mpyhu'
[^:]*:720: Error: operand 1 of 'mpyhu' on wrong side
[^:]*:721: Error: operand 2 of 'mpyhu' on wrong side
[^:]*:722: Error: 'mpyhuls' instruction not supported on this functional unit
[^:]*:723: Error: bad number of operands to 'mpyhuls'
[^:]*:724: Error: operand 1 of 'mpyhuls' on wrong side
[^:]*:725: Error: operand 2 of 'mpyhuls' on wrong side
[^:]*:726: Error: 'mpyhus' instruction not supported on this functional unit
[^:]*:727: Error: bad number of operands to 'mpyhus'
[^:]*:728: Error: operand 1 of 'mpyhus' on wrong side
[^:]*:729: Error: operand 2 of 'mpyhus' on wrong side
[^:]*:730: Error: 'mpyi' instruction not supported on this functional unit
[^:]*:731: Error: bad number of operands to 'mpyi'
[^:]*:732: Error: operand 1 of 'mpyi' on wrong side
[^:]*:733: Error: operand 2 of 'mpyi' on wrong side
[^:]*:734: Error: operand 1 of 'mpyi' out of range
[^:]*:735: Error: operand 1 of 'mpyi' out of range
[^:]*:736: Error: 'mpyid' instruction not supported on this functional unit
[^:]*:737: Error: bad number of operands to 'mpyid'
[^:]*:738: Error: operand 1 of 'mpyid' on wrong side
[^:]*:739: Error: operand 2 of 'mpyid' on wrong side
[^:]*:740: Error: operand 1 of 'mpyid' out of range
[^:]*:741: Error: operand 1 of 'mpyid' out of range
[^:]*:742: Error: 'mpyih' instruction not supported on this functional unit
[^:]*:743: Error: bad number of operands to 'mpyih'
[^:]*:744: Error: operand 1 of 'mpyih' on wrong side
[^:]*:745: Error: operand 1 of 'mpyih' on wrong side
[^:]*:746: Error: 'mpyihr' instruction not supported on this functional unit
[^:]*:747: Error: bad number of operands to 'mpyihr'
[^:]*:748: Error: operand 1 of 'mpyihr' on wrong side
[^:]*:749: Error: operand 1 of 'mpyihr' on wrong side
[^:]*:750: Error: 'mpyil' instruction not supported on this functional unit
[^:]*:751: Error: bad number of operands to 'mpyil'
[^:]*:752: Error: operand 1 of 'mpyil' on wrong side
[^:]*:753: Error: operand 1 of 'mpyil' on wrong side
[^:]*:754: Error: 'mpyilr' instruction not supported on this functional unit
[^:]*:755: Error: bad number of operands to 'mpyilr'
[^:]*:756: Error: operand 1 of 'mpyilr' on wrong side
[^:]*:757: Error: operand 1 of 'mpyilr' on wrong side
[^:]*:758: Error: 'mpylh' instruction not supported on this functional unit
[^:]*:759: Error: bad number of operands to 'mpylh'
[^:]*:760: Error: operand 1 of 'mpylh' on wrong side
[^:]*:761: Error: operand 2 of 'mpylh' on wrong side
[^:]*:762: Error: 'mpylhu' instruction not supported on this functional unit
[^:]*:763: Error: bad number of operands to 'mpylhu'
[^:]*:764: Error: operand 1 of 'mpylhu' on wrong side
[^:]*:765: Error: operand 2 of 'mpylhu' on wrong side
[^:]*:766: Error: 'mpyli' instruction not supported on this functional unit
[^:]*:767: Error: bad number of operands to 'mpyli'
[^:]*:768: Error: operand 1 of 'mpyli' on wrong side
[^:]*:769: Error: operand 2 of 'mpyli' on wrong side
[^:]*:770: Error: 'mpylir' instruction not supported on this functional unit
[^:]*:771: Error: bad number of operands to 'mpylir'
[^:]*:772: Error: operand 1 of 'mpylir' on wrong side
[^:]*:773: Error: operand 2 of 'mpylir' on wrong side
[^:]*:774: Error: 'mpylshu' instruction not supported on this functional unit
[^:]*:775: Error: bad number of operands to 'mpylshu'
[^:]*:776: Error: operand 1 of 'mpylshu' on wrong side
[^:]*:777: Error: operand 2 of 'mpylshu' on wrong side
[^:]*:778: Error: 'mpyluhs' instruction not supported on this functional unit
[^:]*:779: Error: bad number of operands to 'mpyluhs'
[^:]*:780: Error: operand 1 of 'mpyluhs' on wrong side
[^:]*:781: Error: operand 2 of 'mpyluhs' on wrong side
[^:]*:782: Error: 'mpysp' instruction not supported on this functional unit
[^:]*:783: Error: bad number of operands to 'mpysp'
[^:]*:784: Error: operand 1 of 'mpysp' on wrong side
[^:]*:785: Error: operand 2 of 'mpysp' on wrong side
[^:]*:786: Error: 'mpyspdp' instruction not supported on this functional unit
[^:]*:787: Error: too many operands to 'mpyspdp'
[^:]*:788: Error: operand 1 of 'mpyspdp' on wrong side
[^:]*:789: Error: operand 2 of 'mpyspdp' on wrong side
[^:]*:790: Error: 'mpysp2dp' instruction not supported on this functional unit
[^:]*:791: Error: bad number of operands to 'mpysp2dp'
[^:]*:792: Error: operand 1 of 'mpysp2dp' on wrong side
[^:]*:793: Error: operand 2 of 'mpysp2dp' on wrong side
[^:]*:794: Error: 'mpysu' instruction not supported on this functional unit
[^:]*:795: Error: bad number of operands to 'mpysu'
[^:]*:796: Error: operand 1 of 'mpysu' on wrong side
[^:]*:797: Error: operand 2 of 'mpysu' on wrong side
[^:]*:798: Error: operand 1 of 'mpysu' out of range
[^:]*:799: Error: operand 1 of 'mpysu' out of range
[^:]*:800: Error: 'mpysu4' instruction not supported on this functional unit
[^:]*:801: Error: bad number of operands to 'mpysu4'
[^:]*:802: Error: operand 1 of 'mpysu4' on wrong side
[^:]*:803: Error: operand 2 of 'mpysu4' on wrong side
[^:]*:804: Error: 'mpyu' instruction not supported on this functional unit
[^:]*:805: Error: bad number of operands to 'mpyu'
[^:]*:806: Error: operand 1 of 'mpyu' on wrong side
[^:]*:807: Error: operand 2 of 'mpyu' on wrong side
[^:]*:808: Error: 'mpyu4' instruction not supported on this functional unit
[^:]*:809: Error: bad number of operands to 'mpyu4'
[^:]*:810: Error: operand 1 of 'mpyu4' on wrong side
[^:]*:811: Error: operand 2 of 'mpyu4' on wrong side
[^:]*:812: Error: 'mpyus' instruction not supported on this functional unit
[^:]*:813: Error: bad number of operands to 'mpyus'
[^:]*:814: Error: operand 1 of 'mpyus' on wrong side
[^:]*:815: Error: operand 2 of 'mpyus' on wrong side
[^:]*:816: Error: 'mpyus4' instruction not supported on this functional unit
[^:]*:817: Error: bad number of operands to 'mpyus4'
[^:]*:818: Error: operand 1 of 'mpyus4' on wrong side
[^:]*:819: Error: operand 1 of 'mpyus4' on wrong side
[^:]*:820: Error: 'mpy2' instruction not supported on this functional unit
[^:]*:821: Error: bad number of operands to 'mpy2'
[^:]*:822: Error: operand 1 of 'mpy2' on wrong side
[^:]*:823: Error: operand 2 of 'mpy2' on wrong side
[^:]*:824: Error: 'mpy2ir' instruction not supported on this functional unit
[^:]*:825: Error: bad number of operands to 'mpy2ir'
[^:]*:826: Error: operand 1 of 'mpy2ir' on wrong side
[^:]*:827: Error: operand 2 of 'mpy2ir' on wrong side
[^:]*:828: Error: 'mpy32' instruction not supported on this functional unit
[^:]*:829: Error: bad number of operands to 'mpy32'
[^:]*:830: Error: operand 1 of 'mpy32' on wrong side
[^:]*:831: Error: operand 2 of 'mpy32' on wrong side
[^:]*:832: Error: operand 1 of 'mpy32' on wrong side
[^:]*:833: Error: operand 2 of 'mpy32' on wrong side
[^:]*:834: Error: 'mpy32su' instruction not supported on this functional unit
[^:]*:835: Error: bad number of operands to 'mpy32su'
[^:]*:836: Error: operand 2 of 'mpy32su' on wrong side
[^:]*:837: Error: operand 1 of 'mpy32su' on wrong side
[^:]*:838: Error: 'mpy32u' instruction not supported on this functional unit
[^:]*:839: Error: bad number of operands to 'mpy32u'
[^:]*:840: Error: operand 2 of 'mpy32u' on wrong side
[^:]*:841: Error: operand 1 of 'mpy32u' on wrong side
[^:]*:842: Error: 'mpy32us' instruction not supported on this functional unit
[^:]*:843: Error: bad number of operands to 'mpy32us'
[^:]*:844: Error: operand 2 of 'mpy32us' on wrong side
[^:]*:845: Error: operand 1 of 'mpy32us' on wrong side
[^:]*:846: Error: 'mvc' instruction not supported on this functional unit
[^:]*:847: Error: bad register for operand 1 of 'mvc'
[^:]*:847: Error: bad operand 2 of 'mvc'
[^:]*:848: Error: bad register for operand 2 of 'mvc'
[^:]*:849: Error: operand 2 of 'mvc' is read-only
[^:]*:850: Error: operand 1 of 'mvc' is write-only
[^:]*:851: Error: operand 2 of 'mvc' is read-only
[^:]*:852: Error: operand 1 of 'mvc' is write-only
[^:]*:853: Error: operand 2 of 'mvc' is read-only
[^:]*:854: Error: operand 1 of 'mvc' is write-only
[^:]*:855: Error: operand 2 of 'mvc' is read-only
[^:]*:856: Error: operand 2 of 'mvc' is read-only
[^:]*:858: Error: 'mv' instruction not supported on this functional unit
[^:]*:859: Error: too many operands to 'mv'
[^:]*:860: Error: operand 2 of 'mv' on wrong side
[^:]*:861: Error: operand 1 of 'mv' on wrong side
[^:]*:862: Error: operand 2 of 'mv' on wrong side
[^:]*:863: Error: operand 1 of 'mv' on wrong side
[^:]*:864: Error: operand 2 of 'mv' on wrong side
[^:]*:865: Error: operand 1 of 'mv' on wrong side
[^:]*:866: Error: 'mvd' instruction not supported on this functional unit
[^:]*:867: Error: too many operands to 'mvd'
[^:]*:868: Error: operand 2 of 'mvd' on wrong side
[^:]*:869: Error: operand 1 of 'mvd' on wrong side
[^:]*:870: Error: operand 1 of 'mvk' out of range
[^:]*:871: Error: operand 1 of 'mvk' out of range
[^:]*:872: Error: 'mvk' instruction not supported on this functional unit
[^:]*:873: Error: operand 1 of 'mvk' out of range
[^:]*:874: Error: operand 1 of 'mvk' out of range
[^:]*:875: Error: 'mvk' instruction not supported on this functional unit
[^:]*:876: Error: 'norm' instruction not supported on this functional unit
[^:]*:877: Error: too many operands to 'norm'
[^:]*:878: Error: bad register for operand 1 of 'norm'
[^:]*:879: Error: operand 2 of 'norm' on wrong side
[^:]*:880: Error: operand 1 of 'norm' on wrong side
[^:]*:881: Error: 'or' instruction not supported on this functional unit
[^:]*:882: Error: bad number of operands to 'or'
[^:]*:883: Error: operand 1 of 'or' out of range
[^:]*:884: Error: operand 1 of 'or' out of range
[^:]*:885: Error: operand 1 of 'or' out of range
[^:]*:886: Error: operand 1 of 'or' out of range
[^:]*:887: Error: operand 1 of 'or' out of range
[^:]*:888: Error: operand 1 of 'or' out of range
[^:]*:889: Error: operand 3 of 'or' on wrong side
[^:]*:890: Error: operand 2 of 'or' on wrong side
[^:]*:891: Error: operand 2 of 'or' on wrong side
[^:]*:892: Error: operand 3 of 'or' on wrong side
[^:]*:893: Error: 'pack2' instruction not supported on this functional unit
[^:]*:894: Error: bad number of operands to 'pack2'
[^:]*:895: Error: operand 3 of 'pack2' on wrong side
[^:]*:896: Error: operand 2 of 'pack2' on wrong side
[^:]*:897: Error: 'packh2' instruction not supported on this functional unit
[^:]*:898: Error: bad number of operands to 'packh2'
[^:]*:899: Error: operand 3 of 'packh2' on wrong side
[^:]*:900: Error: operand 2 of 'packh2' on wrong side
[^:]*:901: Error: 'packh4' instruction not supported on this functional unit
[^:]*:902: Error: bad number of operands to 'packh4'
[^:]*:903: Error: operand 3 of 'packh4' on wrong side
[^:]*:904: Error: operand 2 of 'packh4' on wrong side
[^:]*:905: Error: 'packhl2' instruction not supported on this functional unit
[^:]*:906: Error: bad number of operands to 'packhl2'
[^:]*:907: Error: operand 3 of 'packhl2' on wrong side
[^:]*:908: Error: operand 2 of 'packhl2' on wrong side
[^:]*:909: Error: 'packlh2' instruction not supported on this functional unit
[^:]*:910: Error: bad number of operands to 'packlh2'
[^:]*:911: Error: operand 3 of 'packlh2' on wrong side
[^:]*:912: Error: operand 2 of 'packlh2' on wrong side
[^:]*:913: Error: 'packl4' instruction not supported on this functional unit
[^:]*:914: Error: bad number of operands to 'packl4'
[^:]*:915: Error: operand 3 of 'packl4' on wrong side
[^:]*:916: Error: operand 2 of 'packl4' on wrong side
[^:]*:917: Error: 'rcpdp' instruction not supported on this functional unit
[^:]*:918: Error: bad number of operands to 'rcpdp'
[^:]*:919: Error: operand 1 of 'rcpdp' on wrong side
[^:]*:920: Error: 'rcpdp' instruction not supported on this functional unit
[^:]*:921: Error: 'rcpsp' instruction not supported on this functional unit
[^:]*:922: Error: too many operands to 'rcpsp'
[^:]*:923: Error: operand 2 of 'rcpsp' on wrong side
[^:]*:924: Error: operand 1 of 'rcpsp' on wrong side
[^:]*:925: Error: 'rint' instruction not supported on this functional unit
[^:]*:926: Error: too many operands to 'rint'
[^:]*:927: Error: 'rotl' instruction not supported on this functional unit
[^:]*:928: Error: bad number of operands to 'rotl'
[^:]*:929: Error: operand 2 of 'rotl' on wrong side
[^:]*:930: Error: operand 1 of 'rotl' on wrong side
[^:]*:931: Error: operand 2 of 'rotl' out of range
[^:]*:932: Error: operand 2 of 'rotl' out of range
[^:]*:933: Error: operand 1 of 'rotl' on wrong side
[^:]*:934: Error: 'rpack2' instruction not supported on this functional unit
[^:]*:935: Error: bad number of operands to 'rpack2'
[^:]*:936: Error: operand 1 of 'rpack2' on wrong side
[^:]*:937: Error: operand 2 of 'rpack2' on wrong side
[^:]*:938: Error: 'rsqrdp' instruction not supported on this functional unit
[^:]*:939: Error: bad number of operands to 'rsqrdp'
[^:]*:940: Error: operand 1 of 'rsqrdp' on wrong side
[^:]*:941: Error: 'rsqrdp' instruction not supported on this functional unit
[^:]*:942: Error: 'rsqrsp' instruction not supported on this functional unit
[^:]*:943: Error: too many operands to 'rsqrsp'
[^:]*:944: Error: operand 2 of 'rsqrsp' on wrong side
[^:]*:945: Error: operand 1 of 'rsqrsp' on wrong side
[^:]*:946: Error: 'sadd' instruction not supported on this functional unit
[^:]*:947: Error: bad number of operands to 'sadd'
[^:]*:948: Error: bad register for operand 1 of 'sadd'
[^:]*:949: Error: bad operand combination for 'sadd'
[^:]*:950: Error: operand 1 of 'sadd' on wrong side
[^:]*:951: Error: operand 2 of 'sadd' on wrong side
[^:]*:952: Error: operand 1 of 'sadd' out of range
[^:]*:953: Error: operand 1 of 'sadd' out of range
[^:]*:954: Error: operand 1 of 'sadd' out of range
[^:]*:955: Error: operand 1 of 'sadd' out of range
[^:]*:956: Error: 'sadd2' instruction not supported on this functional unit
[^:]*:957: Error: bad number of operands to 'sadd2'
[^:]*:958: Error: operand 1 of 'sadd2' on wrong side
[^:]*:959: Error: operand 2 of 'sadd2' on wrong side
[^:]*:960: Error: 'saddsub' instruction not supported on this functional unit
[^:]*:961: Error: bad number of operands to 'saddsub'
[^:]*:962: Error: bad register pair for operand 3 of 'saddsub'
[^:]*:963: Error: operand 1 of 'saddsub' on wrong side
[^:]*:964: Error: operand 2 of 'saddsub' on wrong side
[^:]*:965: Error: 'saddsub2' instruction not supported on this functional unit
[^:]*:966: Error: bad number of operands to 'saddsub2'
[^:]*:967: Error: bad register pair for operand 3 of 'saddsub2'
[^:]*:968: Error: operand 1 of 'saddsub2' on wrong side
[^:]*:969: Error: operand 2 of 'saddsub2' on wrong side
[^:]*:970: Error: 'saddsu2' instruction not supported on this functional unit
[^:]*:971: Error: bad number of operands to 'saddsu2'
[^:]*:972: Error: operand 2 of 'saddsu2' on wrong side
[^:]*:973: Error: operand 1 of 'saddsu2' on wrong side
[^:]*:974: Error: 'saddus2' instruction not supported on this functional unit
[^:]*:975: Error: bad number of operands to 'saddus2'
[^:]*:976: Error: operand 1 of 'saddus2' on wrong side
[^:]*:977: Error: operand 2 of 'saddus2' on wrong side
[^:]*:978: Error: 'saddu4' instruction not supported on this functional unit
[^:]*:979: Error: bad number of operands to 'saddu4'
[^:]*:980: Error: operand 1 of 'saddu4' on wrong side
[^:]*:981: Error: operand 2 of 'saddu4' on wrong side
[^:]*:982: Error: 'sat' instruction not supported on this functional unit
[^:]*:983: Error: 'sat' instruction not supported on this functional unit
[^:]*:984: Error: bad number of operands to 'sat'
[^:]*:985: Error: operand 1 of 'sat' on wrong side
[^:]*:986: Error: 'set' instruction not supported on this functional unit
[^:]*:987: Error: bad number of operands to 'set'
[^:]*:988: Error: operand 2 of 'set' out of range
[^:]*:989: Error: operand 2 of 'set' out of range
[^:]*:990: Error: operand 3 of 'set' out of range
[^:]*:991: Error: operand 3 of 'set' out of range
[^:]*:992: Error: bad register for operand 2 of 'set'
[^:]*:992: Error: bad register for operand 3 of 'set'
[^:]*:992: Error: too many operands to 'set'
[^:]*:993: Error: operand 1 of 'set' on wrong side
[^:]*:994: Error: operand 2 of 'set' on wrong side
[^:]*:995: Error: 'shfl' instruction not supported on this functional unit
[^:]*:996: Error: too many operands to 'shfl'
[^:]*:997: Error: operand 2 of 'shfl' on wrong side
[^:]*:998: Error: operand 1 of 'shfl' on wrong side
[^:]*:999: Error: 'shfl3' instruction not supported on this functional unit
[^:]*:1000: Error: bad number of operands to 'shfl3'
[^:]*:1001: Error: operand 1 of 'shfl3' on wrong side
[^:]*:1002: Error: operand 2 of 'shfl3' on wrong side
[^:]*:1003: Error: 'shl' instruction not supported on this functional unit
[^:]*:1004: Error: bad number of operands to 'shl'
[^:]*:1005: Error: bad register for operand 1 of 'shl'
[^:]*:1006: Error: operand 2 of 'shl' on wrong side
[^:]*:1007: Error: operand 1 of 'shl' on wrong side
[^:]*:1008: Error: operand 2 of 'shl' out of range
[^:]*:1009: Error: operand 2 of 'shl' out of range
[^:]*:1010: Error: operand 2 of 'shl' out of range
[^:]*:1011: Error: operand 2 of 'shl' out of range
[^:]*:1012: Error: operand 2 of 'shl' out of range
[^:]*:1013: Error: operand 2 of 'shl' out of range
[^:]*:1014: Error: 'shlmb' instruction not supported on this functional unit
[^:]*:1015: Error: bad number of operands to 'shlmb'
[^:]*:1016: Error: operand 1 of 'shlmb' on wrong side
[^:]*:1017: Error: operand 2 of 'shlmb' on wrong side
[^:]*:1018: Error: operand 1 of 'shlmb' on wrong side
[^:]*:1019: Error: operand 2 of 'shlmb' on wrong side
[^:]*:1020: Error: 'shr' instruction not supported on this functional unit
[^:]*:1021: Error: bad number of operands to 'shr'
[^:]*:1022: Error: bad register for operand 1 of 'shr'
[^:]*:1022: Error: bad register for operand 3 of 'shr'
[^:]*:1023: Error: operand 2 of 'shr' on wrong side
[^:]*:1024: Error: operand 2 of 'shr' out of range
[^:]*:1025: Error: operand 2 of 'shr' out of range
[^:]*:1026: Error: operand 2 of 'shr' out of range
[^:]*:1027: Error: operand 2 of 'shr' out of range
[^:]*:1028: Error: 'shr2' instruction not supported on this functional unit
[^:]*:1029: Error: 'shr2' instruction not supported on this functional unit
[^:]*:1030: Error: bad number of operands to 'shr2'
[^:]*:1031: Error: operand 2 of 'shr2' on wrong side
[^:]*:1032: Error: operand 1 of 'shr2' on wrong side
[^:]*:1033: Error: operand 2 of 'shr2' out of range
[^:]*:1034: Error: operand 2 of 'shr2' out of range
[^:]*:1035: Error: 'shrmb' instruction not supported on this functional unit
[^:]*:1036: Error: bad number of operands to 'shrmb'
[^:]*:1037: Error: operand 1 of 'shrmb' on wrong side
[^:]*:1038: Error: operand 2 of 'shrmb' on wrong side
[^:]*:1039: Error: operand 1 of 'shrmb' on wrong side
[^:]*:1040: Error: operand 2 of 'shrmb' on wrong side
[^:]*:1041: Error: 'shru' instruction not supported on this functional unit
[^:]*:1042: Error: bad number of operands to 'shru'
[^:]*:1043: Error: bad register for operand 1 of 'shru'
[^:]*:1043: Error: bad register for operand 3 of 'shru'
[^:]*:1044: Error: operand 2 of 'shru' on wrong side
[^:]*:1045: Error: operand 2 of 'shru' out of range
[^:]*:1046: Error: operand 2 of 'shru' out of range
[^:]*:1047: Error: operand 2 of 'shru' out of range
[^:]*:1048: Error: operand 2 of 'shru' out of range
[^:]*:1049: Error: 'shru2' instruction not supported on this functional unit
[^:]*:1050: Error: 'shru2' instruction not supported on this functional unit
[^:]*:1051: Error: bad number of operands to 'shru2'
[^:]*:1052: Error: operand 2 of 'shru2' on wrong side
[^:]*:1053: Error: operand 1 of 'shru2' on wrong side
[^:]*:1054: Error: operand 2 of 'shru2' out of range
[^:]*:1055: Error: operand 2 of 'shru2' out of range
[^:]*:1056: Error: 'smpy' instruction not supported on this functional unit
[^:]*:1057: Error: bad number of operands to 'smpy'
[^:]*:1058: Error: operand 1 of 'smpy' on wrong side
[^:]*:1059: Error: operand 2 of 'smpy' on wrong side
[^:]*:1060: Error: 'smpyh' instruction not supported on this functional unit
[^:]*:1061: Error: bad number of operands to 'smpyh'
[^:]*:1062: Error: operand 1 of 'smpyh' on wrong side
[^:]*:1063: Error: operand 2 of 'smpyh' on wrong side
[^:]*:1064: Error: 'smpyhl' instruction not supported on this functional unit
[^:]*:1065: Error: bad number of operands to 'smpyhl'
[^:]*:1066: Error: operand 1 of 'smpyhl' on wrong side
[^:]*:1067: Error: operand 2 of 'smpyhl' on wrong side
[^:]*:1068: Error: 'smpylh' instruction not supported on this functional unit
[^:]*:1069: Error: bad number of operands to 'smpylh'
[^:]*:1070: Error: operand 1 of 'smpylh' on wrong side
[^:]*:1071: Error: operand 2 of 'smpylh' on wrong side
[^:]*:1072: Error: 'smpy2' instruction not supported on this functional unit
[^:]*:1073: Error: bad number of operands to 'smpy2'
[^:]*:1074: Error: operand 1 of 'smpy2' on wrong side
[^:]*:1075: Error: operand 2 of 'smpy2' on wrong side
[^:]*:1076: Error: 'smpy32' instruction not supported on this functional unit
[^:]*:1077: Error: bad number of operands to 'smpy32'
[^:]*:1078: Error: operand 1 of 'smpy32' on wrong side
[^:]*:1079: Error: operand 2 of 'smpy32' on wrong side
[^:]*:1080: Error: 'spack2' instruction not supported on this functional unit
[^:]*:1081: Error: bad number of operands to 'spack2'
[^:]*:1082: Error: operand 1 of 'spack2' on wrong side
[^:]*:1083: Error: operand 2 of 'spack2' on wrong side
[^:]*:1084: Error: 'spacku4' instruction not supported on this functional unit
[^:]*:1085: Error: bad number of operands to 'spacku4'
[^:]*:1086: Error: operand 1 of 'spacku4' on wrong side
[^:]*:1087: Error: operand 2 of 'spacku4' on wrong side
[^:]*:1088: Error: 'spdp' instruction not supported on this functional unit
[^:]*:1089: Error: bad number of operands to 'spdp'
[^:]*:1090: Error: operand 2 of 'spdp' on wrong side
[^:]*:1091: Error: operand 1 of 'spdp' on wrong side
[^:]*:1092: Error: 'spint' instruction not supported on this functional unit
[^:]*:1093: Error: too many operands to 'spint'
[^:]*:1094: Error: operand 2 of 'spint' on wrong side
[^:]*:1095: Error: operand 1 of 'spint' on wrong side
[^:]*:1096: Error: 'sptrunc' instruction not supported on this functional unit
[^:]*:1097: Error: too many operands to 'sptrunc'
[^:]*:1098: Error: operand 2 of 'sptrunc' on wrong side
[^:]*:1099: Error: operand 1 of 'sptrunc' on wrong side
[^:]*:1100: Error: 'sshl' instruction not supported on this functional unit
[^:]*:1101: Error: bad number of operands to 'sshl'
[^:]*:1102: Error: operand 2 of 'sshl' on wrong side
[^:]*:1103: Error: operand 1 of 'sshl' on wrong side
[^:]*:1104: Error: operand 2 of 'sshl' out of range
[^:]*:1105: Error: operand 2 of 'sshl' out of range
[^:]*:1106: Error: 'sshvl' instruction not supported on this functional unit
[^:]*:1107: Error: bad number of operands to 'sshvl'
[^:]*:1108: Error: operand 2 of 'sshvl' on wrong side
[^:]*:1109: Error: operand 1 of 'sshvl' on wrong side
[^:]*:1110: Error: 'sshvr' instruction not supported on this functional unit
[^:]*:1111: Error: bad number of operands to 'sshvr'
[^:]*:1112: Error: operand 2 of 'sshvr' on wrong side
[^:]*:1113: Error: operand 1 of 'sshvr' on wrong side
[^:]*:1114: Error: 'ssub' instruction not supported on this functional unit
[^:]*:1115: Error: bad number of operands to 'ssub'
[^:]*:1116: Error: operand 3 of 'ssub' on wrong side
[^:]*:1117: Error: bad operand combination for 'ssub'
[^:]*:1118: Error: operand 1 of 'ssub' out of range
[^:]*:1119: Error: operand 1 of 'ssub' out of range
[^:]*:1120: Error: bad register for operand 2 of 'ssub'
[^:]*:1120: Error: bad register for operand 3 of 'ssub'
[^:]*:1121: Error: operand 1 of 'ssub' out of range
[^:]*:1122: Error: operand 1 of 'ssub' out of range
[^:]*:1123: Error: 'ssub2' instruction not supported on this functional unit
[^:]*:1124: Error: bad number of operands to 'ssub2'
[^:]*:1125: Error: operand 2 of 'ssub2' on wrong side
[^:]*:1126: Error: operand 2 of 'ssub2' on wrong side
[^:]*:1127: Error: 'stb' instruction not supported on this functional unit
[^:]*:1128: Error: operand 1 of 'stb' on wrong side
[^:]*:1129: Error: operand 2 of 'stb' not a valid memory reference
[^:]*:1130: Error: operand 2 of 'stb' not a valid memory reference
[^:]*:1131: Error: operand 1 of 'stb' on wrong side
[^:]*:1132: Error: bad register for operand 1 of 'stb'
[^:]*:1133: Error: operand 2 of 'stb' not a valid memory reference
[^:]*:1134: Error: bad operand 2 of 'stb'
[^:]*:1135: Error: bad operand 2 of 'stb'
[^:]*:1136: Error: offset in operand 2 of 'stb' out of range
[^:]*:1137: Error: offset in operand 2 of 'stb' out of range
[^:]*:1138: Error: offset in operand 2 of 'stb' out of range
[^:]*:1139: Error: offset in operand 2 of 'stb' out of range
[^:]*:1140: Error: operand 2 of 'stb' not a valid memory reference
[^:]*:1141: Error: operand 2 of 'stb' not a valid memory reference
[^:]*:1142: Error: operand 2 of 'stb' out of range
[^:]*:1143: Error: operand 2 of 'stb' out of range
[^:]*:1144: Error: 'stdw' instruction not supported on this functional unit
[^:]*:1145: Error: operand 1 of 'stdw' on wrong side
[^:]*:1146: Error: operand 2 of 'stdw' not a valid memory reference
[^:]*:1147: Error: operand 2 of 'stdw' not a valid memory reference
[^:]*:1148: Error: operand 1 of 'stdw' on wrong side
[^:]*:1149: Error: bad register pair for operand 1 of 'stdw'
[^:]*:1150: Error: operand 2 of 'stdw' not a valid memory reference
[^:]*:1151: Error: bad operand 2 of 'stdw'
[^:]*:1152: Error: bad operand 2 of 'stdw'
[^:]*:1153: Error: offset in operand 2 of 'stdw' out of range
[^:]*:1154: Error: offset in operand 2 of 'stdw' out of range
[^:]*:1155: Error: offset in operand 2 of 'stdw' out of range
[^:]*:1156: Error: offset in operand 2 of 'stdw' out of range
[^:]*:1157: Error: operand 2 of 'stdw' not a valid memory reference
[^:]*:1158: Error: operand 2 of 'stdw' not a valid memory reference
[^:]*:1159: Error: offset in operand 2 of 'stdw' not divisible by 8
[^:]*:1160: Error: operand 2 of 'stdw' not a valid memory reference
[^:]*:1161: Error: 'sth' instruction not supported on this functional unit
[^:]*:1162: Error: operand 1 of 'sth' on wrong side
[^:]*:1163: Error: operand 2 of 'sth' not a valid memory reference
[^:]*:1164: Error: operand 2 of 'sth' not a valid memory reference
[^:]*:1165: Error: operand 1 of 'sth' on wrong side
[^:]*:1166: Error: bad register for operand 1 of 'sth'
[^:]*:1167: Error: operand 2 of 'sth' not a valid memory reference
[^:]*:1168: Error: bad operand 2 of 'sth'
[^:]*:1169: Error: bad operand 2 of 'sth'
[^:]*:1170: Error: offset in operand 2 of 'sth' out of range
[^:]*:1171: Error: offset in operand 2 of 'sth' out of range
[^:]*:1172: Error: offset in operand 2 of 'sth' out of range
[^:]*:1173: Error: offset in operand 2 of 'sth' out of range
[^:]*:1174: Error: operand 2 of 'sth' not a valid memory reference
[^:]*:1175: Error: operand 2 of 'sth' not a valid memory reference
[^:]*:1176: Error: offset in operand 2 of 'sth' not divisible by 2
[^:]*:1177: Error: operand 2 of 'sth' out of range
[^:]*:1178: Error: operand 2 of 'sth' out of range
[^:]*:1179: Error: 'stndw' instruction not supported on this functional unit
[^:]*:1180: Error: operand 1 of 'stndw' on wrong side
[^:]*:1181: Error: operand 2 of 'stndw' not a valid memory reference
[^:]*:1182: Error: operand 2 of 'stndw' not a valid memory reference
[^:]*:1183: Error: operand 1 of 'stndw' on wrong side
[^:]*:1184: Error: bad register pair for operand 1 of 'stndw'
[^:]*:1185: Error: operand 2 of 'stndw' not a valid memory reference
[^:]*:1186: Error: bad operand 2 of 'stndw'
[^:]*:1187: Error: bad operand 2 of 'stndw'
[^:]*:1188: Error: offset in operand 2 of 'stndw' out of range
[^:]*:1189: Error: offset in operand 2 of 'stndw' out of range
[^:]*:1190: Error: offset in operand 2 of 'stndw' out of range
[^:]*:1191: Error: offset in operand 2 of 'stndw' out of range
[^:]*:1192: Error: operand 2 of 'stndw' not a valid memory reference
[^:]*:1193: Error: 'stnw' instruction not supported on this functional unit
[^:]*:1194: Error: operand 1 of 'stnw' on wrong side
[^:]*:1195: Error: operand 2 of 'stnw' not a valid memory reference
[^:]*:1196: Error: operand 2 of 'stnw' not a valid memory reference
[^:]*:1197: Error: operand 1 of 'stnw' on wrong side
[^:]*:1198: Error: bad register for operand 1 of 'stnw'
[^:]*:1199: Error: operand 2 of 'stnw' not a valid memory reference
[^:]*:1200: Error: bad operand 2 of 'stnw'
[^:]*:1201: Error: bad operand 2 of 'stnw'
[^:]*:1202: Error: offset in operand 2 of 'stnw' out of range
[^:]*:1203: Error: offset in operand 2 of 'stnw' out of range
[^:]*:1204: Error: offset in operand 2 of 'stnw' out of range
[^:]*:1205: Error: offset in operand 2 of 'stnw' out of range
[^:]*:1206: Error: operand 2 of 'stnw' not a valid memory reference
[^:]*:1207: Error: operand 2 of 'stnw' not a valid memory reference
[^:]*:1208: Error: offset in operand 2 of 'stnw' not divisible by 4
[^:]*:1209: Error: 'stw' instruction not supported on this functional unit
[^:]*:1210: Error: operand 1 of 'stw' on wrong side
[^:]*:1211: Error: operand 2 of 'stw' not a valid memory reference
[^:]*:1212: Error: operand 2 of 'stw' not a valid memory reference
[^:]*:1213: Error: operand 1 of 'stw' on wrong side
[^:]*:1214: Error: bad register for operand 1 of 'stw'
[^:]*:1215: Error: operand 2 of 'stw' not a valid memory reference
[^:]*:1216: Error: bad operand 2 of 'stw'
[^:]*:1217: Error: bad operand 2 of 'stw'
[^:]*:1218: Error: offset in operand 2 of 'stw' out of range
[^:]*:1219: Error: offset in operand 2 of 'stw' out of range
[^:]*:1220: Error: offset in operand 2 of 'stw' out of range
[^:]*:1221: Error: offset in operand 2 of 'stw' out of range
[^:]*:1222: Error: operand 2 of 'stw' not a valid memory reference
[^:]*:1223: Error: operand 2 of 'stw' not a valid memory reference
[^:]*:1224: Error: offset in operand 2 of 'stw' not divisible by 4
[^:]*:1225: Error: operand 2 of 'stw' out of range
[^:]*:1226: Error: operand 2 of 'stw' out of range
[^:]*:1227: Error: 'neg' instruction not supported on this functional unit
[^:]*:1228: Error: bad register for operand 1 of 'neg'
[^:]*:1228: Error: bad register for operand 2 of 'neg'
[^:]*:1229: Error: too many operands to 'neg'
[^:]*:1230: Error: operand 2 of 'neg' on wrong side
[^:]*:1231: Error: operand 1 of 'neg' on wrong side
[^:]*:1232: Error: bad register for operand 1 of 'neg'
[^:]*:1232: Error: bad register for operand 2 of 'neg'
[^:]*:1233: Error: operand 2 of 'neg' on wrong side
[^:]*:1234: Error: operand 1 of 'neg' on wrong side
[^:]*:1235: Error: 'sub' instruction not supported on this functional unit
[^:]*:1236: Error: bad number of operands to 'sub'
[^:]*:1237: Error: operand 1 of 'sub' on wrong side
[^:]*:1238: Error: bad operand combination for 'sub'
[^:]*:1239: Error: junk after operand 2 of 'sub'
[^:]*:1240: Error: operand 1 of 'sub' out of range
[^:]*:1241: Error: operand 1 of 'sub' out of range
[^:]*:1242: Error: operand 1 of 'sub' out of range
[^:]*:1243: Error: operand 1 of 'sub' out of range
[^:]*:1244: Error: bad number of operands to 'sub'
[^:]*:1245: Error: operand 3 of 'sub' on wrong side
[^:]*:1246: Error: bad operand combination for 'sub'
[^:]*:1247: Error: operand 1 of 'sub' out of range
[^:]*:1248: Error: operand 1 of 'sub' out of range
[^:]*:1249: Error: junk after operand 2 of 'sub'
[^:]*:1249: Error: bad register for operand 3 of 'sub'
[^:]*:1250: Error: bad number of operands to 'sub'
[^:]*:1251: Error: operand 1 of 'sub' on wrong side
[^:]*:1252: Error: operand 2 of 'sub' on wrong side
[^:]*:1253: Error: bad register for operand 2 of 'sub'
[^:]*:1254: Error: operand 2 of 'sub' out of range
[^:]*:1255: Error: operand 2 of 'sub' out of range
[^:]*:1256: Error: 'subab' instruction not supported on this functional unit
[^:]*:1257: Error: bad number of operands to 'subab'
[^:]*:1258: Error: operand 2 of 'subab' on wrong side
[^:]*:1259: Error: 'subab' instruction not supported on this functional unit
[^:]*:1260: Error: 'subab' instruction not supported on this functional unit
[^:]*:1261: Error: operand 2 of 'subab' out of range
[^:]*:1262: Error: operand 2 of 'subab' out of range
[^:]*:1263: Error: 'subabs4' instruction not supported on this functional unit
[^:]*:1264: Error: bad number of operands to 'subabs4'
[^:]*:1265: Error: operand 3 of 'subabs4' on wrong side
[^:]*:1266: Error: operand 2 of 'subabs4' on wrong side
[^:]*:1267: Error: 'subah' instruction not supported on this functional unit
[^:]*:1268: Error: bad number of operands to 'subah'
[^:]*:1269: Error: operand 2 of 'subah' on wrong side
[^:]*:1270: Error: 'subah' instruction not supported on this functional unit
[^:]*:1271: Error: 'subah' instruction not supported on this functional unit
[^:]*:1272: Error: operand 2 of 'subah' out of range
[^:]*:1273: Error: operand 2 of 'subah' out of range
[^:]*:1274: Error: 'subaw' instruction not supported on this functional unit
[^:]*:1275: Error: bad number of operands to 'subaw'
[^:]*:1276: Error: operand 2 of 'subaw' on wrong side
[^:]*:1277: Error: 'subaw' instruction not supported on this functional unit
[^:]*:1278: Error: 'subaw' instruction not supported on this functional unit
[^:]*:1279: Error: operand 2 of 'subaw' out of range
[^:]*:1280: Error: operand 2 of 'subaw' out of range
[^:]*:1281: Error: 'subc' instruction not supported on this functional unit
[^:]*:1282: Error: bad number of operands to 'subc'
[^:]*:1283: Error: operand 1 of 'subc' on wrong side
[^:]*:1284: Error: operand 2 of 'subc' on wrong side
[^:]*:1285: Error: 'subdp' instruction not supported on this functional unit
[^:]*:1286: Error: bad number of operands to 'subdp'
[^:]*:1287: Error: operand 1 of 'subdp' on wrong side
[^:]*:1288: Error: bad operand combination for 'subdp'
[^:]*:1289: Error: operand 1 of 'subdp' on wrong side
[^:]*:1290: Error: bad operand combination for 'subdp'
[^:]*:1291: Error: 'subsp' instruction not supported on this functional unit
[^:]*:1292: Error: bad number of operands to 'subsp'
[^:]*:1293: Error: operand 3 of 'subsp' on wrong side
[^:]*:1294: Error: bad operand combination for 'subsp'
[^:]*:1295: Error: bad number of operands to 'subsp'
[^:]*:1296: Error: operand 3 of 'subsp' on wrong side
[^:]*:1297: Error: bad operand combination for 'subsp'
[^:]*:1298: Error: 'subu' instruction not supported on this functional unit
[^:]*:1299: Error: bad number of operands to 'subu'
[^:]*:1300: Error: bad register pair for operand 3 of 'subu'
[^:]*:1301: Error: operand 3 of 'subu' on wrong side
[^:]*:1302: Error: bad operand combination for 'subu'
[^:]*:1303: Error: 'sub2' instruction not supported on this functional unit
[^:]*:1304: Error: bad number of operands to 'sub2'
[^:]*:1305: Error: operand 3 of 'sub2' on wrong side
[^:]*:1306: Error: operand 2 of 'sub2' on wrong side
[^:]*:1307: Error: bad number of operands to 'sub2'
[^:]*:1308: Error: operand 3 of 'sub2' on wrong side
[^:]*:1309: Error: operand 2 of 'sub2' on wrong side
[^:]*:1310: Error: bad number of operands to 'sub2'
[^:]*:1311: Error: operand 3 of 'sub2' on wrong side
[^:]*:1312: Error: operand 2 of 'sub2' on wrong side
[^:]*:1313: Error: 'sub4' instruction not supported on this functional unit
[^:]*:1314: Error: bad number of operands to 'sub4'
[^:]*:1315: Error: operand 3 of 'sub4' on wrong side
[^:]*:1316: Error: operand 2 of 'sub4' on wrong side
[^:]*:1317: Error: 'swap2' instruction not supported on this functional unit
[^:]*:1318: Error: too many operands to 'swap2'
[^:]*:1319: Error: 'swap2' instruction not supported on this functional unit
[^:]*:1320: Error: operand 1 of 'swap2' on wrong side
[^:]*:1321: Error: too many operands to 'swap2'
[^:]*:1322: Error: 'swap2' instruction not supported on this functional unit
[^:]*:1323: Error: operand 1 of 'swap2' on wrong side
[^:]*:1324: Error: 'swap4' instruction not supported on this functional unit
[^:]*:1325: Error: bad number of operands to 'swap4'
[^:]*:1326: Error: operand 2 of 'swap4' on wrong side
[^:]*:1327: Error: operand 1 of 'swap4' on wrong side
[^:]*:1328: Error: 'swe' instruction not supported on this functional unit
[^:]*:1329: Error: too many operands to 'swe'
[^:]*:1330: Error: 'swenr' instruction not supported on this functional unit
[^:]*:1331: Error: too many operands to 'swenr'
[^:]*:1332: Error: 'unpkhu4' instruction not supported on this functional unit
[^:]*:1333: Error: too many operands to 'unpkhu4'
[^:]*:1334: Error: operand 2 of 'unpkhu4' on wrong side
[^:]*:1335: Error: operand 1 of 'unpkhu4' on wrong side
[^:]*:1336: Error: too many operands to 'unpkhu4'
[^:]*:1337: Error: operand 2 of 'unpkhu4' on wrong side
[^:]*:1338: Error: operand 1 of 'unpkhu4' on wrong side
[^:]*:1339: Error: 'unpklu4' instruction not supported on this functional unit
[^:]*:1340: Error: too many operands to 'unpklu4'
[^:]*:1341: Error: operand 2 of 'unpklu4' on wrong side
[^:]*:1342: Error: operand 1 of 'unpklu4' on wrong side
[^:]*:1343: Error: too many operands to 'unpklu4'
[^:]*:1344: Error: operand 2 of 'unpklu4' on wrong side
[^:]*:1345: Error: operand 1 of 'unpklu4' on wrong side
[^:]*:1346: Error: 'not' instruction not supported on this functional unit
[^:]*:1347: Error: too many operands to 'not'
[^:]*:1348: Error: operand 2 of 'not' on wrong side
[^:]*:1349: Error: operand 1 of 'not' on wrong side
[^:]*:1350: Error: too many operands to 'not'
[^:]*:1351: Error: operand 2 of 'not' on wrong side
[^:]*:1352: Error: operand 1 of 'not' on wrong side
[^:]*:1353: Error: too many operands to 'not'
[^:]*:1354: Error: operand 2 of 'not' on wrong side
[^:]*:1355: Error: operand 1 of 'not' on wrong side
[^:]*:1356: Error: 'xor' instruction not supported on this functional unit
[^:]*:1357: Error: bad number of operands to 'xor'
[^:]*:1358: Error: operand 3 of 'xor' on wrong side
[^:]*:1359: Error: operand 2 of 'xor' on wrong side
[^:]*:1360: Error: operand 1 of 'xor' out of range
[^:]*:1361: Error: operand 1 of 'xor' out of range
[^:]*:1362: Error: bad number of operands to 'xor'
[^:]*:1363: Error: operand 3 of 'xor' on wrong side
[^:]*:1364: Error: operand 2 of 'xor' on wrong side
[^:]*:1365: Error: operand 1 of 'xor' out of range
[^:]*:1366: Error: operand 1 of 'xor' out of range
[^:]*:1367: Error: bad number of operands to 'xor'
[^:]*:1368: Error: operand 3 of 'xor' on wrong side
[^:]*:1369: Error: operand 2 of 'xor' on wrong side
[^:]*:1370: Error: operand 1 of 'xor' out of range
[^:]*:1371: Error: operand 1 of 'xor' out of range
[^:]*:1372: Error: 'xormpy' instruction not supported on this functional unit
[^:]*:1373: Error: bad number of operands to 'xormpy'
[^:]*:1374: Error: operand 1 of 'xormpy' on wrong side
[^:]*:1375: Error: operand 2 of 'xormpy' on wrong side
[^:]*:1376: Error: 'xpnd2' instruction not supported on this functional unit
[^:]*:1377: Error: too many operands to 'xpnd2'
[^:]*:1378: Error: operand 2 of 'xpnd2' on wrong side
[^:]*:1379: Error: operand 1 of 'xpnd2' on wrong side
[^:]*:1380: Error: 'xpnd4' instruction not supported on this functional unit
[^:]*:1381: Error: too many operands to 'xpnd4'
[^:]*:1382: Error: operand 2 of 'xpnd4' on wrong side
[^:]*:1383: Error: operand 1 of 'xpnd4' on wrong side
[^:]*:1384: Error: 'zero' instruction not supported on this functional unit
[^:]*:1385: Error: too many operands to 'zero'
[^:]*:1386: Error: operand 1 of 'zero' on wrong side
[^:]*:1387: Error: too many operands to 'zero'
[^:]*:1388: Error: operand 1 of 'zero' on wrong side
[^:]*:1389: Error: too many operands to 'zero'
[^:]*:1390: Error: operand 1 of 'zero' on wrong side
[^:]*:1391: Error: operand 2 of 'sub' out of range
[^:]*:1392: Error: operand 2 of 'sub' out of range
[^:]*:1393: Error: operand 2 of 'sub' out of range
[^:]*:1394: Error: operand 2 of 'sub' out of range
[^:]*:1395: Error: operand 2 of 'sub' out of range
[^:]*:1396: Error: operand 2 of 'sub' out of range
[^:]*:1397: Error: operand 1 of 'addab' not a valid base address register
[^:]*:1398: Error: operand 1 of 'addah' not a valid base address register
[^:]*:1399: Error: operand 1 of 'addaw' not a valid base address register
