! labels starting with a valid register name

.text

sp_label:	lda	r0,sp_label

r0_label:	lda	r0,r0_label
r1_label:	lda	r0,r1_label
r2_label:	lda	r0,r2_label
r3_label:	lda	r0,r3_label
r4_label:	lda	r0,r4_label
r5_label:	lda	r0,r5_label
r6_label:	lda	r0,r6_label
r7_label:	lda	r0,r7_label
r8_label:	lda	r0,r8_label
r9_label:	lda	r0,r9_label
r10_label:	lda	r0,r10_label
r11_label:	lda	r0,r11_label
r12_label:	lda	r0,r12_label
r13_label:	lda	r0,r13_label
r14_label:	lda	r0,r14_label
r15_label:	lda	r0,r15_label
r16_label:	lda	r0,r16_label	! not a valid register name anyway

rr0_label:	lda	r0,rr0_label
rr1_label:	lda	r0,rr1_label	! not a valid register name anyway
rr2_label:	lda	r0,rr2_label
rr3_label:	lda	r0,rr3_label	! not a valid register name anyway
rr4_label:	lda	r0,rr4_label
rr5_label:	lda	r0,rr5_label	! not a valid register name anyway
rr6_label:	lda	r0,rr6_label
rr7_label:	lda	r0,rr7_label	! not a valid register name anyway
rr8_label:	lda	r0,rr8_label
rr9_label:	lda	r0,rr9_label	! not a valid register name anyway
rr10_label:	lda	r0,rr10_label
rr11_label:	lda	r0,rr11_label	! not a valid register name anyway
rr12_label:	lda	r0,rr12_label
rr13_label:	lda	r0,rr13_label	! not a valid register name anyway
rr14_label:	lda	r0,rr14_label
rr15_label:	lda	r0,rr15_label	! not a valid register name anyway
rr16_label:	lda	r0,rr16_label	! not a valid register name anyway

rq0_label:	lda	r0,rq0_label
rq1_label:	lda	r0,rq1_label	! not a valid register name anyway
rq2_label:	lda	r0,rq2_label	! not a valid register name anyway
rq3_label:	lda	r0,rq3_label	! not a valid register name anyway
rq4_label:	lda	r0,rq4_label
rq5_label:	lda	r0,rq5_label	! not a valid register name anyway
rq6_label:	lda	r0,rq6_label	! not a valid register name anyway
rq7_label:	lda	r0,rq7_label	! not a valid register name anyway
rq8_label:	lda	r0,rq8_label
rq9_label:	lda	r0,rq9_label	! not a valid register name anyway
rq10_label:	lda	r0,rq10_label	! not a valid register name anyway
rq11_label:	lda	r0,rq11_label	! not a valid register name anyway
rq12_label:	lda	r0,rq12_label
rq13_label:	lda	r0,rq13_label	! not a valid register name anyway
rq14_label:	lda	r0,rq14_label	! not a valid register name anyway
rq15_label:	lda	r0,rq15_label	! not a valid register name anyway
rq16_label:	lda	r0,rq16_label	! not a valid register name anyway


rh0_label:	lda	r0,rh0_label
rh1_label:	lda	r0,rh1_label
rh2_label:	lda	r0,rh2_label
rh3_label:	lda	r0,rh3_label
rh4_label:	lda	r0,rh4_label
rh5_label:	lda	r0,rh5_label
rh6_label:	lda	r0,rh6_label
rh7_label:	lda	r0,rh7_label
rh8_label:	lda	r0,rh8_label	! not a valid register name anyway
rh9_label:	lda	r0,rh9_label	! not a valid register name anyway
rh10_label:	lda	r0,rh10_label	! not a valid register name anyway
rh11_label:	lda	r0,rh11_label	! not a valid register name anyway
rh12_label:	lda	r0,rh12_label	! not a valid register name anyway
rh13_label:	lda	r0,rh13_label	! not a valid register name anyway
rh14_label:	lda	r0,rh14_label	! not a valid register name anyway
rh15_label:	lda	r0,rh15_label	! not a valid register name anyway
rh16_label:	lda	r0,rh16_label	! not a valid register name anyway

rl0_label:	lda	r0,rl0_label
rl1_label:	lda	r0,rl1_label
rl2_label:	lda	r0,rl2_label
rl3_label:	lda	r0,rl3_label
rl4_label:	lda	r0,rl4_label
rl5_label:	lda	r0,rl5_label
rl6_label:	lda	r0,rl6_label
rl7_label:	lda	r0,rl7_label
rl8_label:	lda	r0,rl8_label	! not a valid register name anyway
rl9_label:	lda	r0,rl9_label	! not a valid register name anyway
rl10_label:	lda	r0,rl10_label	! not a valid register name anyway
rl11_label:	lda	r0,rl11_label	! not a valid register name anyway
rl12_label:	lda	r0,rl12_label	! not a valid register name anyway
rl13_label:	lda	r0,rl13_label	! not a valid register name anyway
rl14_label:	lda	r0,rl14_label	! not a valid register name anyway
rl15_label:	lda	r0,rl15_label	! not a valid register name anyway
rl16_label:	lda	r0,rl16_label	! not a valid register name anyway

r00_label:	lda	r0,r00_label	! not a valid register name anyway

