[^:]*: Assembler messages:
[^:]*:5: Error: too many operands to 'spkernel'
[^:]*:6: Error: 'spkernel' instruction not supported on this functional unit
[^:]*:7: Error: 'spkernelr' instruction not supported on this functional unit
[^:]*:8: Error: too many operands to 'spkernelr'
[^:]*:9: Error: 'sploop' instruction not supported on this functional unit
[^:]*:10: Error: bad number of operands to 'sploop'
[^:]*:11: Error: operand 1 of 'sploop' out of range
[^:]*:12: Error: operand 1 of 'sploop' out of range
[^:]*:13: Error: 'sploopd' instruction not supported on this functional unit
[^:]*:14: Error: bad number of operands to 'sploopd'
[^:]*:15: Error: operand 1 of 'sploopd' out of range
[^:]*:16: Error: operand 1 of 'sploopd' out of range
[^:]*:17: Error: 'sploopw' instruction not supported on this functional unit
[^:]*:18: Error: bad number of operands to 'sploopw'
[^:]*:19: Error: operand 1 of 'sploopw' out of range
[^:]*:20: Error: operand 1 of 'sploopw' out of range
[^:]*:21: Error: 'spmask' instruction not supported on this functional unit
[^:]*:22: Error: bad functional unit for operand 1 of 'spmask'
[^:]*:23: Error: too many operands to 'spmask'
[^:]*:24: Error: 'spmaskr' instruction not supported on this functional unit
[^:]*:25: Error: bad functional unit for operand 1 of 'spmaskr'
[^:]*:26: Error: too many operands to 'spmaskr'
