.*: Assembler messages:
.*:3: Error: Constant out of range.
.*:4: Error: Constant out of range.
.*:6: Error: Bad constant value.
.*:7: Error: Bad constant value.
.*:8: Error: Bad constant value.
.*:9: Error: Bad constant value.
.*:10: Error: Bad constant value.
.*:11: Error: Bad constant value.
.*:13: Error: Dregs expected. Input text was R3.L.
.*:15: Error: Source multiplication register mismatch. Input text was \).
.*:17: Error: bad option.
.*:18: Error: bad option.
.*:19: Error: bad option.
.*:20: Error: bad option.
.*:21: Error: bad option.
.*:22: Error: bad option.
.*:23: Error: Bad opt mode.
.*:24: Error: Bad opt mode.
.*:26: Error: Cannot move A1 to even register. Input text was \).
.*:27: Error: Cannot move A1 to low half of register. Input text was \).
.*:28: Error: Cannot move A0 to odd register. Input text was \).
.*:29: Error: Cannot move A0 to high half of register. Input text was \).
.*:31: Error: Displacement out of range. Input text was r0.
.*:32: Error: Displacement out of range. Input text was r0.
.*:33: Error: Displacement out of range. Input text was r0.
.*:34: Error: Displacement out of range. Input text was r0.
.*:36: Error: Displacement out of range. Input text was r0.
.*:37: Error: Displacement out of range. Input text was r0.
.*:38: Error: Displacement out of range. Input text was r0.
.*:40: Error: Displacement out of range. Input text was r0.
.*:41: Error: Displacement out of range. Input text was r0.
.*:42: Error: Displacement out of range. Input text was r0.
.*:44: Error: Displacement out of range. Input text was \).
.*:45: Error: Displacement out of range. Input text was ].
.*:46: Error: Displacement out of range. Input text was ].
.*:47: Error: Displacement out of range. Input text was ].
.*:49: Error: Plain symbol used as offset. Input text was ].
.*:50: Error: Plain symbol used as offset.
.*:51: Error: Plain symbol used as offset.
.*:53: Error: Displacement out of range. Input text was ].
.*:54: Error: Displacement out of range.
.*:55: Error: Displacement out of range.
.*:57: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was R2.
.*:58: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was R2.
.*:59: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was R2.
.*:60: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was R2.
.*:61: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was R2.
.*:62: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was R2.
.*:64: Error: Preg \+\+ Preg expected in address. Input text was R2.h.
.*:65: Error: Preg \+\+ Preg expected in address. Input text was R2.h.
.*:66: Error: Preg \+\+ Preg expected in address. Input text was R2.h.
.*:67: Error: Preg \+\+ Preg expected in address. Input text was R2.h.
.*:68: Error: Preg \+\+ Preg expected in address. Input text was R2.h.
.*:69: Error: Preg \+\+ Preg expected in address. Input text was R2.h.
.*:71: Error: Ireg or Preg expected in address. Input text was R2.
.*:72: Error: Dreg expected for source operand. Input text was P2.
.*:74: Error: Ireg expected in address. Input text was R2.h.
.*:75: Error: Dreg expected for source operand. Input text was P2.h.
.*:77: Error: Preg expected in address. Input text was R2.
.*:78: Error: Preg expected in address. Input text was R2.
.*:79: Error: Dreg expected for source operand. Input text was P2.
.*:81: Error: Preg expected in address. Input text was R2.
.*:82: Error: Preg expected in address. Input text was R2.
.*:83: Error: Dreg expected for source operand. Input text was P2.
.*:85: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was ].
.*:86: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was ].
.*:87: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was ].
.*:88: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was ].
.*:89: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was ].
.*:90: Error: Preg \+\+ Preg or Ireg \+\+ Mreg expected in address. Input text was ].
.*:92: Error: Preg expected in address. Input text was ].
.*:93: Error: Preg expected in address. Input text was ].
.*:94: Error: Preg expected in address. Input text was ].
.*:95: Error: Preg expected in address. Input text was ].
.*:96: Error: Preg expected in address. Input text was ].
.*:97: Error: Preg expected in address. Input text was ].
.*:99: Error: Ireg or Preg expected in address. Input text was ].
.*:100: Error: Dreg expected in destination operand. Input text was ].
.*:102: Error: syntax error. Input text was B.
.*:102: Error: 
.*:103: Error: syntax error. Input text was B.
.*:103: Error: 
.*:105: Error: Ireg expected in address. Input text was ].
.*:106: Error: Ireg expected in address. Input text was ].
.*:107: Error: Dreg expected for source operand. Input text was ].
.*:109: Error: Preg expected in address. Input text was \).
.*:110: Error: Preg expected in address. Input text was \).
.*:111: Error: Dreg expected for destination operand. Input text was \).
.*:113: Error: Preg expected in address. Input text was \).
.*:114: Error: Preg expected in address. Input text was \).
.*:115: Error: Dreg expected for destination operand. Input text was \).
