.*: Assembler messages:
.*:150: Warning: Condition code register should be even for bc1any2f, was 1
.*:152: Warning: Condition code register should be even for bc1any2t, was 3
.*:154: Warning: Condition code register should be 0 or 4 for bc1any4f, was 1
.*:156: Warning: Condition code register should be 0 or 4 for bc1any4t, was 2
