[^:]*: Assembler messages:
[^:]*:7: Error: operand 1 of 'spkernel' out of range
[^:]*:8: Error: operand 2 of 'spkernel' out of range
[^:]*:9: Error: operand 2 of 'spkernel' out of range
[^:]*:10: Error: operand 1 of 'spkernel' out of range
[^:]*:13: Error: operand 1 of 'spkernel' out of range
[^:]*:14: Error: operand 2 of 'spkernel' out of range
[^:]*:15: Error: operand 2 of 'spkernel' out of range
[^:]*:16: Error: operand 1 of 'spkernel' out of range
[^:]*:19: Error: operand 1 of 'spkernel' out of range
[^:]*:20: Error: operand 2 of 'spkernel' out of range
[^:]*:21: Error: operand 2 of 'spkernel' out of range
[^:]*:22: Error: operand 1 of 'spkernel' out of range
[^:]*:25: Error: operand 1 of 'spkernel' out of range
[^:]*:26: Error: operand 2 of 'spkernel' out of range
[^:]*:27: Error: operand 2 of 'spkernel' out of range
[^:]*:28: Error: operand 1 of 'spkernel' out of range
[^:]*:31: Error: operand 1 of 'spkernel' out of range
[^:]*:32: Error: operand 2 of 'spkernel' out of range
[^:]*:33: Error: operand 2 of 'spkernel' out of range
[^:]*:34: Error: operand 1 of 'spkernel' out of range
[^:]*:37: Error: operand 1 of 'spkernel' out of range
[^:]*:38: Error: operand 2 of 'spkernel' out of range
[^:]*:39: Error: operand 2 of 'spkernel' out of range
[^:]*:40: Error: operand 1 of 'spkernel' out of range
