
Primary GOT:
 Canonical gp value: 00057ff0

 Reserved entries:
   Address     Access  Initial Purpose
  00050000 -32752\(gp\) 00000000 Lazy resolver
  00050004 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  00050008 -32744\(gp\) 00040411

