[^;]*: Assembler messages:
[^;]*:448: Warning: s suffix on comparison instruction is deprecated
[^;]*:448: Warning: s suffix on comparison instruction is deprecated
[^;]*:448: Warning: s suffix on comparison instruction is deprecated
[^;]*:448: Warning: s suffix on comparison instruction is deprecated
[^;]*:449: Warning: s suffix on comparison instruction is deprecated
[^;]*:449: Warning: s suffix on comparison instruction is deprecated
[^;]*:449: Warning: s suffix on comparison instruction is deprecated
[^;]*:449: Warning: s suffix on comparison instruction is deprecated
[^;]*:450: Warning: s suffix on comparison instruction is deprecated
[^;]*:450: Warning: s suffix on comparison instruction is deprecated
[^;]*:450: Warning: s suffix on comparison instruction is deprecated
[^;]*:450: Warning: s suffix on comparison instruction is deprecated
[^;]*:451: Warning: s suffix on comparison instruction is deprecated
[^;]*:451: Warning: s suffix on comparison instruction is deprecated
[^;]*:451: Warning: s suffix on comparison instruction is deprecated
[^;]*:451: Warning: s suffix on comparison instruction is deprecated
