# objdump: -dr
# as: -linkrelax
# source: unsave-op.s
.*:     file format elf64-mmix

Disassembly of section \.text:

0000000000000000 <Main>:
   0:	fb00002d 	unsave 0,\$45
   4:	fb00001f 	unsave 0,\$31
   8:	fb000000 	unsave 0,\$0
