.text

	ei	all
	di	all
	ei	both
	di	both
	ei	vi
	di	vi
	ei	nvi
	di	nvi

	ei	vi,nvi
	ei	nvi,vi
	di	vi,nvi
	di	nvi,vi


	EI	ALL
	DI	ALL
	EI	BOTH
	DI	BOTH
	EI	VI
	DI	VI
	EI	NVI
	DI	NVI

	EI	VI,NVI
	EI	NVI,VI
	DI	VI,NVI
	DI	NVI,VI
