[^:]*: Assembler messages:
[^:]*:26: Warning: s suffix on comparison instruction is deprecated
[^:]*:29: Warning: s suffix on comparison instruction is deprecated
[^:]*:32: Warning: s suffix on comparison instruction is deprecated
[^:]*:35: Warning: s suffix on comparison instruction is deprecated
