#objdump: -dr

dump\.o:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	7f 8c                         	rmpa\.b
   2:	7f 8d                         	rmpa\.w
   4:	7f 8e                         	rmpa\.l
