GAS for MMIX .*/get-op\.s 			page 1


   1              	#.*
   2              	#.*
   3 0000 FE7B0004 	Main	GET X,rJ
   4 0004 FE2D0013 		GET \$45,rG
   5 0008 FEF5001F 		GET \$245,rZZ
   6              	X IS \$123
GAS for MMIX .*/get-op\.s 			page 2


DEFINED SYMBOLS
.*/get-op\.s:3      \.text:0000000000000000 Main
                            \*REG\*:000000000000007b X

NO UNDEFINED SYMBOLS
