	.section ".tbss", "awT", @nobits
	.global	sH1, sH2, sH3, sH4, sH5, sH6, sH7, sH8
	.hidden	sH1, sH2, sH3, sH4, sH5, sH6, sH7, sH8
	.align	4
sH1:	.space	4
sH2:	.space	4
sH3:	.space	4
sH4:	.space	4
sH5:	.space	4
sH6:	.space	4
sH7:	.space	4
sH8:	.space	4
