#source: simple.s
#ld: 
#objdump: -h

.*:     file format elf32-d10v

Sections:
Idx Name          Size      VMA       LMA       File off  Algn
  0 \.text         00000004  01014000  01014000  00001000  2\*\*0
                  CONTENTS, ALLOC, LOAD, READONLY, CODE
