
Primary GOT:
 Canonical gp value: 00057ff0

 Reserved entries:
   Address     Access  Initial Purpose
  00050000 -32752\(gp\) 00000000 Lazy resolver
  00050004 -32748\(gp\) 80000000 Module pointer \(GNU extension\)


PLT GOT:

 Reserved entries:
   Address  Initial Purpose
  00050400 00000000 PLT lazy resolver
  00050404 00000000 Module pointer

 Entries:
   Address  Initial Sym.Val. Type    Ndx Name
  00050408 00040600 00040620 FUNC    UND extern3
  0005040c 00040600 00040630 FUNC    UND extern2
  00050410 00040600 00040640 FUNC    UND extern4
  00050414 00040600 00040650 FUNC    UND extern1
