EXPORTS
    A @1
    B @2
    C @3
    D @4
    E @5
    GC_abort @6
    GC_add_ext_descriptor @7
    GC_add_leaked @8
    GC_add_map_entry @9
    GC_used_heap_size_after_full @10
    GC_version @11
    GC_with_callee_saves_pushed @12
    GC_words_allocd_at_reset @13
    GC_world_stopped @14
    GC_write @15
    JIS0208_to_Unicode @16
    JIS0212_to_Unicode @17
    JvConvertArgv @18
    JvRunMain @19
    JvRunMainName @20
    Unicode_to_JIS @21
    _Jv_AllocBytes @22
    _Jv_AllocObject @23
    _Jv_AllocObjectNoFinalizer @24
    _Jv_JNIFunctions @25
    _Jv_JNI_InvokeFunctions @26
    _Jv_JNI_PopSystemFrame @27
    _Jv_JVMPI_Notify_OBJECT_ALLOC @28
    _Jv_JVMPI_Notify_THREAD_END @29
    _Jv_JVMPI_Notify_THREAD_START @30
    _Jv_JVMTI_Interface @31
    _Jv_LookupInterfaceMethod @32
    _Jv_LookupInterfaceMethodIdx @33
    _Jv_LookupJNIMethod @34
    _Jv_Malloc @35
    _Jv_Throw @36
    _Jv_ThrowAbstractMethodError @37
    _Jv_UnwrapJNIweakReference @38
    _Jv__mcmp @39
    _Jv__mdiff @40
    _Jv__mprec_bigtens @41
    _Jv__mprec_tinytens @42
    _Jv_argc @43
    _Jv_argv @44
    _Jv_b2d @45
    _Jv_booleanClass @46
    _Jv_byteClass @47
    _Jv_charClass @48
    _Jv_d2b @49
    _Jv_ulp @50
    _Jv_voidClass @51
    _Z10_Jv_InitGCv @52
    _Z10_Jv_equalnP13_Jv_Utf8ConstPN4java4lang6StringEi @53
    _Z11_Jv_SetArgsiPPKc @54
    _Z11_Jv_ZMallocPvjj @55
    _Z11trie_lookupPtt @56
    _Z12_Jv_CondWaitP23_Jv_ConditionVariable_tP11_Jv_Mutex_txi @57
    _Z12_Jv_init_cifP13_Jv_Utf8ConstibP7ffi_cifPP9_ffi_typeS5_ @58
    _Z12_Jv_is_proxyPv @59
    _Z12shsTransformP8SHS_INFO @60
    _Z13_Jv_DisableGCv @61
    _Z15_Jv_create_coreP14_Jv_core_chainPN4java4lang6StringE @62
    _Z16_Jv_BlockSigchldv @63
    _Z16_Jv_BuildGCDescrPN4java4lang5ClassE @64
    _Z16_Jv_GCFreeMemoryv @65
    _Z16_Jv_SetStackSizePKc @66
    _Z16_Jv_VerifyMethodP16_Jv_InterpMethod @67
    _Z17JvNewStringLatin1PKc @68
    _Z24_Jv_isPrimitiveOrDerivedPK13_Jv_Utf8Const @69
    _Z26_Jv_FindSymbolInExecutablePKc @70
    _Z26_Jv_GCInitializeFinalizersPFvvE @71
    _Z37_Jv_FindClassFromSignatureNoExceptionPcPN4java4lang11ClassLoaderEPS_ @72
    _Z39_Jv_ThrowNoClassDefFoundErrorTrampolineP7ffi_cifPvPS1_S1_ @73
    _Z7in_hashPN4java4lang6ObjectE @74
    _Z7shsInitP8SHS_INFO @75
    _Z8shsFinalP8SHS_INFO @76
    _Z9_Jv_AbortPKcS0_iS0_ @77
    _Z9_Jv_RunGCv @78
    _Z9_Jv_ZFreePvS_ @79
    _Z9_Jv_equalP13_Jv_Utf8ConstPN4java4lang6StringEi @80
    _Z9shsUpdateP8SHS_INFOPhi @81
    _ZGr30_java_Sutil_Sweeks__properties @82
    _ZGr32_java_Sutil_Siso4217__properties @83
    _ZGr48_gnu_Sjavax_Sprint_SPrinterDialog_de__properties @84
    _ZGr49_gnu_Sjava_Slocale_SLocaleInformation__properties @85
    _ZGr51_gnu_Sjava_Sutil_Sregex_SMessagesBundle__properties @86
    _ZTVN5javax8security4auth4x50021X500PrivateCredentialE @87
    _ZTVN5javax8security4auth5login12LoginContextE @88
    _ZTVN5javax8security4auth5login13ConfigurationE @89
    _ZTVN5javax8security4auth5login14LoginExceptionE @90
    _ZTVN5javax8security4sasl19RealmChoiceCallbackE @91
    _ZTVN5javax8security4sasl23AuthenticationExceptionE @92
    _ZTVN5javax8security4sasl4SaslE @93
    __gcj_personality_v0 @94
    __ieee754_acos @95
    __ieee754_asin @96
    __ieee754_atan2 @97
    __kernel_cos @98
    __kernel_rem_pio2 @99
    __kernel_sin @100
    __kernel_tan @101
    _dist_code @102
    _length_code @103
    _mprec_log10 @104
    _tr_align @105
    _tr_flush_block @106
    _tr_init @107
    _tr_stored_block @108
    _tr_tally @109
    adler32 @110
    adler32_combine @111
    crc32 @112
    crc32_combine @113
    deflate @114
    deflateBound @115
    deflateCopy @116
    ffi_call_STDCALL @117
    ffi_call_SYSV @118
    ffi_closure_SYSV @119
    ffi_closure_SYSV_inner @120
    ffi_closure_alloc @121
    ffi_closure_free @122
    free_list_index_of @123
    get_crc_table @124
    gzclearerr @125
    gzclose @126
    gzungetc @127
    gzwrite @128
    h0 @129
    h1 @130
    h2 @131
    h3 @132
    h4 @133
    inflate @134
    inflateBack @135
    inflateBackEnd @136
    inflate_fast @137
    inflate_table @138
    lt_dladderror @139
    lt_dladdsearchdir @140
    lt_dlsetsearchpath @141
    lt_dlsym @142
    lt_preloaded_symbols @143
    print @144
    thread_table @145
    uncompress @146
    zError @147
    z_errmsg @148
    zcalloc @149
    zcfree @150
    zlibCompileFlags @151
    zlibVersion @152
