[^:]*: Assembler messages:
[^:]*:6: Error: r15 not allowed here -- `bfc pc,#0,#1'
[^:]*:7: Error: r15 not allowed here -- `bfi pc,r0,#0,#1'
[^:]*:8: Error: r15 not allowed here -- `movw pc,#0'
[^:]*:9: Error: r15 not allowed here -- `movt pc,#0'
[^:]*:12: Error: immediate value out of range -- `bfc r0,#0,#0'
[^:]*:13: Error: immediate value out of range -- `bfc r0,#32,#0'
[^:]*:14: Error: immediate value out of range -- `bfc r0,#0,#33'
[^:]*:15: Error: immediate value out of range -- `bfc r0,#33,#1'
[^:]*:16: Error: immediate value out of range -- `bfc r0,#32,#1'
[^:]*:17: Error: bit-field extends past end of register -- `bfc r0,#28,#10'
[^:]*:19: Error: immediate value out of range -- `bfi r0,r1,#0,#0'
[^:]*:20: Error: immediate value out of range -- `bfi r0,r1,#32,#0'
[^:]*:21: Error: immediate value out of range -- `bfi r0,r1,#0,#33'
[^:]*:22: Error: immediate value out of range -- `bfi r0,r1,#33,#1'
[^:]*:23: Error: immediate value out of range -- `bfi r0,r1,#32,#1'
[^:]*:24: Error: bit-field extends past end of register -- `bfi r0,r1,#28,#10'
[^:]*:26: Error: immediate value out of range -- `sbfx r0,r1,#0,#0'
[^:]*:27: Error: immediate value out of range -- `sbfx r0,r1,#32,#0'
[^:]*:28: Error: immediate value out of range -- `sbfx r0,r1,#0,#33'
[^:]*:29: Error: immediate value out of range -- `sbfx r0,r1,#33,#1'
[^:]*:30: Error: immediate value out of range -- `sbfx r0,r1,#32,#1'
[^:]*:31: Error: bit-field extends past end of register -- `sbfx r0,r1,#28,#10'
[^:]*:33: Error: immediate value out of range -- `ubfx r0,r1,#0,#0'
[^:]*:34: Error: immediate value out of range -- `ubfx r0,r1,#32,#0'
[^:]*:35: Error: immediate value out of range -- `ubfx r0,r1,#0,#33'
[^:]*:36: Error: immediate value out of range -- `ubfx r0,r1,#33,#1'
[^:]*:37: Error: immediate value out of range -- `ubfx r0,r1,#32,#1'
[^:]*:38: Error: bit-field extends past end of register -- `ubfx r0,r1,#28,#10'
[^:]*:41: Error: immediate value out of range -- `bfi r0,#1,#2,#3'
[^:]*:44: Error: immediate value out of range -- `movt r0,#65537'
[^:]*:45: Error: immediate value out of range -- `movw r0,#65537'
[^:]*:46: Error: immediate value out of range -- `movt r0,#-1'
[^:]*:47: Error: immediate value out of range -- `movw r0,#-1'
[^:]*:50: Warning: destination register same as write-back base
[^:]*:51: Warning: destination register same as write-back base
[^:]*:52: Warning: destination register same as write-back base
[^:]*:53: Warning: source register same as write-back base
[^:]*:59: Error: instruction does not accept this addressing mode -- `ldrex r0,r2'
[^:]*:60: Error: instruction does not accept this addressing mode -- `strex r1,r0,r2'
