.text
xc16x_jmpa:
	jmpa cc_UC,0xaaaa
	jmpa cc_Z,0xaaaa
	jmpa cc_NZ,0xaaaa
	jmpa cc_V,0xaaaa
	jmpa cc_NV,0xaaaa
	jmpa cc_N,0xaaaa
	jmpa cc_NN,0xaaaa
	jmpa cc_ULT,0xaaaa
	jmpa cc_UGE,0xaaaa
	jmpa cc_Z,0xaaaa
	jmpa cc_NZ,0xaaaa
	jmpa cc_ULT,0xaaaa
	jmpa cc_ULE,0xaaaa
	jmpa cc_UGE,0xaaaa
	jmpa cc_UGT,0xaaaa
	jmpa cc_SLE,0xaaaa
	jmpa cc_SGE,0xaaaa
	jmpa cc_SGT,0xaaaa
	jmpa cc_NET,0xaaaa

		
