[^:]*: Assembler messages:
[^:]*:8: Error: selected processor does not support Thumb mode `pkhbt r0,r0,r0'
[^:]*:9: Error: selected processor does not support Thumb mode `pkhbt r9,r0,r0'
[^:]*:10: Error: selected processor does not support Thumb mode `pkhbt r0,r9,r0'
[^:]*:11: Error: selected processor does not support Thumb mode `pkhbt r0,r0,r9'
[^:]*:12: Error: selected processor does not support Thumb mode `pkhbt r0,r0,r0,lsl#0x14'
[^:]*:13: Error: selected processor does not support Thumb mode `pkhbt r0,r0,r0,lsl#3'
[^:]*:14: Error: selected processor does not support Thumb mode `pkhtb r1,r2,r3'
[^:]*:15: Error: selected processor does not support Thumb mode `pkhtb r1,r2,r3,asr#0x11'
[^:]*:18: Error: selected processor does not support Thumb mode `qadd r1,r2,r3'
[^:]*:19: Error: selected processor does not support Thumb mode `qadd16 r1,r2,r3'
[^:]*:20: Error: selected processor does not support Thumb mode `qadd8 r1,r2,r3'
[^:]*:21: Error: selected processor does not support Thumb mode `qasx r1,r2,r3'
[^:]*:22: Error: selected processor does not support Thumb mode `qaddsubx r1,r2,r3'
[^:]*:23: Error: selected processor does not support Thumb mode `qdadd r1,r2,r3'
[^:]*:24: Error: selected processor does not support Thumb mode `qdsub r1,r2,r3'
[^:]*:25: Error: selected processor does not support Thumb mode `qsub r1,r2,r3'
[^:]*:26: Error: selected processor does not support Thumb mode `qsub16 r1,r2,r3'
[^:]*:27: Error: selected processor does not support Thumb mode `qsub8 r1,r2,r3'
[^:]*:28: Error: selected processor does not support Thumb mode `qsax r1,r2,r3'
[^:]*:29: Error: selected processor does not support Thumb mode `qsubaddx r1,r2,r3'
[^:]*:30: Error: selected processor does not support Thumb mode `sadd16 r1,r2,r3'
[^:]*:31: Error: selected processor does not support Thumb mode `sadd8 r1,r2,r3'
[^:]*:32: Error: selected processor does not support Thumb mode `sasx r1,r2,r3'
[^:]*:33: Error: selected processor does not support Thumb mode `saddsubx r1,r2,r3'
[^:]*:34: Error: selected processor does not support Thumb mode `ssub16 r1,r2,r3'
[^:]*:35: Error: selected processor does not support Thumb mode `ssub8 r1,r2,r3'
[^:]*:36: Error: selected processor does not support Thumb mode `ssax r1,r2,r3'
[^:]*:37: Error: selected processor does not support Thumb mode `ssubaddx r1,r2,r3'
[^:]*:38: Error: selected processor does not support Thumb mode `shadd16 r1,r2,r3'
[^:]*:39: Error: selected processor does not support Thumb mode `shadd8 r1,r2,r3'
[^:]*:40: Error: selected processor does not support Thumb mode `shasx r1,r2,r3'
[^:]*:41: Error: selected processor does not support Thumb mode `shaddsubx r1,r2,r3'
[^:]*:42: Error: selected processor does not support Thumb mode `shsub16 r1,r2,r3'
[^:]*:43: Error: selected processor does not support Thumb mode `shsub8 r1,r2,r3'
[^:]*:44: Error: selected processor does not support Thumb mode `shsax r1,r2,r3'
[^:]*:45: Error: selected processor does not support Thumb mode `shsubaddx r1,r2,r3'
[^:]*:46: Error: selected processor does not support Thumb mode `uadd16 r1,r2,r3'
[^:]*:47: Error: selected processor does not support Thumb mode `uadd8 r1,r2,r3'
[^:]*:48: Error: selected processor does not support Thumb mode `uasx r1,r2,r3'
[^:]*:49: Error: selected processor does not support Thumb mode `uaddsubx r1,r2,r3'
[^:]*:50: Error: selected processor does not support Thumb mode `usub16 r1,r2,r3'
[^:]*:51: Error: selected processor does not support Thumb mode `usub8 r1,r2,r3'
[^:]*:52: Error: selected processor does not support Thumb mode `usax r1,r2,r3'
[^:]*:53: Error: selected processor does not support Thumb mode `usubaddx r1,r2,r3'
[^:]*:54: Error: selected processor does not support Thumb mode `uhadd16 r1,r2,r3'
[^:]*:55: Error: selected processor does not support Thumb mode `uhadd8 r1,r2,r3'
[^:]*:56: Error: selected processor does not support Thumb mode `uhasx r1,r2,r3'
[^:]*:57: Error: selected processor does not support Thumb mode `uhaddsubx r1,r2,r3'
[^:]*:58: Error: selected processor does not support Thumb mode `uhsub16 r1,r2,r3'
[^:]*:59: Error: selected processor does not support Thumb mode `uhsub8 r1,r2,r3'
[^:]*:60: Error: selected processor does not support Thumb mode `uhsax r1,r2,r3'
[^:]*:61: Error: selected processor does not support Thumb mode `uhsubaddx r1,r2,r3'
[^:]*:62: Error: selected processor does not support Thumb mode `uqadd16 r1,r2,r3'
[^:]*:63: Error: selected processor does not support Thumb mode `uqadd8 r1,r2,r3'
[^:]*:64: Error: selected processor does not support Thumb mode `uqasx r1,r2,r3'
[^:]*:65: Error: selected processor does not support Thumb mode `uqaddsubx r1,r2,r3'
[^:]*:66: Error: selected processor does not support Thumb mode `uqsub16 r1,r2,r3'
[^:]*:67: Error: selected processor does not support Thumb mode `uqsub8 r1,r2,r3'
[^:]*:68: Error: selected processor does not support Thumb mode `uqsax r1,r2,r3'
[^:]*:69: Error: selected processor does not support Thumb mode `uqsubaddx r1,r2,r3'
[^:]*:70: Error: selected processor does not support Thumb mode `sel r1,r2,r3'
[^:]*:73: Error: selected processor does not support Thumb mode `smlabb r0,r0,r0,r0'
[^:]*:74: Error: selected processor does not support Thumb mode `smlabb r9,r0,r0,r0'
[^:]*:75: Error: selected processor does not support Thumb mode `smlabb r0,r9,r0,r0'
[^:]*:76: Error: selected processor does not support Thumb mode `smlabb r0,r0,r9,r0'
[^:]*:77: Error: selected processor does not support Thumb mode `smlabb r0,r0,r0,r9'
[^:]*:79: Error: selected processor does not support Thumb mode `smlatb r0,r0,r0,r0'
[^:]*:80: Error: selected processor does not support Thumb mode `smlabt r0,r0,r0,r0'
[^:]*:81: Error: selected processor does not support Thumb mode `smlatt r0,r0,r0,r0'
[^:]*:82: Error: selected processor does not support Thumb mode `smlawb r0,r0,r0,r0'
[^:]*:83: Error: selected processor does not support Thumb mode `smlawt r0,r0,r0,r0'
[^:]*:84: Error: selected processor does not support Thumb mode `smlad r0,r0,r0,r0'
[^:]*:85: Error: selected processor does not support Thumb mode `smladx r0,r0,r0,r0'
[^:]*:86: Error: selected processor does not support Thumb mode `smlsd r0,r0,r0,r0'
[^:]*:87: Error: selected processor does not support Thumb mode `smlsdx r0,r0,r0,r0'
[^:]*:88: Error: selected processor does not support Thumb mode `smmla r0,r0,r0,r0'
[^:]*:89: Error: selected processor does not support Thumb mode `smmlar r0,r0,r0,r0'
[^:]*:90: Error: selected processor does not support Thumb mode `smmls r0,r0,r0,r0'
[^:]*:91: Error: selected processor does not support Thumb mode `smmlsr r0,r0,r0,r0'
[^:]*:92: Error: selected processor does not support Thumb mode `usada8 r0,r0,r0,r0'
[^:]*:95: Error: selected processor does not support Thumb mode `smlalbb r0,r0,r0,r0'
[^:]*:96: Error: selected processor does not support Thumb mode `smlalbb r9,r0,r0,r0'
[^:]*:97: Error: selected processor does not support Thumb mode `smlalbb r0,r9,r0,r0'
[^:]*:98: Error: selected processor does not support Thumb mode `smlalbb r0,r0,r9,r0'
[^:]*:99: Error: selected processor does not support Thumb mode `smlalbb r0,r0,r0,r9'
[^:]*:101: Error: selected processor does not support Thumb mode `smlaltb r0,r0,r0,r0'
[^:]*:102: Error: selected processor does not support Thumb mode `smlalbt r0,r0,r0,r0'
[^:]*:103: Error: selected processor does not support Thumb mode `smlaltt r0,r0,r0,r0'
[^:]*:104: Error: selected processor does not support Thumb mode `smlald r0,r0,r0,r0'
[^:]*:105: Error: selected processor does not support Thumb mode `smlaldx r0,r0,r0,r0'
[^:]*:106: Error: selected processor does not support Thumb mode `smlsld r0,r0,r0,r0'
[^:]*:107: Error: selected processor does not support Thumb mode `smlsldx r0,r0,r0,r0'
[^:]*:108: Error: selected processor does not support Thumb mode `umaal r0,r0,r0,r0'
[^:]*:111: Error: selected processor does not support Thumb mode `smulbb r0,r0,r0'
[^:]*:112: Error: selected processor does not support Thumb mode `smulbb r9,r0,r0'
[^:]*:113: Error: selected processor does not support Thumb mode `smulbb r0,r9,r0'
[^:]*:114: Error: selected processor does not support Thumb mode `smulbb r0,r0,r9'
[^:]*:116: Error: selected processor does not support Thumb mode `smultb r0,r0,r0'
[^:]*:117: Error: selected processor does not support Thumb mode `smulbt r0,r0,r0'
[^:]*:118: Error: selected processor does not support Thumb mode `smultt r0,r0,r0'
[^:]*:119: Error: selected processor does not support Thumb mode `smulwb r0,r0,r0'
[^:]*:120: Error: selected processor does not support Thumb mode `smulwt r0,r0,r0'
[^:]*:121: Error: selected processor does not support Thumb mode `smmul r0,r0,r0'
[^:]*:122: Error: selected processor does not support Thumb mode `smmulr r0,r0,r0'
[^:]*:123: Error: selected processor does not support Thumb mode `smuad r0,r0,r0'
[^:]*:124: Error: selected processor does not support Thumb mode `smuadx r0,r0,r0'
[^:]*:125: Error: selected processor does not support Thumb mode `smusd r0,r0,r0'
[^:]*:126: Error: selected processor does not support Thumb mode `smusdx r0,r0,r0'
[^:]*:127: Error: selected processor does not support Thumb mode `usad8 r0,r0,r0'
[^:]*:130: Error: selected processor does not support Thumb mode `ssat16 r0,#1,r0'
[^:]*:131: Error: selected processor does not support Thumb mode `ssat16 r9,#1,r0'
[^:]*:132: Error: selected processor does not support Thumb mode `ssat16 r0,#10,r0'
[^:]*:133: Error: selected processor does not support Thumb mode `ssat16 r0,#1,r9'
[^:]*:135: Error: selected processor does not support Thumb mode `usat16 r0,#0,r0'
[^:]*:136: Error: selected processor does not support Thumb mode `usat16 r9,#0,r0'
[^:]*:137: Error: selected processor does not support Thumb mode `usat16 r0,#9,r0'
[^:]*:138: Error: selected processor does not support Thumb mode `usat16 r0,#0,r9'
[^:]*:141: Error: selected processor does not support Thumb mode `sxtb16 r1,r2'
[^:]*:142: Error: selected processor does not support Thumb mode `sxtb16 r8,r9'
[^:]*:143: Error: selected processor does not support Thumb mode `uxtb16 r1,r2'
[^:]*:144: Error: selected processor does not support Thumb mode `uxtb16 r8,r9'
[^:]*:147: Error: selected processor does not support Thumb mode `sxtab r0,r0,r0'
[^:]*:148: Error: selected processor does not support Thumb mode `sxtab r0,r0,r0,ror#0'
[^:]*:149: Error: selected processor does not support Thumb mode `sxtab r9,r0,r0,ror#8'
[^:]*:150: Error: selected processor does not support Thumb mode `sxtab r0,r9,r0,ror#16'
[^:]*:151: Error: selected processor does not support Thumb mode `sxtab r0,r0,r9,ror#24'
[^:]*:153: Error: selected processor does not support Thumb mode `sxtab16 r1,r2,r3'
[^:]*:154: Error: selected processor does not support Thumb mode `sxtah r1,r2,r3'
[^:]*:155: Error: selected processor does not support Thumb mode `uxtab r1,r2,r3'
[^:]*:156: Error: selected processor does not support Thumb mode `uxtab16 r1,r2,r3'
[^:]*:157: Error: selected processor does not support Thumb mode `uxtah r1,r2,r3'
