[^:]*: Assembler messages:
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:31: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:36: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:37: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:37: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:37: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:37: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:37: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:38: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:38: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:38: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:38: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:38: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:42: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:43: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:44: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:44: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:44: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:44: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:44: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:45: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:45: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:45: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:45: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:45: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:47: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:48: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:49: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:49: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:49: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:49: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:49: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:50: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:50: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:50: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:50: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
[^:]*:50: Error: bad offset 0x00000100 \(only 8 bits available for the magnitude\)
