#nm: --undefined-only
#name: weakref tests, weak undefined syms
#source: weakref1.s
# see weakref1.d for comments on the not-targets
#not-target: alpha*-*-osf* *-*-ecoff pdp11-*-aout

# the rest of this file is generated with the following script:
# # script begin
# sed -n 's:^[ 	]*\.weakref .*, \(w.*\)$:.* w \1:p' weakref1.s | uniq | while read line; do echo "#..."; echo "$line"; done
# echo \#pass
# # script output:
#...
.* w wa1
#...
.* w wb1
#...
.* w wc1
#...
.* w wh2
#...
.* w wh3
#...
.* w wh4
#...
.* w wh5
#...
.* w wh6
#...
.* w wh7
#...
.* w wm6
#...
.* w wm7
#...
.* w wm8
#...
.* w ww1
#...
.* w ww10
#...
.* w ww2
#...
.* w ww3
#...
.* w ww4
#...
.* w ww5
#...
.* w ww6
#...
.* w ww7
#...
.* w ww8
#...
.* w ww9
#pass
