[^:]*: Assembler messages:
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:27: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:28: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:29: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:30: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:32: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:33: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:34: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
[^:]*:35: Error: bad offset 0x00001000 \(only 12 bits available for the magnitude\)
