LANGUAGE 0, 0
 
A BITMAP MOVEABLE PURE DISCARDABLE "bmp1.bmp"
 
AB BITMAP MOVEABLE PURE DISCARDABLE "bmp1.bmp"
 
ABC BITMAP MOVEABLE PURE DISCARDABLE "bmp1.bmp"

ABCD BITMAP MOVEABLE PURE DISCARDABLE "bmp1.bmp"
