EXPORTS
    JvConvertArgv @1
    JvRunMain @2
    JvRunMainName @3
    _Jv_AllocBytes @4
    _Jv_AllocObject @5
    _Jv_AllocObjectNoFinalizer @6
    _Jv_JNIFunctions @7
    _Jv_JNI_InvokeFunctions @8
    _Jv_JNI_PopSystemFrame @9
    _Jv_JVMPI_Notify_OBJECT_ALLOC @10
    _Jv_JVMPI_Notify_THREAD_END @11
    _Jv_JVMPI_Notify_THREAD_START @12
    _Jv_JVMTI_Interface @13
    _Jv_LookupInterfaceMethod @14
    _Jv_LookupInterfaceMethodIdx @15
    _Jv_LookupJNIMethod @16
    _Jv_Malloc @17
    _Jv_Throw @18
    _Jv_ThrowAbstractMethodError @19
    _Jv_UnwrapJNIweakReference @20
    _Jv__mcmp @21
    _Jv__mdiff @22
    _Jv__mprec_bigtens @23
    _Jv__mprec_tinytens @24
    _Jv_argc @25
    _Jv_argv @26
    _Jv_b2d @27
    _Jv_booleanClass @28
    _Jv_byteClass @29
    _Jv_charClass @30
    _Jv_d2b @31
    _Jv_ulp @32
    _Jv_voidClass @33
    _Z10_Jv_InitGCv @34
    _Z10_Jv_equalnP13_Jv_Utf8ConstPN4java4lang6StringEi @35
    _Z11_Jv_SetArgsiPPKc @36
    _Z11_Jv_ZMallocPvjj @37
    _Z11trie_lookupPtt @38
    _Z12_Jv_CondWaitP23_Jv_ConditionVariable_tP11_Jv_Mutex_txi @39
    _Z12_Jv_init_cifP13_Jv_Utf8ConstibP7ffi_cifPP9_ffi_typeS5_ @40
    _Z12_Jv_is_proxyPv @41
    _Z12shsTransformP8SHS_INFO @42
    _Z13_Jv_DisableGCv @43
    _Z15_Jv_create_coreP14_Jv_core_chainPN4java4lang6StringE @44
    _Z16_Jv_BlockSigchldv @45
    _Z16_Jv_BuildGCDescrPN4java4lang5ClassE @46
    _Z16_Jv_GCFreeMemoryv @47
    _Z16_Jv_SetStackSizePKc @48
    _Z16_Jv_VerifyMethodP16_Jv_InterpMethod @49
    _Z17JvNewStringLatin1PKc @50
    _Z24_Jv_isPrimitiveOrDerivedPK13_Jv_Utf8Const @51
    _Z26_Jv_FindSymbolInExecutablePKc @52
    _Z26_Jv_GCInitializeFinalizersPFvvE @53
    _Z37_Jv_FindClassFromSignatureNoExceptionPcPN4java4lang11ClassLoaderEPS_ @54
    _Z39_Jv_ThrowNoClassDefFoundErrorTrampolineP7ffi_cifPvPS1_S1_ @55
    _Z7in_hashPN4java4lang6ObjectE @56
    _Z7shsInitP8SHS_INFO @57
    _Z8shsFinalP8SHS_INFO @58
    _Z9_Jv_AbortPKcS0_iS0_ @59
    _Z9_Jv_RunGCv @60
    _Z9_Jv_ZFreePvS_ @61
    _Z9_Jv_equalP13_Jv_Utf8ConstPN4java4lang6StringEi @62
    _Z9shsUpdateP8SHS_INFOPhi @63
    _ZGr30_java_Sutil_Sweeks__properties @64
    _ZGr32_java_Sutil_Siso4217__properties @65
    _ZGr48_gnu_Sjavax_Sprint_SPrinterDialog_de__properties @66
    _ZGr49_gnu_Sjava_Slocale_SLocaleInformation__properties @67
    _ZGr51_gnu_Sjava_Sutil_Sregex_SMessagesBundle__properties @68
    _ZTVN5javax8security4auth4x50021X500PrivateCredentialE @69
    _ZTVN5javax8security4auth5login12LoginContextE @70
    _ZTVN5javax8security4auth5login13ConfigurationE @71
    _ZTVN5javax8security4auth5login14LoginExceptionE @72
    _ZTVN5javax8security4sasl19RealmChoiceCallbackE @73
    _ZTVN5javax8security4sasl23AuthenticationExceptionE @74
    _ZTVN5javax8security4sasl4SaslE @75
    __gcj_personality_v0 @76
