#readelf: -wl
#source: branch.s
#as: --em=criself --gdwarf2

# Complicated branch expansion.
#...
 Line Number Statements:
  Extended opcode 2: set Address to 0x0
  Special opcode .*: advance Address by 0 to 0x0 and Line by 7 to 8
  Special opcode .*: advance Address by 2 to 0x2 and Line by 2 to 10
  Advance PC by 32360 to 0x7e6a
  Special opcode .*: advance Address by 0 to 0x7e6a and Line by 3 to 13
  Advance PC by 196 to 0x7f2e
  Special opcode .*: advance Address by 0 to 0x7f2e and Line by 6 to 19
  Special opcode .*: advance Address by 2 to 0x7f30 and Line by 1 to 20
  Special opcode .*: advance Address by 2 to 0x7f32 and Line by 1 to 21
  Special opcode .*: advance Address by 2 to 0x7f34 and Line by 1 to 22
  Special opcode .*: advance Address by 2 to 0x7f36 and Line by 1 to 23
  Special opcode .*: advance Address by 2 to 0x7f38 and Line by 1 to 24
  Special opcode .*: advance Address by 2 to 0x7f3a and Line by 1 to 25
  Special opcode .*: advance Address by 2 to 0x7f3c and Line by 1 to 26
  Special opcode .*: advance Address by 2 to 0x7f3e and Line by 1 to 27
  Special opcode .*: advance Address by 2 to 0x7f40 and Line by 1 to 28
  Special opcode .*: advance Address by 2 to 0x7f42 and Line by 1 to 29
  Special opcode .*: advance Address by 2 to 0x7f44 and Line by 1 to 30
  Special opcode .*: advance Address by 2 to 0x7f46 and Line by 1 to 31
  Special opcode .*: advance Address by 2 to 0x7f48 and Line by 1 to 32
  Special opcode .*: advance Address by 2 to 0x7f4a and Line by 1 to 33
  Special opcode .*: advance Address by 2 to 0x7f4c and Line by 1 to 34
  Special opcode .*: advance Address by 2 to 0x7f4e and Line by 1 to 35
  Special opcode .*: advance Address by 2 to 0x7f50 and Line by 1 to 36
  Special opcode .*: advance Address by 2 to 0x7f52 and Line by 1 to 37
  Special opcode .*: advance Address by 2 to 0x7f54 and Line by 1 to 38
  Special opcode .*: advance Address by 2 to 0x7f56 and Line by 1 to 39
  Special opcode .*: advance Address by 2 to 0x7f58 and Line by 2 to 41
  Special opcode .*: advance Address by 2 to 0x7f5a and Line by 1 to 42
  Special opcode .*: advance Address by 2 to 0x7f5c and Line by 1 to 43
  Special opcode .*: advance Address by 2 to 0x7f5e and Line by 1 to 44
  Special opcode .*: advance Address by 2 to 0x7f60 and Line by 1 to 45
  Special opcode .*: advance Address by 2 to 0x7f62 and Line by 1 to 46
  Special opcode .*: advance Address by 2 to 0x7f64 and Line by 1 to 47
  Special opcode .*: advance Address by 2 to 0x7f66 and Line by 1 to 48
  Special opcode .*: advance Address by 2 to 0x7f68 and Line by 1 to 49
  Special opcode .*: advance Address by 2 to 0x7f6a and Line by 1 to 50
  Special opcode .*: advance Address by 4 to 0x7f6e and Line by 1 to 51
  Special opcode .*: advance Address by 4 to 0x7f72 and Line by 1 to 52
  Special opcode .*: advance Address by 4 to 0x7f76 and Line by 1 to 53
  Special opcode .*: advance Address by 4 to 0x7f7a and Line by 1 to 54
  Special opcode .*: advance Address by 4 to 0x7f7e and Line by 1 to 55
  Special opcode .*: advance Address by 4 to 0x7f82 and Line by 1 to 56
  Special opcode .*: advance Address by 4 to 0x7f86 and Line by 1 to 57
  Special opcode .*: advance Address by 4 to 0x7f8a and Line by 1 to 58
  Special opcode .*: advance Address by 4 to 0x7f8e and Line by 1 to 59
  Special opcode .*: advance Address by 4 to 0x7f92 and Line by 1 to 60
  Special opcode .*: advance Address by 4 to 0x7f96 and Line by 1 to 61
  Special opcode .*: advance Address by 4 to 0x7f9a and Line by 4 to 65
  Special opcode .*: advance Address by 2 to 0x7f9c and Line by 1 to 66
  Special opcode .*: advance Address by 4 to 0x7fa0 and Line by 1 to 67
  Special opcode .*: advance Address by 4 to 0x7fa4 and Line by 1 to 68
  Special opcode .*: advance Address by 4 to 0x7fa8 and Line by 1 to 69
  Special opcode .*: advance Address by 4 to 0x7fac and Line by 1 to 70
  Special opcode .*: advance Address by 4 to 0x7fb0 and Line by 1 to 71
  Special opcode .*: advance Address by 4 to 0x7fb4 and Line by 1 to 72
  Special opcode .*: advance Address by 4 to 0x7fb8 and Line by 1 to 73
  Special opcode .*: advance Address by 4 to 0x7fbc and Line by 1 to 74
  Special opcode .*: advance Address by 4 to 0x7fc0 and Line by 1 to 75
  Special opcode .*: advance Address by 4 to 0x7fc4 and Line by 1 to 76
  Special opcode .*: advance Address by 4 to 0x7fc8 and Line by 1 to 77
  Special opcode .*: advance Address by 4 to 0x7fcc and Line by 1 to 78
  Special opcode .*: advance Address by 4 to 0x7fd0 and Line by 1 to 79
  Special opcode .*: advance Address by 4 to 0x7fd4 and Line by 1 to 80
  Special opcode .*: advance Address by 4 to 0x7fd8 and Line by 1 to 81
  Special opcode .*: advance Address by 4 to 0x7fdc and Line by 1 to 82
  Special opcode .*: advance Address by 4 to 0x7fe0 and Line by 1 to 83
  Special opcode .*: advance Address by 4 to 0x7fe4 and Line by 1 to 84
  Special opcode .*: advance Address by 4 to 0x7fe8 and Line by 1 to 85
  Special opcode .*: advance Address by 4 to 0x7fec and Line by 6 to 91
  Special opcode .*: advance Address by 2 to 0x7fee and Line by 1 to 92
  Special opcode .*: advance Address by 4 to 0x7ff2 and Line by 1 to 93
  Special opcode .*: advance Address by 4 to 0x7ff6 and Line by 1 to 94
  Special opcode .*: advance Address by 4 to 0x7ffa and Line by 1 to 95
  Special opcode .*: advance Address by 4 to 0x7ffe and Line by 1 to 96
  Special opcode .*: advance Address by 4 to 0x8002 and Line by 1 to 97
  Special opcode .*: advance Address by 12 to 0x800e and Line by 1 to 98
  Special opcode .*: advance Address by 12 to 0x801a and Line by 1 to 99
  Special opcode .*: advance Address by 12 to 0x8026 and Line by 1 to 100
  Special opcode .*: advance Address by 12 to 0x8032 and Line by 1 to 101
  Special opcode .*: advance Address by 12 to 0x803e and Line by 1 to 102
  Special opcode .*: advance Address by 12 to 0x804a and Line by 1 to 103
  Special opcode .*: advance Address by 12 to 0x8056 and Line by 1 to 104
  Special opcode .*: advance Address by 12 to 0x8062 and Line by 1 to 105
  Special opcode .*: advance Address by 12 to 0x806e and Line by 1 to 106
  Special opcode .*: advance Address by 12 to 0x807a and Line by 1 to 107
  Special opcode .*: advance Address by 12 to 0x8086 and Line by 1 to 108
  Special opcode .*: advance Address by 12 to 0x8092 and Line by 1 to 109
  Special opcode .*: advance Address by 12 to 0x809e and Line by 1 to 110
  Special opcode .*: advance Address by 12 to 0x80aa and Line by 1 to 111
  Special opcode .*: advance Address by 12 to 0x80b6 and Line by 5 to 116
  Special opcode .*: advance Address by 2 to 0x80b8 and Line by 1 to 117
  Special opcode .*: advance Address by 12 to 0x80c4 and Line by 1 to 118
  Special opcode .*: advance Address by 12 to 0x80d0 and Line by 1 to 119
  Special opcode .*: advance Address by 12 to 0x80dc and Line by 1 to 120
  Special opcode .*: advance Address by 12 to 0x80e8 and Line by 1 to 121
  Special opcode .*: advance Address by 12 to 0x80f4 and Line by 1 to 122
  Special opcode .*: advance Address by 12 to 0x8100 and Line by 1 to 123
  Special opcode .*: advance Address by 12 to 0x810c and Line by 1 to 124
  Special opcode .*: advance Address by 12 to 0x8118 and Line by 1 to 125
  Special opcode .*: advance Address by 12 to 0x8124 and Line by 1 to 126
  Special opcode .*: advance Address by 12 to 0x8130 and Line by 1 to 127
  Special opcode .*: advance Address by 12 to 0x813c and Line by 1 to 128
  Special opcode .*: advance Address by 12 to 0x8148 and Line by 1 to 129
  Special opcode .*: advance Address by 12 to 0x8154 and Line by 1 to 130
  Special opcode .*: advance Address by 12 to 0x8160 and Line by 1 to 131
  Special opcode .*: advance Address by 12 to 0x816c and Line by 1 to 132
  Special opcode .*: advance Address by 12 to 0x8178 and Line by 1 to 133
  Special opcode .*: advance Address by 12 to 0x8184 and Line by 1 to 134
  Special opcode .*: advance Address by 12 to 0x8190 and Line by 1 to 135
  Special opcode .*: advance Address by 12 to 0x819c and Line by 1 to 136
  Special opcode .*: advance Address by 12 to 0x81a8 and Line by 6 to 142
  Special opcode .*: advance Address by 2 to 0x81aa and Line by 1 to 143
  Special opcode .*: advance Address by 12 to 0x81b6 and Line by 1 to 144
  Special opcode .*: advance Address by 12 to 0x81c2 and Line by 1 to 145
  Special opcode .*: advance Address by 12 to 0x81ce and Line by 1 to 146
  Special opcode .*: advance Address by 12 to 0x81da and Line by 1 to 147
  Special opcode .*: advance Address by 12 to 0x81e6 and Line by 1 to 148
  Special opcode .*: advance Address by 12 to 0x81f2 and Line by 1 to 149
  Special opcode .*: advance Address by 12 to 0x81fe and Line by 1 to 150
  Special opcode .*: advance Address by 12 to 0x820a and Line by 1 to 151
  Special opcode .*: advance Address by 12 to 0x8216 and Line by 1 to 152
  Special opcode .*: advance Address by 12 to 0x8222 and Line by 1 to 153
  Special opcode .*: advance Address by 12 to 0x822e and Line by 1 to 154
  Special opcode .*: advance Address by 12 to 0x823a and Line by 1 to 155
  Special opcode .*: advance Address by 12 to 0x8246 and Line by 1 to 156
  Special opcode .*: advance Address by 12 to 0x8252 and Line by 1 to 157
  Special opcode .*: advance Address by 12 to 0x825e and Line by 1 to 158
  Special opcode .*: advance Address by 12 to 0x826a and Line by 1 to 159
  Special opcode .*: advance Address by 12 to 0x8276 and Line by 1 to 160
  Special opcode .*: advance Address by 12 to 0x8282 and Line by 1 to 161
  Special opcode .*: advance Address by 12 to 0x828e and Line by 1 to 162
  Special opcode .*: advance Address by 12 to 0x829a and Line by 5 to 167
  Special opcode .*: advance Address by 2 to 0x829c and Line by 1 to 168
  Special opcode .*: advance Address by 12 to 0x82a8 and Line by 1 to 169
  Special opcode .*: advance Address by 12 to 0x82b4 and Line by 1 to 170
  Special opcode .*: advance Address by 12 to 0x82c0 and Line by 1 to 171
  Special opcode .*: advance Address by 12 to 0x82cc and Line by 1 to 172
  Special opcode .*: advance Address by 12 to 0x82d8 and Line by 1 to 173
  Special opcode .*: advance Address by 12 to 0x82e4 and Line by 1 to 174
  Special opcode .*: advance Address by 12 to 0x82f0 and Line by 1 to 175
  Special opcode .*: advance Address by 12 to 0x82fc and Line by 1 to 176
  Special opcode .*: advance Address by 12 to 0x8308 and Line by 1 to 177
  Special opcode .*: advance Address by 12 to 0x8314 and Line by 1 to 178
  Special opcode .*: advance Address by 12 to 0x8320 and Line by 1 to 179
  Special opcode .*: advance Address by 12 to 0x832c and Line by 1 to 180
  Special opcode .*: advance Address by 12 to 0x8338 and Line by 1 to 181
  Special opcode .*: advance Address by 12 to 0x8344 and Line by 1 to 182
  Special opcode .*: advance Address by 4 to 0x8348 and Line by 1 to 183
  Special opcode .*: advance Address by 4 to 0x834c and Line by 1 to 184
  Special opcode .*: advance Address by 4 to 0x8350 and Line by 1 to 185
  Special opcode .*: advance Address by 4 to 0x8354 and Line by 1 to 186
  Special opcode .*: advance Address by 4 to 0x8358 and Line by 1 to 187
  Special opcode .*: advance Address by 4 to 0x835c and Line by 5 to 192
  Special opcode .*: advance Address by 2 to 0x835e and Line by 1 to 193
  Special opcode .*: advance Address by 4 to 0x8362 and Line by 1 to 194
  Special opcode .*: advance Address by 4 to 0x8366 and Line by 1 to 195
  Special opcode .*: advance Address by 4 to 0x836a and Line by 1 to 196
  Special opcode .*: advance Address by 4 to 0x836e and Line by 1 to 197
  Special opcode .*: advance Address by 4 to 0x8372 and Line by 1 to 198
  Special opcode .*: advance Address by 4 to 0x8376 and Line by 1 to 199
  Special opcode .*: advance Address by 4 to 0x837a and Line by 1 to 200
  Special opcode .*: advance Address by 4 to 0x837e and Line by 1 to 201
  Special opcode .*: advance Address by 4 to 0x8382 and Line by 1 to 202
  Special opcode .*: advance Address by 4 to 0x8386 and Line by 1 to 203
  Special opcode .*: advance Address by 4 to 0x838a and Line by 1 to 204
  Special opcode .*: advance Address by 4 to 0x838e and Line by 1 to 205
  Special opcode .*: advance Address by 4 to 0x8392 and Line by 1 to 206
  Special opcode .*: advance Address by 4 to 0x8396 and Line by 1 to 207
  Special opcode .*: advance Address by 4 to 0x839a and Line by 1 to 208
  Special opcode .*: advance Address by 4 to 0x839e and Line by 1 to 209
  Special opcode .*: advance Address by 4 to 0x83a2 and Line by 1 to 210
  Special opcode .*: advance Address by 4 to 0x83a6 and Line by 1 to 211
  Special opcode .*: advance Address by 4 to 0x83aa and Line by 1 to 212
  Special opcode .*: advance Address by 4 to 0x83ae and Line by 5 to 217
  Special opcode .*: advance Address by 2 to 0x83b0 and Line by 1 to 218
  Special opcode .*: advance Address by 4 to 0x83b4 and Line by 1 to 219
  Special opcode .*: advance Address by 4 to 0x83b8 and Line by 1 to 220
  Special opcode .*: advance Address by 4 to 0x83bc and Line by 1 to 221
  Special opcode .*: advance Address by 4 to 0x83c0 and Line by 1 to 222
  Special opcode .*: advance Address by 4 to 0x83c4 and Line by 1 to 223
  Special opcode .*: advance Address by 4 to 0x83c8 and Line by 1 to 224
  Special opcode .*: advance Address by 4 to 0x83cc and Line by 1 to 225
  Special opcode .*: advance Address by 4 to 0x83d0 and Line by 1 to 226
  Special opcode .*: advance Address by 4 to 0x83d4 and Line by 1 to 227
  Special opcode .*: advance Address by 4 to 0x83d8 and Line by 1 to 228
  Special opcode .*: advance Address by 4 to 0x83dc and Line by 1 to 229
  Special opcode .*: advance Address by 2 to 0x83de and Line by 1 to 230
  Special opcode .*: advance Address by 2 to 0x83e0 and Line by 1 to 231
  Special opcode .*: advance Address by 2 to 0x83e2 and Line by 1 to 232
  Special opcode .*: advance Address by 2 to 0x83e4 and Line by 1 to 233
  Special opcode .*: advance Address by 2 to 0x83e6 and Line by 1 to 234
  Special opcode .*: advance Address by 2 to 0x83e8 and Line by 1 to 235
  Special opcode .*: advance Address by 2 to 0x83ea and Line by 1 to 236
  Special opcode .*: advance Address by 2 to 0x83ec and Line by 1 to 237
  Special opcode .*: advance Address by 2 to 0x83ee and Line by 5 to 242
  Special opcode .*: advance Address by 2 to 0x83f0 and Line by 1 to 243
  Special opcode .*: advance Address by 2 to 0x83f2 and Line by 1 to 244
  Special opcode .*: advance Address by 2 to 0x83f4 and Line by 1 to 245
  Special opcode .*: advance Address by 2 to 0x83f6 and Line by 1 to 246
  Special opcode .*: advance Address by 2 to 0x83f8 and Line by 1 to 247
  Special opcode .*: advance Address by 2 to 0x83fa and Line by 1 to 248
  Special opcode .*: advance Address by 2 to 0x83fc and Line by 1 to 249
  Special opcode .*: advance Address by 2 to 0x83fe and Line by 1 to 250
  Special opcode .*: advance Address by 2 to 0x8400 and Line by 1 to 251
  Special opcode .*: advance Address by 2 to 0x8402 and Line by 1 to 252
  Special opcode .*: advance Address by 2 to 0x8404 and Line by 1 to 253
  Special opcode .*: advance Address by 2 to 0x8406 and Line by 1 to 254
  Special opcode .*: advance Address by 2 to 0x8408 and Line by 1 to 255
  Special opcode .*: advance Address by 2 to 0x840a and Line by 1 to 256
  Special opcode .*: advance Address by 2 to 0x840c and Line by 1 to 257
  Special opcode .*: advance Address by 2 to 0x840e and Line by 1 to 258
  Special opcode .*: advance Address by 2 to 0x8410 and Line by 1 to 259
  Special opcode .*: advance Address by 2 to 0x8412 and Line by 1 to 260
  Special opcode .*: advance Address by 2 to 0x8414 and Line by 1 to 261
  Special opcode .*: advance Address by 2 to 0x8416 and Line by 1 to 262
  Special opcode .*: advance Address by 2 to 0x8418 and Line by 2 to 264
  Advance PC by 196 to 0x84dc
  Special opcode .*: advance Address by 0 to 0x84dc and Line by 3 to 267
  Advance PC by 32360 to 0x10344
  Special opcode .*: advance Address by 0 to 0x10344 and Line by 3 to 270
  Advance PC by 2 to 0x10346
  Extended opcode 1: End of Sequence
