        .text
        .global main
main:
	##############
	# storm cnt
	##############
 	storm $1
 	storm $2
 	storm $3
 	storm $4
 	storm $5
 	storm $6
 	storm $7
 	storm $8
	##############
	# stormp cnt
	##############
 	stormp $1
 	stormp $2
 	stormp $3
 	stormp $4
 	stormp $5
 	stormp $6
 	stormp $7
 	stormp $8
