[^:]*: Assembler messages:
[^:]*:6: Error: register number 31 not supported on this architecture
[^:]*:7: Error: register number 31 not supported on this architecture
[^:]*:8: Error: register number 31 not supported on this architecture
[^:]*:9: Error: register number 31 not supported on this architecture
[^:]*:24: Error: register number 31 not supported on this architecture
[^:]*:25: Error: register number 31 not supported on this architecture
[^:]*:26: Error: register number 31 not supported on this architecture
[^:]*:27: Error: register number 31 not supported on this architecture
[^:]*:42: Error: register number 31 not supported on this architecture
[^:]*:43: Error: register number 31 not supported on this architecture
[^:]*:44: Error: register number 31 not supported on this architecture
[^:]*:45: Error: register number 31 not supported on this architecture
[^:]*:46: Error: register number 31 not supported on this architecture
[^:]*:47: Error: register number 30 not supported on this architecture
