.*: Assembler messages:
.*:6: Error: bad expression
.*:6: Error: illegal operands `addiu \$4,\$28,%dtprel\(tlsvar\)'
.*:7: Error: bad expression
.*:7: Error: illegal operands `addiu \$4,\$28,%tprel\(tlsvar\)'
.*:8: Error: bad expression
.*:8: Error: missing '\)'
.*:8: Error: illegal operands `addiu \$4,\$28,%lo\(%gottprel\(tlsvar\)\)'
.*:9: Error: bad expression
.*:9: Error: missing '\)'
.*:9: Error: illegal operands `addiu \$4,\$28,%hi\(%gottprel\(tlsvar\)\)'