#readelf: -wl
#source: brokw-3.s
#as: --em=criself --gdwarf2

# Long broken word table.
#...
 Line Number Statements:
  Extended opcode 2: set Address to 0x0
  Special opcode .*: advance Address by 0 to 0x0 and Line by 3 to 4
  Special opcode .*: advance Address by 2 to 0x2 and Line by 4 to 8
  Special opcode .*: advance Address by 4 to 0x6 and Line by 1 to 9
  Special opcode .*: advance Address by 4 to 0xa and Line by 1 to 10
  Advance Line by 47 to 57
  Advance PC by 104 to 0x72
  Copy
  Advance Line by 10 to 67
  Advance PC by 260 to 0x176
  Copy
  Advance PC by 32770 to 0x8178
  Special opcode .*: advance Address by 0 to 0x8178 and Line by 4 to 71
  Special opcode .*: advance Address by 2 to 0x817a and Line by 1 to 72
  Special opcode .*: advance Address by 2 to 0x817c and Line by 1 to 73
  Special opcode .*: advance Address by 2 to 0x817e and Line by 1 to 74
  Special opcode .*: advance Address by 2 to 0x8180 and Line by 1 to 75
  Special opcode .*: advance Address by 2 to 0x8182 and Line by 1 to 76
  Special opcode .*: advance Address by 2 to 0x8184 and Line by 1 to 77
  Special opcode .*: advance Address by 2 to 0x8186 and Line by 1 to 78
  Special opcode .*: advance Address by 2 to 0x8188 and Line by 1 to 79
  Special opcode .*: advance Address by 2 to 0x818a and Line by 1 to 80
  Special opcode .*: advance Address by 2 to 0x818c and Line by 1 to 81
  Special opcode .*: advance Address by 2 to 0x818e and Line by 1 to 82
  Special opcode .*: advance Address by 2 to 0x8190 and Line by 1 to 83
  Special opcode .*: advance Address by 2 to 0x8192 and Line by 1 to 84
  Special opcode .*: advance Address by 2 to 0x8194 and Line by 1 to 85
  Special opcode .*: advance Address by 2 to 0x8196 and Line by 1 to 86
  Special opcode .*: advance Address by 2 to 0x8198 and Line by 1 to 87
  Special opcode .*: advance Address by 2 to 0x819a and Line by 1 to 88
  Special opcode .*: advance Address by 2 to 0x819c and Line by 1 to 89
  Special opcode .*: advance Address by 2 to 0x819e and Line by 1 to 90
  Special opcode .*: advance Address by 2 to 0x81a0 and Line by 1 to 91
  Special opcode .*: advance Address by 2 to 0x81a2 and Line by 1 to 92
  Special opcode .*: advance Address by 2 to 0x81a4 and Line by 1 to 93
  Special opcode .*: advance Address by 2 to 0x81a6 and Line by 1 to 94
  Special opcode .*: advance Address by 2 to 0x81a8 and Line by 1 to 95
  Special opcode .*: advance Address by 2 to 0x81aa and Line by 1 to 96
  Special opcode .*: advance Address by 2 to 0x81ac and Line by 1 to 97
  Special opcode .*: advance Address by 2 to 0x81ae and Line by 1 to 98
  Special opcode .*: advance Address by 2 to 0x81b0 and Line by 1 to 99
  Special opcode .*: advance Address by 2 to 0x81b2 and Line by 1 to 100
  Special opcode .*: advance Address by 2 to 0x81b4 and Line by 1 to 101
  Special opcode .*: advance Address by 2 to 0x81b6 and Line by 1 to 102
  Special opcode .*: advance Address by 2 to 0x81b8 and Line by 1 to 103
  Special opcode .*: advance Address by 2 to 0x81ba and Line by 1 to 104
  Special opcode .*: advance Address by 2 to 0x81bc and Line by 1 to 105
  Special opcode .*: advance Address by 2 to 0x81be and Line by 1 to 106
  Special opcode .*: advance Address by 2 to 0x81c0 and Line by 1 to 107
  Special opcode .*: advance Address by 2 to 0x81c2 and Line by 1 to 108
  Special opcode .*: advance Address by 2 to 0x81c4 and Line by 1 to 109
  Special opcode .*: advance Address by 2 to 0x81c6 and Line by 1 to 110
  Special opcode .*: advance Address by 2 to 0x81c8 and Line by 1 to 111
  Special opcode .*: advance Address by 2 to 0x81ca and Line by 1 to 112
  Advance PC by 2 to 0x81cc
  Extended opcode 1: End of Sequence
