ARCH="i386:x86-64"
SCRIPT_NAME=pep
OUTPUT_FORMAT="pei-x86-64"
RELOCATEABLE_OUTPUT_FORMAT="pe-x86-64"
TEMPLATE_NAME=pep
SUBSYSTEM=PE_DEF_SUBSYSTEM
INITIAL_SYMBOL_CHAR=\"_\"
TARGET_PAGE_SIZE=0x1000
GENERATE_AUTO_IMPORT_SCRIPT=1
