SCRIPT_NAME=elf
OUTPUT_FORMAT="elf32-am33lin"
NO_REL_RELOCS=yes
TEXT_START_ADDR=0x8000000
MAXPAGESIZE="CONSTANT (MAXPAGESIZE)"
ARCH=mn10300
MACHINE=
NOP=0xcbcb
TEMPLATE_NAME=elf32
GENERATE_SHLIB_SCRIPT=yes

