
Relocation section '\.rel\.plt' at offset .* contains 1 entries:
 Offset     Info    Type            Sym\.Value  Sym\. Name
.*  .*07 R_386_JUMP_SLOT   00000000   foo

Relocation section '\.rel\.text' at offset .* contains 1 entries:
 Offset     Info    Type            Sym\.Value  Sym\. Name
.*  .*04 R_386_PLT32       00000000   foo
