GAS for MMIX .*/list-textfirst\.s 			page 1


   1              	 \.data
   2              	here:
   3 0000 0000002A 	 tetra 42
   4              	\.text
   5              	there:
   6 0000 EA       	 \.byte 0xea
GAS for MMIX .*/list-textfirst\.s 			page 2


DEFINED SYMBOLS
.*/list-textfirst\.s:2      \.data:0000000000000000 here
.*/list-textfirst\.s:5      \.text:0000000000000000 there

NO UNDEFINED SYMBOLS
