.*: Assembler messages:
.*:1: Error: Instruction not supported by this architecture
.*:2: Error: Instruction not supported by this architecture
.*:3: Error: Instruction not supported by this architecture
.*:4: Error: Instruction not supported by this architecture
.*:5: Error: Instruction not supported by this architecture
#
.*:7: Error: Instruction not supported by this architecture
.*:8: Error: Instruction not supported by this architecture
.*:9: Error: Instruction not supported by this architecture
.*:10: Error: Instruction not supported by this architecture
.*:11: Error: Instruction not supported by this architecture
#
.*:13: Error: Instruction not supported by this architecture
.*:14: Error: Instruction not supported by this architecture
.*:15: Error: Instruction not supported by this architecture
.*:16: Error: Instruction not supported by this architecture
#
.*:18: Error: Instruction not supported by this architecture
.*:19: Error: Instruction not supported by this architecture
.*:20: Error: Instruction not supported by this architecture
#
.*:22: Error: Instruction not supported by this architecture
.*:23: Error: Instruction not supported by this architecture
.*:24: Error: Instruction not supported by this architecture
#
.*:26: Error: Instruction not supported by this architecture
.*:27: Error: Instruction not supported by this architecture
.*:28: Error: Instruction not supported by this architecture
#
.*:30: Error: Instruction not supported by this architecture
.*:31: Error: Instruction not supported by this architecture
.*:32: Error: Instruction not supported by this architecture
