
.*thumb1-bl:     file format elf32-.*arm

Disassembly of section .text:

00001000 <_start>:
    1000:	f3ff fffe 	bl	401000 <bar>
Disassembly of section .foo:

00401000 <bar>:
  401000:	4770      	bx	lr
