[^:]*: Assembler messages:
[^:]*:5: Error: junk at end of line, first unrecognized character is `\['
[^:]*:6: Error: predicate not followed by instruction
[^:]*:7: Error: bad predicate '\[unknown\]'
[^:]*:8: Error: bad predicate '\[a3\]'
[^:]*:9: Error: bad predicate '\[b500\]'
[^:]*:10: Error: bad predicate '\[\]'
[^:]*:11: Error: bad predicate '\[!\]'
[^:]*:12: Error: bad predicate '\[!a\]'
[^:]*:13: Error: bad predicate '\[!A\]'
[^:]*:14: Error: bad predicate '\[!b\]'
[^:]*:15: Error: bad predicate '\[!B\]'
[^:]*:16: Error: bad predicate '\[!x\]'
[^:]*:17: Error: bad predicate '\[a\]'
[^:]*:18: Error: bad predicate '\[B\]'
[^:]*:19: Error: multiple predicates on same line
[^:]*:19: Error: instruction 'nop' cannot be predicated
[^:]*:20: Error: predicate not followed by instruction
[^:]*:21: Error: label after predicate
[^:]*:22: Error: predicate not followed by instruction
