.globl s0
.globl sff
.globl sffff
.globl s80000000
.globl sffff8000
.globl sffffff80
.globl sffffffff
.data
	.word s80000000
	.word sffffffff
	.word s0
	.word sffffffff+0xffffffff
	.word s80000000+0x80000000
	.short sffffffff
	.short sffff
	.short sffff8000
	.short s0-0x8000
	.short s80000000+0x80000000
	.byte sffffffff
	.byte sff
	.byte sffffff80
	.byte s0-0x80
	.byte s80000000+0x80000000
