#objdump: -drt

.*:     file format elf64-mmix

SYMBOL TABLE:
0+ l    d  \.text	0+ (|\.text)
0+ l    d  \.data	0+ (|\.data)
0+ l    d  \.bss	0+ (|\.bss)
0+ g     F \.text	0+ Main


Disassembly of section \.text:

0+ <Main>:
   0:	f801e240 	pop 1,57920
