[^:]*: Assembler messages:
[^:]*:5: Error: selected processor does not support 'A' form of this instruction -- `cpsie a'
[^:]*:6: Error: Thumb does not support the 2-argument form of this instruction -- `cpsie i,#0x10'
[^:]*:7: Error: selected processor does not support Thumb mode `cps #0x10'

