        .text
        .global main
main:
	##############
	# loadm cnt
	##############
 	loadm $1
 	loadm $2
 	loadm $3
 	loadm $4
 	loadm $5
 	loadm $6
 	loadm $7
 	loadm $8
	##############
	# loadmp cnt
	##############
 	loadmp $1
 	loadmp $2
 	loadmp $3
 	loadmp $4
 	loadmp $5
 	loadmp $6
 	loadmp $7
 	loadmp $8
