TEMPLATE_NAME=elf32
MACHINE=
SCRIPT_NAME=elf
OUTPUT_FORMAT="elf32-ip2k"
NO_REL_RELOCS=yes
# See also `include/elf/ip2k.h'
DATA_ADDR=0x01000100
TEXT_START_ADDR=0x02010000
GPR_START_ADDR=0x1000080
GPR_SIZE=0x7F
GRP_MEMORY=gpr
ARCH=ip2k
ENTRY=__start
EMBEDDED=yes
ELFSIZE=32
MAXPAGESIZE=256
WRITABLE_RODATA=
OTHER_RELOCATING_SECTIONS='PROVIDE (__stack = 0x01000FFF);'
OTHER_READONLY_SECTIONS='.pram 0x2000000 : { *(.pram) } .reset 0x201FFE0 : { *(.reset) }'
OTHER_READWRITE_SECTIONS='.gpr 0x1000080 : { *(.gpr) }'

